function [iyear,iday,ihour]= forday(dtime,yrflag)
%forday: converts HYCOM model day to "calendar" date (year,julian-day,hour)
%
%    [y,d,h]= forday(dtime,yrflag) converts HYCOM model day to "calendar"
%    date
%
%           INPUT: dtime: time in days lapse (days, may be non-integer)
%                  yrflag=0: 360 days per model year, starting Jan 16
%                  yrflag=1: 366 days per model year, starting Jan 16
%                  yrflag=2: 366 days per model year, starting Jan 01
%                  yrflag=3:model day is calendar days since 01/01/1901
%            OUTPUT: y is year
%                    d is Julian date
%                    h is hour
%
%   EXAMPLE: [y,d,h]=forday(37874.5) returns y=2004, d=254, h=12.
%
%   SEE ALSO: day2year
%
%forday
%
% --- converts model day to "calendar" date (year,julian-day,hour).
%     dtime time in days lapse (days) since dec 31 1900.
%%%% Intended for dtime >=0
if     (yrflag == 0)
    %       360 days per model year, starting Jan 16
    %%%       iyear =  int((dtime+15.001  )/360.0) + 1;
    iyear =  floor((dtime+15.001  )/360.0) + 1;
    iday  =  floor(  mod( dtime+15.001   ,360.0) + 1 );
    ihour =  floor( (mod( dtime+15.001   ,360.0) + 1.0 - iday)*24.0 );

elseif (yrflag == 1)
    %       366 days per model year, starting Jan 16
    %%%%        iyear =  int((dtime+15.001  )/366.0) + 1;

    iyear =  floor((dtime+15.001  )/366.0) + 1;
    iday  = floor(  mod( dtime+15.001   ,366.0) + 1 );
    ihour = floor( (mod( dtime+15.001   ,366.0) + 1.0 - iday)*24.0) ;

elseif (yrflag == 2)
    %       366 days per model year, starting Jan 01
    %%%%iyear =  int((dtime+ 0.001  )/366.0) + 1;
    %%%% Intended for dtime >=0
    iyear =  floor((dtime+ 0.001  )/366.0) + 1;
    iday  =  floor( mod( dtime+ 0.001   ,366.0) + 1);
    ihour =  floor( (mod( dtime+ 0.001   ,366.0) + 1.0 - iday)*24.0);

elseif (yrflag == 3)
    %       model day is calendar days since 01/01/1901
    iyr   = floor( (dtime-1.0)/365.25 ) ;
    nleap = floor( iyr/4  );
    dtim1 = 365.0*iyr + nleap + 1.0;
    day   = dtime - dtim1 + 1.0;
    if     (dtim1 > dtime)
        iyr = iyr - 1;
    elseif (day >= 367.0)
        iyr = iyr + 1;
    elseif (day >= 366.0 & ~(mod(iyr,4)==3))
        iyr = iyr + 1;
    end
    nleap = floor( iyr/4 );
    dtim1 = 365.0*iyr + nleap + 1.0;

    iyear =  floor(1901 + iyr );
    iday  =  floor(dtime - dtim1 + 1 );
%     ihour =  round( ( dtime - dtim1 + 1.0 - iday)*24.0 );
    ihour =  ( dtime - dtim1 + 1.0 - iday)*24.0 ;
else


    error( 'error in forday - unsupported yrflag value')
end

