% N_trackSHT_300km.m
%		read in layer and SHT data from a set of Stand-alone/Coupled HYCOM simulation grib files,
%       and
%       produce a set of the SHT foot prints along a hurricane track. 
%
%-------
%	input
%-------
%			*.3d.grb   - layer-thickness for each layer (1-15)
%           nhc_Rita05.dat        - NHC disseminated hurricane information
%-------
% output
%-------
%       1. a set of 4 figures:
%               png1name=[fcst,'_',Hname,'_SHT_Htrack'];
%               png2name=[fcst,'_',Hname,'_SHT_Htrack_matrix'];
%               png3name=[fcst,'_',Hname,'_mnSHT_Htrack'];
%               png4name=[fcst,'_',Hname,'_mnSHT_Htrack_matrix'];
%								png5name=[fcst,'_',Hname,'_diffSHT6hr_Htrack_matrix'];
%								png6name=[fcst,'_',Hname,'_diffSHT12hr_Htrack_matrix'];
%
%       2. ascii output for an SHT matrix as function of date (x) and distance (y).
%
%--------
% history
%--------
%       1/29/3008 Modified 'diagnos_rtofs_trackSHT.m' 
%               for Coupled/Stand-alone simulations. -hsk
%		11/19/2007 Edited by Hyun-Sook Kim
%
%------------------------------------------------------------------------
clear all; close all; 

%ncyc=24;

%-------------------------------------------  Run information -------------
for ncyc=138:6:138
    
eta=300;        % Storm size (km)
isave=1;

tsample=6;                  % sampling

TZERO=273.15;        % Kelvin to Celsus

%-------------------------------------------  Run information -------------
fcst4t='HWRF';               % forecast ID for title
fcst='H4Y2';               % model system ID
domain='al';              % hurricane domain
year=2012;                  % year for interest of hurricane
mm=08;
dd=21;
hr=06;
ID='09';
Hname=['Isaac',ID,domain(end)];             % Hurricane name

TCname=['Isaac 09L'];
if ncyc<=6
    fname='seven07w';
else
    fname=Hname;
end


%--- best track
%--- best HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',num2str(year),'\b',domain,ID,num2str(year),'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhy=str2num(nhc(:,35:38))/10;
nhx=(-1)*str2num(nhc(:,41:45))/10;
        if domain=='wp'
            nhx=nhx*(-1);
        end
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');
        Rads=str2num(nhc(:,74:95))*1.8;     % size: [nm] to [km]
        bestR=[];
        for n=1:size(nhc,1)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            bestR(n)=mn;
            clear tmp mn
        end
best=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

%-------------------------------------------------------- for users: ------
%  Number of cycle
% ncyc=108;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
dnc=dn0+ncyc/24;
nds=datestr(dnc,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['Z:\',fcst,'\',Hname,'\',yearmmddhh,'\',runID,'\atmos\'];       % run output directory
tdir=['Z:\',fcst,'\',Hname,'\atcf\'];       % track directory

%--- output directory
% a folder for figure deposit 
odir=['Z:\',fcst,'\',Hname,'\',yearmmddhh,'\',runID,'\Hwrf_trackSHT\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

% output data filename
ofname=[fcst,'-',Hname,'-PtrackSHT','.dat'];      % ASCII data filename for MLD

%--- setup date for data extraction
%  6-hour data - 
% list of input files: 
prefix=[fname,'.',datestr(dnc,'yyyymmddHH.')];
Gfs{1}=[prefix,'HWRFprs_N.GrbF00'];
Gfs{2}=[prefix,'HWRFprs_N.GrbF06'];
Gfs{3}=[prefix,'HWRFprs_N.GrbF12'];
Gfs{4}=[prefix,'HWRFprs_N.GrbF18'];
Gfs{5}=[prefix,'HWRFprs_N.GrbF24'];
Gfs{6}=[prefix,'HWRFprs_N.GrbF30'];
Gfs{7}=[prefix,'HWRFprs_N.GrbF36'];
Gfs{8}=[prefix,'HWRFprs_N.GrbF42'];
Gfs{9}=[prefix,'HWRFprs_N.GrbF48'];
Gfs{10}=[prefix,'HWRFprs_N.GrbF54'];
Gfs{11}=[prefix,'HWRFprs_N.GrbF60'];
Gfs{12}=[prefix,'HWRFprs_N.GrbF66'];
Gfs{13}=[prefix,'HWRFprs_N.GrbF72'];
Gfs{14}=[prefix,'HWRFprs_N.GrbF78'];
Gfs{15}=[prefix,'HWRFprs_N.GrbF84'];
Gfs{16}=[prefix,'HWRFprs_N.GrbF90'];
Gfs{17}=[prefix,'HWRFprs_N.GrbF96'];
Gfs{18}=[prefix,'HWRFprs_N.GrbF102'];
Gfs{19}=[prefix,'HWRFprs_N.GrbF108'];
Gfs{20}=[prefix,'HWRFprs_N.GrbF114'];
Gfs{21}=[prefix,'HWRFprs_N.GrbF120'];
Gfs{22}=[prefix,'HWRFprs_N.GrbF126'];

%------------------------------------------------------------------
% Ancillary
%-----------
% hurricane domain: grid information
switch lower(domain)
    case {'west'}
        lonlat=[-100 -55 10 40];
    case {'mid'}
        lonlat=[-70   -20    5    45];
        fpos1=[36   291   832   638];
    case {'east'}
        lonlat=[-90 -40 5 50];
    case {'beast'}
        lonlat=([-100 -70 15 35]);  % domain for figure
        fpos1=[36   291   832   638];
    case 'wp'
        lonlat=[100 170 0 45];
        fpos1=[36   291   832   638];        
    case 'al'
        lonlat=[-105 -75 20 32];
end
clear M

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
switch lower(frc)
    case {'hwrf'}
        dlook=dir([tdir,'\',fname,'.',datestr(dnc,'yyyymmddHH'),'.trak.hwrf.atcfunix']);
        tfile=dlook.name;
        hsk=caseread([tdir,'\',tfile]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        knt=str2num(hsk(:,65:66));      % reference knot
        % find index for reference wind speed=34kt
        ix=find(knt==34);
        hsk=hsk(ix,:);
        hx=-1*str2num(hsk(:,42:45))/10;
        if domain=='wp'
            hx=hx*-1;
        end
        hy=str2num(hsk(:,36:38))/10; 
        hhr=hhr(ix);
        hdn=datenum(hsk(:,9:18),'yyyymmddHH')+hhr/24;
        Rads=str2num(hsk(:,74:95)) *1.8;     % size [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk
    case {'gfs'}
        nhc=load('G:\PROJECT07\OFS\GFStrack\Rita.best.track.gfs.txt');
        hx=nhc(:,3); hy=nhc(:,2);
        ymdh=num2str(nhc(:,1));
        hdn=datenum(ymdh,'yyyymmddHH');
end

% %nhc=load('G:/NHC/nhc_Rita05.dat');           % NHC hurricane information
% %
% %   1    2   3  4  5   6   7       8         9        10   
% %  ----------------------------------------------------------
% %   year mon dy hh lat lon Prs(mb) wind(m/s) size(km) Prs_env
% %
% nhc=load(['G:/NHC/nhc_',Hname,'.dat']);           % NHC hurricane information
% hx=nhc(:,6); hy=nhc(:,5);
% hdn=datenum([nhc(:,1),nhc(:,2),nhc(:,3),nhc(:,4),repmat(0,length(hx),2)]);
% Rsize=nhc(:,end-1);           % the hurricane radius (km)
% 
%--------------------------------------------------------------------
% main section
%    1.Find a set of indicies along the hurricane track
%------------------------------------------------------

%--- figure output name:
add=num2str(eta,'%3g');
png1name=[fcst,'_',Hname,'_nestSHT_Htrack',add];
png2name=[fcst,'_',Hname,'_nestSHT_Htrack_matrix1',add];
png3name=[fcst,'_',Hname,'_nestSHT_Htrack_matrix2',add];
png4name=[fcst,'_',Hname,'_nestSHT_timeseries',add];
png5name=[fcst,'_',Hname,'_diff_nestSHT6hr_Htrack_matrix',add];

%====================================================== Assembling data ===
%--- assembling data
Cs=load('coasts.mat');     % coastline

Ni=101; Nj=71;     % dimension of the parent domain

% work-space
Im=repmat(nan,150,length(Gfs));       % collection of indicies each time step
mnSHT=repmat(nan,length(Gfs),1);        % mean SHT on a hurricane footprint                            
SHTall=repmat(nan,[length(Gfs),Nj,Ni]); % SHT for all 
alon=repmat(nan,[length(Gfs),Nj,Ni]);
alat=repmat(nan,[length(Gfs),Nj,Ni]);
disp(' ')
cindx=[];

SHTall=[]; % SHT for all 
alon=[];
alat=[];

dn=[];
Axavg=[];
for K=1:length(Gfs)
    dn=[dn; dnc+(K-1)*6/24];
    gfile=[ddir,Gfs{K}];
    
    % find indices at the hurricane eye
    q=find(hdn==dn(K));
    if ~isempty(q)
        
    cindx=[cindx; q];
    
    disp(sprintf('      %g ... Working with %s',K,gfile))

    % get SHT
    gtmp=getgrib(gfile,'SHTFL');    
    Ds=flipud(gtmp.data); clear gtmp   
    
    SHTall(K,:,:)=Ds;

    % get (lon,lat) 
    gtmp=read_grib(gfile,{'WTMP'});
    tmp=gtmp.gds;
    xs=[min(tmp.Lo1,tmp.Lo2):tmp.Di:max(tmp.Lo1,tmp.Lo2)];
    ys=[min(tmp.La1,tmp.La2):tmp.Di:max(tmp.La1,tmp.La2)];
    [hlon,hlat]=meshgrid(xs,ys);
    alon(K,:,:)=hlon;
    alat(K,:,:)=hlat;
    
    clear xs ys tmp gtmp
    
    % find indices at the hurricane eye
    dr=fnddist(hlon,hlat,hx(q),hy(q));
    %ks=find(dr <= Rsize(q));
    ks=find(dr <= eta+10);
    drks=dr(ks);
    
    Dstmp=Ds(ks);
    Di=[0:9:309];
    Atmp=[];
    for l=1:length(Di)-1
        bb=find((drks>=Di(l) & drks<Di(l+1)));
        Atmp(l)=nanmean(Dstmp(bb));
        clear bb
    end
    Axavg=[Axavg; Atmp(:)'];
    
  %  aa=find(Dstmp>(nanmean(Dstmp)-5*nanstd(Dstmp)))
  %  ks=ks(aa);

    Im(1:length(ks),K)=ks(:);
    
   %keyboard
    
    clear ks q dr Ds aa
    end
end
hdn=hdn(cindx);
Rsize=Rsize(cindx);
hx=hx(cindx); 
hy=hy(cindx);

Im(Im==0)=nan;

mnSHTtrack=repmat(nan,length(cindx),length(cindx));   % a matrix of mean SHTs 
                                % on a Hurricane footprint for the whole time period
stdSHTtrack=mnSHTtrack;
minSHTtrack=mnSHTtrack;        % min SHT on a hurricane footprint                            
maxSHTtrack=mnSHTtrack;        % max SHT on a hurricane footprint                            

for k=1:size(SHTall,1)
    ssm=squeeze(SHTall(k,:,:));       % a fixed day
    for p=1:length(cindx);         % x-direction
        a=find(~isnan(Im(:,p)));
        if isempty(a)
        mnSHTtrack(k,p)=nan;     % mean SHT for pre and post storm passage
        stdSHTtrack(k,p)=nan;      % STD
        minSHTtrack(k,p)=nan;      % STD
        maxSHTtrack(k,p)=nan;      % STD
        else
        indx=Im(a,p); clear a;
        mnSHTtrack(k,p)=nanmean(ssm(indx));     % mean SHT for pre and post storm passage
        stdSHTtrack(k,p)=nanstd(ssm(indx));      % STD
        minSHTtrack(k,p)=nanmin(ssm(indx));      % STD
        maxSHTtrack(k,p)=nanmax(ssm(indx));      % STD
        end
    end
end

mnSHT=diag(mnSHTtrack);
stdSHT=diag(stdSHTtrack);
minSHT=diag(minSHTtrack);
maxSHT=diag(maxSHTtrack);

%--------------------------------------------------------------------------
%   Diagnostic Part
%-------------------
% color range
crange=[-2:0.2:2.6]*100;
njet=length(crange)-1;

%--- FIGURE 1: SHT on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.11 0.88 0.81]);
plot(Cs.coastlines(1,:),Cs.coastlines(2,:),'k'); grid; hold on;
%draw_wrldcst360('k'); grid; hold on
% SHT on the storm footprint
for h=2:21;
    ssm=squeeze(SHTall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;
    sss=repmat(nan,size(ssm));
    sss(indx)=ssm(indx);
    
    [aa,bb]=find(~isnan(sss));
    aa=unique(aa(:));
    bb=unique(bb(:));
    
    if mod((dn(h)-dn(1)),1)==0
        %scatter(hlon(indx),hlat(indx),20,ssm(indx),'filled');
        q=find(hdn==dn(h));
        if isempty(aa) | isempty(bb)
                    plot(hx(q),hy(q),'or','markersize',6)    
        else
            hlon=squeeze(alon(h,:,:));
            hlat=squeeze(alat(h,:,:));
            
            pcolorhsk(hlon(aa,bb),hlat(aa,bb),sss(aa,bb)); shading flat;
            caxis([crange(1) crange(end)]); 
            plot(hx(q),hy(q),'or','markersize',6)    
            avg=nanmean(ssm(indx));
            xx=hx(q)+Rsize(q)/sqrt(2)/150;
            yy=hy(q)+Rsize(q)/sqrt(2)/150;
            text(xx,yy,[num2str(avg,'%3.1f'),' W/m^2'],'fontsize',11,'color','k','fontweight','bold');
        end
        clear xx yy avg
    end
end
% track
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
plot(best(:,2),best(:,3),'-x','color',repmat(0.5,1,3));
axis(lonlat);
set(gca,'tickdir','out','fontsize',12);
colormap(jet(njet)); 
hc=colorbar; set(hc,'tickdir','out','fontsize',12);
xlabel('Longitude (^oE)','fontsize',13);
ylabel('Latitude (^oN)','fontsize',13); box on;
% title(['Progressive Changes of ',fcst,' SHT on the ',Hname,' Footprint (',runID,')'],...
%     'fontsize',12,'fontweight','bold');
% %title([fcst4t,': Nest Domain  24-hourly SHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
%     'fontsize',12,'fontweight','bold');
% txt{1}='     from';
% txt{2}=datestr(dn(1),'yyyy/mm/dd HH:MMZ');
% txt{3}='     to ';
% txt{4}=datestr(dn(end),'yyyy/mm/dd HH:MMZ');
% text(0.7,0.9,txt,'fontsize',13,'color','m','units','normalized','fontweight','bold');

% text(0.75,-0.09,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png1name]); 
end

%--- FIGURE2: Hurricane's SHT foot-print: Stamp (6x6) Plot
%
% A) indiviual subplot locations for a 10x10 figure
np=10;
pd=0.084;
pys=0.085+pd*[0:np-1];
pxs=0.085+pd*[0:np-1];
[Px,Py]=meshgrid(pxs,pys);
Px=flipud(Px);
Py=flipud(Py);
axs=[Px(:),Py(:),repmat(pd,np*np,2)];        % each figure location

rscale=4;       % box size (1*rscale x 1*rscale)

% plotting
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst4t,': Nest Domain SHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');

for k=1:np;      % y-direction
    ssm=squeeze(SHTall(k,:,:));       % a fixed day
    for p=1:np;         % x-direction
        r=(k-1)*np+p;
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   indx=Im(a,p); clear a;
        
        b=find(hdn==dn(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnSHTtrack(k,p))==1
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
            hlon=squeeze(alon(k,:,:)); 
            hlat=squeeze(alat(k,:,:));
            if (length(ia)>=2 & length(ja)>=2)
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if k==p
         text(-0.15,0.8*rscale,[num2str(mnSHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,'fontweight','bold');
        end
        clear ia ja 
    end
    xlabel(datestr(dn(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png2name]); 
end

% Stamp figure - 2
% Figure 2:
% B) indiviual subplot locations for a 10x10 figure
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst4t,': Nest Domain SHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
for k=1+np:min(2*np,length(dn));      % y-direction
    ssm=squeeze(SHTall(k,:,:));       % a fixed day
    for p=np+1:min(2*np,length(dn));         % x-direction
        r=(k-1-np)*np+(p-np);
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        
        b=find(hdn==dn(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnSHTtrack(k,p))==1 
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss));
            ia=unique(ia); ja=unique(ja); 
            if (length(ia)>=2 & length(ja)>=2)
            hlon=squeeze(alon(k,:,:));
            hlat=squeeze(alat(k,:,:));
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if (k==p)
        text(-0.15,0.8*rscale,[num2str(mnSHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==np+1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
    end
    xlabel(datestr(dn(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    clear ia ja 
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png3name]); 
end

% mean and standard deviation of SHT on footprint
figure;
errorbar(dn,mnSHT,stdSHT,'-');
set(gca,'tickdir','out');
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
xlabel('forecast valid time')
ylabel('heat flux (W/m^2)'); grid
title([fcst4t,': SHT on Footprint for ',upper(Hname),' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')],...
    'fontsize',12);
eval(['print -dpng ',odir,'\series_trackSHT']);

% mean and standard deviation of SHT on footprint
figure;
errorbar(dn,mnSHT,minSHT-mnSHT,maxSHT-mnSHT,'-');
set(gca,'tickdir','out');
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
xlabel('forecast valid time')
ylabel('heat flux (W/m^2)'); grid
title([fcst4t,': SHT on Footprint for ',upper(Hname),' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')],...
    'fontsize',12);
eval(['print -dpng ',odir,'\series_trackSHT_rangebar']);

% axial average SHT
Di=Di(1:end-1);
fhr=[0:1:size(Axavg,1)-1]*6;
figure('position',[520   187   497   611]);
contourf(Di,fhr,Axavg,crange); caxis([crange(1) crange(end)]); 
colorbar; colormap(redblue(njet));
set(gca,'tickdir','out','fontsize',11,'ytick',[0:12:120],'xtick',[0:25:300]);
xlabel('Distance (km)');
ylabel('Fcst time (hr)');
tt{1}=[fcst4t,': Axial Mean SHT ',upper(Hname)];
tt{2}=[' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')];
title(tt,'fontsize',12);
set(gcf,'paperpositionmode','auto');
eval(['print -dpng ',odir,'\AxialAvg_SHT']);

% save output
eval(['save N_trackSHT300km_cyc',num2str(ncyc,'%03g'),'.mat dn fhr Axavg mnSHT stdSHT']);

%clear all; close all; pack

end
