% Ngrb2_trackHFLX_R300km.m
%		reads in latent and sensible heat flux from hwrfprs_n.grb2f*, 
%       and estimate axial mean fluxes.
%
%
%-------
%	input
%-------
%			*hwrf_n.grb2f   - layer-thickness for each layer (1-15)
%           
%-------
% output
%-------
%       1. a set of 4 figures:
%               png1name=[fcst,'_',Hname,'_HFLX_Htrack'];
%               png2name=[fcst,'_',Hname,'_HFLX_Htrack_matrix'];
%               png3name=[fcst,'_',Hname,'_mnHFLX_Htrack'];
%               png4name=[fcst,'_',Hname,'_mnHFLX_Htrack_matrix'];
%								png5name=[fcst,'_',Hname,'_diffHFLX6hr_Htrack_matrix'];
%								png6name=[fcst,'_',Hname,'_diffHFLX12hr_Htrack_matrix'];
%
%       2. ascii output for an HFLX matrix as function of date (x) and distance (y).
%
%--------
% history
%--------
%   9/24/1024 Modified so to read in grib2 file. -hsk
%       1/29/2008 Modified 'diagnos_rtofs_trackHFLX.m' 
%               for Coupled/Stand-alone simulations. -hsk
%		11/19/2007 Edited by Hyun-Sook Kim
%
%------------------------------------------------------------------------
clear all; close all; 

varin1='Latent_heat_net_flux_surface';
varin2='Sensible_heat_net_flux_surface';
varin='Enthlapy';

% number of bins for discrete colorbar
lrange=[0:50:1200]; ljet=length(lrange)-1;
srange=[-250:25:300]; sjet=length(srange)-1;
hrange=[-200:50:1200]; hjet=length(hrange)-1;

% storm footprint size
eta=300;        % Storm size (km)

% flag for a hard copy of figure
isave=1;

%-------------------------------------------  Run information -------------
for ncyc=18:6:18
    
%-------------------------------------------  Run information -------------
expt='R2';

fcst4t='HWRF';               % forecast ID for title
fcst='H4Y2';               % model system ID
domain='ep';              % hurricane domain
year=2014;                  % year for interest of hurricane
mm=08;
dd=22;
hr=00;
Hname='Marie13e';             % Hurricane name
if ncyc<=0
    fname='thirteen13e';
else
    fname=lower(Hname);
end

ID=Hname(end-2:end-1);

TCname=[Hname(1:end-3),' (',upper(Hname(end-2:end)),')'];

%--- best track
%--- best HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',num2str(year),'\b',domain,ID,num2str(year),'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhy=str2num(nhc(:,35:38))/10;
nhx=str2num(nhc(:,41:45))/10;
        if domain=='wp'
            nhx=nhx*(-1);
        end
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');
best=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

%-------------------------------------------------------- for users: ------
%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
dnc=dn0+ncyc/24;
nds=datestr(dnc,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['Z:\',fcst,'\',Hname,expt,'\',yearmmddhh,'\',runID,'\atmos\'];       % run output directory
tdir=['Z:\',fcst,'\',Hname,expt,'\atcf\'];       % track directory

%--- output directory
% a folder for figure deposit 
odir=['Z:\',fcst,'\',Hname,expt,'\',yearmmddhh,'\',runID,'\Hwrf_trackHFLX\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

% output data filename
ofname=[fcst,'-',Hname,'-PtrackHFLX','.dat'];      % ASCII data filename for MLD

%--- setup date for data extraction
%  6-hour data - 
% list of input files: 
prefix=[fname,'.',datestr(dnc,'yyyymmddHH'),'.hwrfprs_n.grb*'];
eval(['!del ',ddir,prefix,'x*']);
Gfs=dir([ddir,prefix]);

%------------------------------------------------------------------
% Ancillary
%-----------
% hurricane domain: grid information
switch lower(domain)
    case {'ep'}
        lonlat=[-140 -90 5 35];
    case {'mid'}
        lonlat=[-70   -20    5    45];
        fpos1=[36   291   832   638];
    case {'east'}
        lonlat=[-90 -40 5 50];
    case {'beast'}
        lonlat=([-100 -70 15 35]);  % domain for figure
        fpos1=[36   291   832   638];
    case 'wp'
        lonlat=[100 140 0 40];
        fpos1=[36   291   832   638];      
    case 'al'
        lonlat=[-110 -75 20 40];
end
clear M

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
switch lower(frc)
    case {'hwrf'}
        dlook=dir([tdir,'\',fname,'.',datestr(dnc,'yyyymmddHH'),'.trak.hwrf.atcfunix']);
        tfile=dlook.name;
        hsk=caseread([tdir,'\',tfile]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        % find index for reference wind speed=34kt
        [C,ix]=unique(hhr);
        hsk=hsk(ix,:);
        hx=-1*str2num(hsk(:,42:45))/10;
        if domain=='wp'
            hx=hx*-1;
        end
        hy=str2num(hsk(:,36:38))/10; 
        hhr=hhr(ix);
        hdn=dnc+hhr/24;
        pmin=str2num(hsk(:,53:57));    % min Pressure (mbar)
        vmax=str2num(hsk(:,49:51));
        
        Rads=str2num(hsk(:,74:95)) *1.8;     % size [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk
    case {'gfs'}
        nhc=load('G:\PROJECT07\OFS\GFStrack\Rita.best.track.gfs.txt');
        hx=nhc(:,3); hy=nhc(:,2);
        ymdh=num2str(nhc(:,1));
        hdn=datenum(ymdh,'yyyymmddHH');
end
atcf=[hdn(:) hx(:) hy(:) vmax(:) pmin(:) Rsize(:)];

% %nhc=load('G:/NHC/nhc_Rita05.dat');           % NHC hurricane information
% %
% %   1    2   3  4  5   6   7       8         9        10   
% %  ----------------------------------------------------------
% %   year mon dy hh lat lon Prs(mb) wind(m/s) size(km) Prs_env
% %
% nhc=load(['G:/NHC/nhc_',Hname,'.dat']);           % NHC hurricane information
% hx=nhc(:,6); hy=nhc(:,5);
% hdn=datenum([nhc(:,1),nhc(:,2),nhc(:,3),nhc(:,4),repmat(0,length(hx),2)]);
% Rsize=nhc(:,end-1);           % the hurricane radius (km)
% 
%--------------------------------------------------------------------
% main section
%    1.Find a set of indicies along the hurricane track
%------------------------------------------------------

%--- figure output name:
add=num2str(eta,'%3g');
png1name=[fcst,'_',Hname,'_nestHFLX_Htrack',add];
png2name=[fcst,'_',Hname,'_nestHFLX_Htrack_matrix1',add];
png3name=[fcst,'_',Hname,'_nestHFLX_Htrack_matrix2',add];
png4name=[fcst,'_',Hname,'_nestHFLX_timeseries',add];
png5name=[fcst,'_',Hname,'_diff_nestHFLX6hr_Htrack_matrix',add];

%====================================================== Assembling data ===
%--- assembling data
Cs=load('coastline');     % coastline

Ni=301; Nj=251;     % dimension of the parent domain

% work-space
Im=repmat(nan,150,length(Gfs));       % collection of indicies each time step
mnHFLX=repmat(nan,length(Gfs),1);        % mean HFLX on a hurricane footprint                            
HFLXall=repmat(nan,[length(Gfs),Nj,Ni]); % HFLX for all 
alon=repmat(nan,[length(Gfs),Nj,Ni]);
alat=repmat(nan,[length(Gfs),Nj,Ni]);
disp(' ')
cindx=[];

LHTall=[]; % latent;
SHTall=[]; % sensible
alon=[]; alat=[];

dnx=[];
Axvar1=[]; Axvar2=[];
knt=0;
for K=1:length(Gfs)
    
    gfile=[ddir,Gfs(K).name];
    
    gc=ncdataset(gfile);
    nvar=max(size(gc.variables));
    if nvar > 14
        knt=knt+1;
        gt=gc.data('time');
        gt=double(gt);
        dni=dnc+gt/24;  clear gt
        dnx=[dnx; dni];
    
        % find indices at the hurricane eye
        q=find(hdn==dni);
        if ~isempty(q)
        cindx=[cindx; q];
        disp(sprintf('      %g ... Working with %s',K,gfile))

    % get HFLX
        ltmp=squeeze(gc.data(varin1));  % latent
        stmp=squeeze(gc.data(varin2));  % sensible
        LHTall(knt,:,:)=ltmp;
        SHTall(knt,:,:)=stmp;
    % get (lon,lat) 
        ln=(gc.data('lon'));
        lt=(gc.data('lat'));
        [hlon,hlat]=meshgrid(ln(:),lt(:));
        clear ln lt
        alon(knt,:,:)=hlon;
        alat(knt,:,:)=hlat;

        % find indices at the hurricane eye
        dr=fnddist(hlon,hlat,hx(q),hy(q));
        ks=find(dr <= eta);
        drks=dr(ks);

     % axial mean
        Dltmp=ltmp(ks); clear vtmp
        Dstmp=stmp(ks);
        Di=[0:3:300];
        otmp1=[]; otmp2=[];
        for l=1:length(Di)-1
            bb=find((drks>=Di(l) & drks<Di(l+1)));
            otmp1(l)=nanmean(Dltmp(bb));
            otmp2(l)=nanmean(Dstmp(bb));
            clear bb
        end
        Axvar1=[Axvar1; otmp1(:)']; clear otmp1
        Axvar2=[Axvar2; otmp2(:)']; clear otmp2
        Im(1:length(ks),knt)=ks(:);
    
        clear ks q dr vtmp aa gc D*tmp
        end
    end
end

% sort data
[Y,ii]=sort(dnx(:));
dnx=dnx(ii);
Axvar1=Axvar1(ii,:);
Axvar2=Axvar2(ii,:);
Im=Im(:,ii);
LHTall=LHTall(ii,:,:);
SHTall=SHTall(ii,:,:);
alon=alon(ii,:,:);
alat=alat(ii,:,:);  clear Y ii

% Adeck
[Y,ii]=sort(cindx(:));
cindx=cindx(ii);
hdn=hdn(cindx); Rsize=Rsize(cindx); Rsize=Rsize(:);
hx=hx(cindx); hy=hy(cindx); clear Y ii
atcf=atcf(cindx,:);

% find LHT,SHT,HFLX at fixed location 
Im(Im==0)=nan;
mnHFLXtrack=repmat(nan,length(cindx),length(cindx));   % a matrix of mean HFLXs 
                                % on a Hurricane footprint for the whole time period
stdHFLXtrack=mnHFLXtrack;
minHFLXtrack=mnHFLXtrack;        % min HFLX on a hurricane footprint                            
maxHFLXtrack=mnHFLXtrack;        % max HFLX on a hurricane footprint                            

mnLHTtrack=mnHFLXtrack;     % LHT
stdLHTtrack=mnHFLXtrack;
minLHTtrack=mnHFLXtrack;                             
maxLHTtrack=mnHFLXtrack;        

mnSHTtrack=mnHFLXtrack;     % SHT
stdSHTtrack=mnHFLXtrack;
minSHTtrack=mnHFLXtrack;                             
maxSHTtrack=mnHFLXtrack;        

HFLXall=LHTall+SHTall;

for k=1:size(LHTall,1)
    ssml=squeeze(LHTall(k,:,:));       % a fixed day
    ssms=squeeze(SHTall(k,:,:));       % a fixed day
    ssmh=squeeze(HFLXall(k,:,:));       % a fixed day
    for p=1:length(cindx);         % x-direction
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        a=find(~isnan(ssml(indx)));
        if ~isempty(a)
        mnLHTtrack(k,p)=nanmean(ssml(indx));     % mean LHT for pre and post storm passage
        stdLHTtrack(k,p)=nanstd(ssml(indx));      % STD
        minLHTtrack(k,p)=nanmin(ssml(indx));      % STD
        maxLHTtrack(k,p)=nanmax(ssml(indx));      % STD
        end
        clear a
        
        a=find(~isnan(ssms(indx)));
        if ~isempty(a)
        mnSHTtrack(k,p)=nanmean(ssms(indx));     % mean SHT for pre and post storm passage
        stdSHTtrack(k,p)=nanstd(ssms(indx));      % STD
        minSHTtrack(k,p)=nanmin(ssms(indx));      % STD
        maxSHTtrack(k,p)=nanmax(ssms(indx));      % STD
        end
        clear a
        
         a=find(~isnan(ssmh(indx)));
        if ~isempty(a)
        mnHFLXtrack(k,p)=nanmean(ssmh(indx));     % mean SHT for pre and post storm passage
        stdHFLXtrack(k,p)=nanstd(ssmh(indx));      % STD
        minHFLXrack(k,p)=nanmin(ssmh(indx));      % STD
        maxHFLXrack(k,p)=nanmax(ssmh(indx));      % STD
        end
        clear a
    end
end
% estimate statistics
avgLHT=diag(mnLHTtrack);
stdLHT=nanstd(stdLHTtrack);
minLHT=nanmin(minLHTtrack);
maxLHT=nanmax(maxLHTtrack);

avgSHT=diag(mnSHTtrack);
stdSHT=nanstd(stdSHTtrack);
minSHT=nanmin(minSHTtrack);
maxSHT=nanmax(maxSHTtrack);

avgHFLX=diag(mnHFLXtrack);
stdHFLX=nanstd(stdHFLXtrack);
minHFLX=nanmin(minHFLXtrack);
maxHLFX=nanmax(maxHFLXtrack);
   
% save output
eval(['save Ngrb2_trackLHT300km_cyc',num2str(ncyc,'%03g'),'.mat atcf dnx Axvar1 Axvar2 avgLHT stdLHT mnLHTtrack avgSHT stdSHT mnSHTtrack']);

%--------------------------------------------------------------------------
%   Diagnostic Part
%-------------------
%--- FIGURE 1: LHT on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.11 0.88 0.81]);
if (findstr(domain,'e') | findstr(domain,'l'));
    plot(Cs.clon-360,Cs.clat,'k'); 
else
    plot(Cs.clon,Cs.clat,'k');
end
grid; hold on;
% LHT on the storm footprint
for h=1:2:length(cindx);
    ssm=squeeze(LHTall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;
    sss=repmat(nan,size(ssm));
    sss(indx)=ssm(indx);
    
    [aa,bb]=find(~isnan(sss));
    aa=unique(aa(:));
    bb=unique(bb(:));
    
    if mod((dnx(h)-dnx(1)),0.5)==0
        %scatter(hlon(indx),hlat(indx),20,ssm(indx),'filled');
        q=find(hdn==dnx(h));
        if isempty(aa) | isempty(bb)
                    plot(hx(q),hy(q),'or','markersize',6)    
        else
            hlon=squeeze(alon(h,:,:));
            hlat=squeeze(alat(h,:,:));
            
            pcolorhsk(hlon(aa,bb),hlat(aa,bb),sss(aa,bb)); shading flat;
            caxis([lrange(1) lrange(end)]); 
            plot(hx(q),hy(q),'or','markersize',6)    
            avg=nanmean(ssm(indx));
            xx=hx(q)+Rsize(q)/sqrt(2)/150;
            yy=hy(q)+Rsize(q)/sqrt(2)/150;
            text(xx,yy,[num2str(avg,'%3.1f'),'Wm^{-2}'],'fontsize',11,'color','k','fontweight','bold');
        end
        clear xx yy avg
    end
end
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
plot(best(:,2),best(:,3),'-x','color',repmat(0.5,1,3));
axis(lonlat);
set(gca,'tickdir','out','fontsize',12); 
colormap(jet(ljet)); caxis([lrange(1) lrange(end)]);
hc=colorbar; set(hc,'tickdir','out','fontsize',12);
xlabel('Longitude (^oE)','fontsize',13);
ylabel('Latitude (^oN)','fontsize',13); box on;
title([TCname,': LHT IC=',datestr(dnc,'yyyy/mm/dd HHZ')],'fontsize',12);
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png1name]); 
end

%--- FIGURE 2: SHT on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.11 0.88 0.81]);
if (findstr(domain,'e') | findstr(domain,'l'));
    plot(Cs.clon-360,Cs.clat,'k'); 
else
    plot(Cs.clon,Cs.clat,'k');
end
grid; hold on;
% SHT on the storm footprint
for h=1:2:length(cindx);
    ssm=squeeze(SHTall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;
    sss=repmat(nan,size(ssm));
    sss(indx)=ssm(indx);
    
    [aa,bb]=find(~isnan(sss));
    aa=unique(aa(:));
    bb=unique(bb(:));
    
    if mod((dnx(h)-dnx(1)),0.5)==0
        %scatter(hlon(indx),hlat(indx),20,ssm(indx),'filled');
        q=find(hdn==dnx(h));
        if isempty(aa) | isempty(bb)
                    plot(hx(q),hy(q),'or','markersize',6)    
        else
            hlon=squeeze(alon(h,:,:));
            hlat=squeeze(alat(h,:,:));
            
            pcolorhsk(hlon(aa,bb),hlat(aa,bb),sss(aa,bb)); shading flat;
            caxis([srange(1) srange(end)]); 
            plot(hx(q),hy(q),'or','markersize',6)    
            avg=nanmean(ssm(indx));
            xx=hx(q)+Rsize(q)/sqrt(2)/150;
            yy=hy(q)+Rsize(q)/sqrt(2)/150;
            text(xx,yy,[num2str(avg,'%3.1f'),'Wm^{-2}'],'fontsize',11,'color','k','fontweight','bold');
        end
        clear xx yy avg
    end
end
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
plot(best(:,2),best(:,3),'-x','color',repmat(0.5,1,3));
axis(lonlat); set(gca,'tickdir','out','fontsize',12);
colormap(jet(sjet)); 
hc=colorbar; set(hc,'tickdir','out','fontsize',12);
xlabel('Longitude (^oE)','fontsize',13);
ylabel('Latitude (^oN)','fontsize',13); box on;
title([TCname,': SHT IC=',datestr(dnc,'yyyy/mm/dd HHZ')],'fontsize',12);
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',strrep(png1name,'LHT','SHT')]); 
end

%--- FIGURE 2: LHT + SHT on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.11 0.88 0.81]);
if (findstr(domain,'e') | findstr(domain,'l'));
    plot(Cs.clon-360,Cs.clat,'k'); 
else
    plot(Cs.clon,Cs.clat,'k');
end
grid; hold on;
% SHT on the storm footprint
for h=1:2:length(cindx);
    ssm=squeeze(HFLXall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;
    sss=repmat(nan,size(ssm));
    sss(indx)=ssm(indx);
    
    [aa,bb]=find(~isnan(sss));
    aa=unique(aa(:));
    bb=unique(bb(:));
    
    if mod((dnx(h)-dnx(1)),0.5)==0
        %scatter(hlon(indx),hlat(indx),20,ssm(indx),'filled');
        q=find(hdn==dnx(h));
        if isempty(aa) | isempty(bb)
                    plot(hx(q),hy(q),'or','markersize',6)    
        else
            hlon=squeeze(alon(h,:,:));
            hlat=squeeze(alat(h,:,:));
            
            pcolorhsk(hlon(aa,bb),hlat(aa,bb),sss(aa,bb)); shading flat;
            caxis([hrange(1) hrange(end)]); 
            plot(hx(q),hy(q),'or','markersize',6)    
            avg=nanmean(ssm(indx));
            xx=hx(q)+Rsize(q)/sqrt(2)/150;
            yy=hy(q)+Rsize(q)/sqrt(2)/150;
            text(xx,yy,[num2str(avg,'%3.1f'),'Wm^{-2}'],'fontsize',11,'color','k','fontweight','bold');
        end
        clear xx yy avg
    end
end
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
plot(best(:,2),best(:,3),'-x','color',repmat(0.5,1,3));
axis(lonlat); set(gca,'tickdir','out','fontsize',12);
 colormap(jet(hjet)); 
hc=colorbar; set(hc,'tickdir','out','fontsize',12);
xlabel('Longitude (^oE)','fontsize',13);
ylabel('Latitude (^oN)','fontsize',13); box on;
title([TCname,': (LHT+SHT) IC=',datestr(dnc,'yyyy/mm/dd HHZ')],'fontsize',12);
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',strrep(png1name,'LHT','HFLX')]); 
end


%--- FIGURE group 2: footprint: Stamp (6x6) Plot
%
% A) indiviual subplot locations for a 10x10 figure
np=10;
pd=0.084;
pys=0.085+pd*[0:np-1];
pxs=0.085+pd*[0:np-1];
[Px,Py]=meshgrid(pxs,pys);
Px=flipud(Px);
Py=flipud(Py);
axs=[Px(:),Py(:),repmat(pd,np*np,2)];        % each figure location

rscale=4;       % box size (1*rscale x 1*rscale)

% plotting LHT
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([lrange;lrange]); caxis([lrange(1) lrange(end)]); colormap(jet(ljet));
set(gca,'yticklabel',[],'xtick',[1:length(lrange)],'xticklabel',[lrange]); 
title([fcst4t,': Nest Domain LHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
for k=1:np;      % y-direction
    ssm=squeeze(LHTall(k,:,:));       % a fixed day
    for p=1:np;         % x-direction
        r=(k-1)*np+p;
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   indx=Im(a,p); clear a;
        b=find(hdn==dnx(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnLHTtrack(k,p))==1
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
            hlon=squeeze(alon(k,:,:)); 
            hlat=squeeze(alat(k,:,:));
            if (length(ia)>=2 & length(ja)>=2)
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([lrange(1) lrange(end)]); colormap(jet(ljet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if k==p
         text(-0.15,0.8*rscale,[num2str(mnLHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,'fontweight','bold');
        end
        clear ia ja 
    end
    xlabel(datestr(dnx(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png2name]); 
end
% Stamp figure - 2
% B) indiviual subplot locations for a 10x10 figure
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([lrange;lrange]); caxis([lrange(1) lrange(end)]); colormap(jet(ljet));
set(gca,'yticklabel',[],'xtick',[1:length(lrange)],'xticklabel',[lrange]); 
title([fcst4t,': Nest Domain LHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
for k=1+np:min(2*np,length(dnx));      % y-direction
    ssm=squeeze(LHTall(k,:,:));       % a fixed day
    for p=np+1:min(2*np,length(dnx));         % x-direction
        r=(k-1-np)*np+(p-np);
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        
        b=find(hdn==dnx(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnLHTtrack(k,p))==1 
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss));
            ia=unique(ia); ja=unique(ja); 
            if (length(ia)>=2 & length(ja)>=2)
            hlon=squeeze(alon(k,:,:));
            hlat=squeeze(alat(k,:,:));
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([lrange(1) lrange(end)]); colormap(jet(ljet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if (k==p)
        text(-0.15,0.8*rscale,[num2str(mnLHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==np+1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
    end
    xlabel(datestr(dnx(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    clear ia ja 
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png3name]); 
end

%=============================
% FIGURE GROUP 2 - continued
%----------------------------
% plotting SHT
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([srange;srange]); caxis([srange(1) srange(end)]); colormap(jet(sjet));
set(gca,'yticklabel',[],'xtick',[1:length(srange)],'xticklabel',[srange]); 
title([fcst4t,': Nest Domain LHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
for k=1:np;      % y-direction
    ssm=squeeze(SHTall(k,:,:));       % a fixed day
    for p=1:np;         % x-direction
        r=(k-1)*np+p;
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   indx=Im(a,p); clear a;
        b=find(hdn==dnx(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnSHTtrack(k,p))==1
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
            hlon=squeeze(alon(k,:,:)); 
            hlat=squeeze(alat(k,:,:));
            if (length(ia)>=2 & length(ja)>=2)
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([srange(1) srange(end)]); colormap(jet(sjet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if k==p
         text(-0.15,0.8*rscale,[num2str(mnSHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,'fontweight','bold');
        end
        clear ia ja 
    end
    xlabel(datestr(dnx(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',strrep(png2name,'LHT','SHT')]); 
end
% Stamp figure - 2 for SHT
% B) indiviual subplot locations for a 10x10 figure
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([srange;srange]); caxis([srange(1) srange(end)]); colormap(jet(sjet));
set(gca,'yticklabel',[],'xtick',[1:length(srange)],'xticklabel',[srange]); 
title([fcst4t,': Nest Domain SHT for ',TCname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
for k=1+np:min(2*np,length(dnx));      % y-direction
    ssm=squeeze(SHTall(k,:,:));       % a fixed day
    for p=np+1:min(2*np,length(dnx));         % x-direction
        r=(k-1-np)*np+(p-np);
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        
        b=find(hdn==dnx(p));                     % concurrent time
        sss=nan(size(ssm));
        if isnan(mnSHTtrack(k,p))==1 
            plot(hx(b),hy(b),'.'); 
        else
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss));
            ia=unique(ia); ja=unique(ja); 
            if (length(ia)>=2 & length(ja)>=2)
            hlon=squeeze(alon(k,:,:));
            hlat=squeeze(alat(k,:,:));
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
            end
        end
        caxis([srange(1) srange(end)]); colormap(jet(sjet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        if (k==p)
        text(-0.15,0.8*rscale,[num2str(mnSHTtrack(k,p),'%4.1f')],'fontsize',9,'fontweight','bold');
        end
        if k==np+1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
    end
    xlabel(datestr(dnx(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    clear ia ja 
    box on
end
text(-2.5,-0.725,pwd,'fontsize',9,'color','r','units','normalized')
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',strrep(png3name,'LHT','SHT')]); 
end



%==================================
% FIGURE GROUP 2
%---------------
% axial average LHT
Di=[0:3:300];
Di=Di(1:end-1); nclimit=[0:100:lrange(end)];
fhr=[0:1:size(Axvar1,1)-1]*3;
figure('position',[520   187   497   611]);
[cs,h]=contourf(Di,fhr,Axvar1,nclimit); caxis([nclimit(1) nclimit(end)]); 
colorbar; nclr=length(nclimit)-1; colormap(redblue(nclr));
clabel(cs,h,'LabelSpacing',500);
set(gca,'tickdir','out','fontsize',11,'ytick',[0:12:120],'xtick',[0:25:300]);
xlabel('Distance (km)');
ylabel('Fcst time (hr)');
tt{1}=[fcst4t,': Axial Mean LHT ',upper(Hname)];
tt{2}=[' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')];
title(tt,'fontsize',12);
set(gcf,'paperpositionmode','auto');
eval(['print -dpng ',odir,'\AxialAvg_LHT']);

% axial average SHT
Di=[0:3:300];
Di=Di(1:end-1); nclimit=[srange(1):100:srange(end)];
fhr=[0:1:size(Axvar2,1)-1]*3;
figure('position',[520   187   497   611]);
[cs,h]=contourf(Di,fhr,Axvar2,nclimit); caxis([nclimit(1) nclimit(end)]); 
colorbar; nclr=length(nclimit)-1; colormap(redblue(nclr));
clabel(cs,h,'LabelSpacing',500);
set(gca,'tickdir','out','fontsize',11,'ytick',[0:12:120],'xtick',[0:25:300]);
xlabel('Distance (km)');
ylabel('Fcst time (hr)');
tt{1}=[fcst4t,': Axial Mean SHT ',upper(Hname)];
tt{2}=[' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')];
title(tt,'fontsize',12);
set(gcf,'paperpositionmode','auto');
eval(['print -dpng ',odir,'\AxialAvg_SHT']);

% axial average LHT+SHT
Di=[0:3:300];
Di=Di(1:end-1); nclimit=[srange(1):100:lrange(end)];
fhr=[0:1:size(Axvar2,1)-1]*3;
figure('position',[520   187   497   611]);
[cs,h]=contourf(Di,fhr,Axvar1+Axvar2,nclimit); caxis([nclimit(1) nclimit(end)]); 
colorbar; nclr=length(nclimit)-1; colormap(redblue(nclr));
clabel(cs,h,'LabelSpacing',500);
set(gca,'tickdir','out','fontsize',11,'ytick',[0:12:120],'xtick',[0:25:300]);
xlabel('Distance (km)');
ylabel('Fcst time (hr)');
tt{1}=[fcst4t,': Axial Mean of (LHT+SHT)',upper(Hname)];
tt{2}=[' (IC=',datestr(dnc,'HH:00 UTC yyyy/mm/dd)')];
title(tt,'fontsize',12);
set(gcf,'paperpositionmode','auto');
eval(['print -dpng ',odir,'\AxialAvg_HFLX']);

%clear all; close all; pack

end
