clear all; close all; 
res=3;   %model resolution in km
srch_wid=63;   %search box (to determine circulation center each level) half width in km
radius=420;  % plotting radius in km
pi=3.1415926;

%-------------------------------------------  Run information -------------
expt='R1';

fcst4t='HWRF';               % forecast ID for title
fcst='H4Y2';               % model system ID
domain='ep';              % hurricane domain
year=2014;                  % year for interest of hurricane
mm=08;
dd=22;
hr=00;
Hname='Marie13e';             % Hurricane name
ID=Hname(end-2:end-1);
TCname=[Hname(1:end-3),' (',upper(Hname(end-2:end)),')'];

for ncyc=18:6:18    
    if ncyc<=0
        fname='thirteen13e';
    else
        fname=lower(Hname);
    end

%--- HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',num2str(year),'\b',domain,ID,num2str(year),'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhy=str2num(nhc(:,35:38))/10;
nhx=(-1)*str2num(nhc(:,41:45))/10;
        if domain=='wp'
            nhx=nhx*(-1);
        end
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');
atcf=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

%-------------------------------------------------------- for users: ------
%  Number of cycle
% ncyc=108;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
dnc=dn0+ncyc/24;
nds=datestr(dnc,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['Z:\',fcst,'\',Hname,expt,'\',yearmmddhh,'\',runID,'\atmos\'];       % run output directory
tdir=['Z:\',fcst,'\',Hname,expt,'\atcf\'];       % track directory

%--- output directory
% a folder for figure deposit 
odir=['Z:\',fcst,'\',Hname,expt,'\',yearmmddhh,'\',runID,'\Hwrf_Vtr\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

%--- setup date for data extraction
%  6-hour data - 
% list of input files: 
prefix=[fname,'.',datestr(dnc,'yyyymmddHH'),'.hwrfprs_n.grb2*'];
eval(['!del ',ddir,prefix,'x*']);
Gfs=dir([ddir,prefix]);

% get data and plot
for K=1:length(Gfs)
    gtmp=[ddir,Gfs(K).name];
    nc=ncdataset(gtmp);

    %datestr(atcf(:,1))
    lon=nc.data('lon');
    lat=nc.data('lat');
    [x,y]=meshgrid(lon,lat);
    
    u10m=squeeze(squeeze(nc.data('u-component_of_wind_height_above_ground')));
    v10m=squeeze(squeeze(nc.data('v-component_of_wind_height_above_ground')));

    gt=double(nc.data('time'));
    dni=dnc+gt/24;
    aa=find(atcf(:,1)==dni);
    if ~isempty(aa)
        cen_x=atcf(aa,2);
        cen_y=atcf(aa,3);  %atcf center

        ugrd=squeeze(nc.data('u-component_of_wind_isobaric'));
        vgrd=squeeze(nc.data('v-component_of_wind_isobaric'));
        prs_level=nc.data('isobaric');

        vmax=atcf(aa,5)*0.5144;    %get vmax m/s
        if (vmax>20)    % for weak storm only plot up to 500 hPa; otherwise 300 hPa 
            pres_top=30000;
        else
            pres_top=50000;
        end
         ut_za=nan(find(prs_level==pres_top)+1,radius/3+1); % declare radius-azimuth ut and ur array
         ur_za=nan(find(prs_level==pres_top)+1,radius/3+1);

        % from 850hPa to pres_top; then from surface (10m) to 850 hPa 
        cprs=[];
        for i_prs=[find(prs_level==85000):find(prs_level==pres_top), 0:find(prs_level==85000)-1]
            cprs=[cprs; i_prs];
            if (i_prs==0)
                ugrd_2d=u10m;
                vgrd_2d=v10m;
                prs_level=[101000;prs_level];
            else
                ugrd_2d=ugrd(i_prs,:,:);
                ugrd_2d=squeeze(ugrd_2d);
                vgrd_2d=vgrd(i_prs,:,:);
                vgrd_2d=squeeze(vgrd_2d);
            end
        cen_x_grd=near(lon,cen_x); % get the nearest grid point to ATCF center
        cen_y_grd=near(lat,cen_y);

        % search min wind in a 150km by 150km box for circulation center
        istart=cen_x_grd-srch_wid/res;
        iend=cen_x_grd+srch_wid/res;
        jstart=cen_y_grd-srch_wid/res;
        jend=cen_y_grd+srch_wid/res;

        spd_box=sqrt(ugrd_2d(jstart:jend,istart:iend).^2+vgrd_2d(jstart:jend,istart:iend).^2);
        spdmin=nanmin(spd_box(:)); clear spd_box
        [ceny_new,cenx_new]=find(spdmin);
        cenx_ind=cen_x_grd+(cenx_new-srch_wid/res-1);
        ceny_ind=cen_y_grd+(ceny_new-srch_wid/res-1);
        cenx_new=double(lon(cenx_ind));
        ceny_new=double(lat(ceny_ind));

        % for levels lower than 850 hPa, use center at 850hPa  
        if (i_prs==find(prs_level==85000))
            cenx_850 = cenx_new;
            ceny_850 = ceny_new;
        end

        if (i_prs<find(prs_level==85000))
            cenx_new = cenx_850;
            ceny_new = ceny_850;
            spd_min=sqrt(ugrd_2d(ceny_ind,cenx_ind).^2+vgrd_2d(ceny_ind,cenx_ind).^2);
        end

        % define polar coordinate 
        for i=1:360  % bearing loop
            % bearing is from north clockwise
            brng=i*1;
            for j=1:radius/res  % distance loop
                dest=lat_lon_dist(cenx_new,ceny_new,j*res,brng); % destination lat and lon
                dest_lat(i,j)=dest(1);
                dest_lon(i,j)=dest(2);
            end
        end

        ugrd_2d_polar=interp2(x,y,ugrd_2d , dest_lon, dest_lat);  % interpolate to polar
        vgrd_2d_polar=interp2(x,y,vgrd_2d , dest_lon, dest_lat);  % interpolate to polar

        % get tangential wind ut and radial wind ur
        ut=nan(360,radius/res);
        ur=nan(360,radius/res);
        for i=1:360  % bearing loop
            % bearing is from north clockwise
            brng=i*1/180*pi;
            ut(i,:)=-ugrd_2d_polar(i,:)*cos(brng)+vgrd_2d_polar(i,:)*sin(brng);
            ur(i,:)=ugrd_2d_polar(i,:)*sin(brng)+vgrd_2d_polar(i,:)*cos(brng);
        end
        for j=2:radius/3+1  % distance loop
            ut_az(i_prs+1,j)=sum(ut(:,j-1))/360;
            ur_az(i_prs+1,j)=sum(ur(:,j-1))/360;
        end 
        ut_az(i_prs+1,1)=spdmin;
        ur_az(i_prs+1,1)=spdmin;

        end      % finished the i_prs loop.
        
        %----------------------------------
        % Diagnostic Plot
        %-----------------
        rs=[0:1:radius/res]*res;  % [km]
        ix=sort(cprs)+1;
        zkm=P2zkm(prs_level(ix),101000);
        clear ix;
        
        figure('position',[41   318   711   572]);
        axes('position',[0.09 0.1 0.4 0.79]);
        [cs,h]=contour(rs,zkm,ut_az,[0:1:ceil(max(ut_az(:)))],'-r','linewidth',1.5); hold on
        clabel(cs,h,'LabelSpacing',400); clear cs h
        [cs,h]=contour(rs,zkm,ut_az,[floor(min(ut_az(:))):1:-1],'--b','linewidth',1.5);
        clabel(cs,h,'LabelSpacing',400); clear cs h
        set(gca,'fontsize',11,'tickdir','out','xlim',[0 300],'xtick',[0:50:300]);
        ylabel('height (km)'); xlabel('distance (km)');
        text(0.02,0.93,'(A) tangential','units','normalized','fontsize',15,'fontweight','bold');
        
        axes('position',[0.55 0.1 0.4 0.79]);
        [cs,h]=contour(rs,zkm,ur_az,[0:1:ceil(max(ur_az(:)))],'-r','linewidth',1.5); hold on
        clabel(cs,h,'LabelSpacing',400); clear cs h
        [cs,h]=contour(rs,zkm,ur_az,[floor(min(ur_az(:))):1:-1],'--b','linewidth',1.5);
        clabel(cs,h,'LabelSpacing',400); clear cs h
        caxis([floor(min(ur_az(:))) ceil(max(ur_az(:)))]); 
        set(gca,'fontsize',11,'tickdir','out','xlim',[0 300],'xtick',[0:50:300]);
        set(gca,'yticklabel',[]);
        ylabel('height (km)'); xlabel('distance (km)');
        text(0.02,0.93,'(B) radial','units','normalized','fontsize',15,'fontweight','bold');
        
        txt{1}=[TCname];
        txt{2}=['Wind Velocity (IC=',datestr(dnc,'yyyy/mm/dd HHZ)')];
        txt{3}=['Valid @',datestr(dni,'yyyy/mm/dd HHZ')];
        text(-0.05,1.08,txt,'units','normalized','fontsize',15,'HorizontalAlignment','center');
               
        ofile=['Ngrb2_Vtr_IC',datestr(dnc,'mmddHH'),'_v',datestr(dni,'ddHH')];
        eval(['print -dpng ',ofile]);
        
        %------------------------------------------------------------------
        % save output
        %--------------
        eval(['save ',ofile,' zkm ur_az ut_az']);
    end
    clear lon lat *grd* ur* ut* pr* cen* cprs *10m dest* spd*n istart iend i_prs jend jstart 
end
end


