% Tsect_track2.m
%		read in a set of HurrHYCOM grib files, and
%       produce a set of the T section along a hurricane track. 
%
%-------
%	input
%-------
%			*.grb   - GRIB files 
%           nhc_Rita05.dat        - NHC disseminated hurricane information
%
%-------
% output
%-------
%           find temperature section on the hurricane footprint
%
%--------
% history
%--------
%   2/25/2008 Modified 'Tsect_track.m' to read in a set of grib files,
%       instead of *.mat. -hsk
%   11/27/2007 Edited by Hyun-Sook Kim
%------------------------------------------------------------------------

for ncyc=72:6:150
    
isave=1;            % logic to save a plot
tplot=0;            % temperature plot for superimposing on density section 
                    % contour plot
tsample=6;  % temporal sampling intervals
                    
%-------------------------------------------  Run information -------------
fcst='NAOMIex';               % model system ID
domain='west';              % hurricane domain
year=2008;                  % year for interest of hurricane
mm=08;
dd=25;
hr=12;
Hname='fGustav08';             % Hurricane name

%-------------------------------------------------------- for users: ------
%  Number of cycle
% ncyc=60;
%ncyc=0;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
nds=datestr(dn0+ncyc/24,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['D:\NAOMIex\',Hname,'\',yearmmddhh,'\',runID,'\ocean\'];       % run output directory

%--- output directory
% a folder for figure deposit 
odir=['D:\NAOMIex\',Hname,'\',yearmmddhh,'\',runID,'\Tsect_track2\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

%--- output data filename
% ofname=[fcst,'-',Hname,'-SST','.dat'];      % ASCII data filename for MLD

%--- setup date for data extraction
%  6-hour data - 
Dr=dir([ddir,'*.grb']);
dn=[];
if length(Dr)==0
    disp([' ... No Data in ',ddir,'...'])
else
  dn=[];
  gfiles=[];
  N=0;
  for K=1:length(Dr)
      ftmp=Dr(K).name;
      shr=ftmp(end-5:end-4);
      if mod(str2num(shr),tsample)==0; 
          N=N+1;
          syd=ftmp(end-9:end-7);
          gfiles{N}=Dr(K).name;
          gd=greg2((str2num(syd)-1)+str2num(shr)/24,year);
          dn(N)=datenum(gd);
          clear gd 
      end
  end
end

%------------------------------------------------------------------
% Ancilary
%-----------
% hurricane domain: grid information
switch lower(domain)
    case {'west'}
        M=load(['ncep12_01_hur_west_grid.mat']);
        hlon=M.hlon; hlat=M.hlat;
    case {'east'}
        M=load(['ncep12_03_hur_east_grid.mat']);
        hlon=M.elon; hlat=M.elat;
end

%--------------------------------------------------------------------
% main section
%    1.Find a set of indicies along the hurricane track
%------------------------------------------------------
nlayers=15;

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
switch lower(frc)
    case {'hwrf'}
        dlook=dir([ddir,'\trak.hwrf.atcfunix.*']);
        tfile=dlook.name;
        hsk=caseread([ddir,'\',tfile]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        knt=str2num(hsk(:,65:66));      % reference knot
        % find index for reference wind speed=34kt
        ix=find(knt==34);
        hsk=hsk(ix,:);
        hx=-1*str2num(hsk(:,42:45))/10;
        hy=str2num(hsk(:,36:38))/10; 
        hhr=hhr(ix);
        hdn=datenum(hsk(:,9:18),'yyyymmddHH')+hhr/24;
        Rads=str2num(hsk(:,74:95))*1.8;     % size: [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk
    case {'gfs'}
        nhc=load('G:\PROJECT07\OFS\GFStrack\Rita.best.track.gfs.txt');
        hx=nhc(:,3); hy=nhc(:,2);
        ymdh=num2str(nhc(:,1));
        hdn=datenum(ymdh,'yyyymmddHH');
end
hdni=interp1(hdn,hdn,dn,'linear');
%nhc=load('G:/NHC/nhc_Rita05.dat');           % NHC hurricane information
%
%   1    2   3  4  5   6   7       8         9        10   
%  ----------------------------------------------------------
%   year mon dy hh lat lon Prs(mb) wind(m/s) size(km) Prs_env
%
%nhc=load(['G:/NHC/nhc_',Hname,'.dat']);           % NHC hurricane information
%hx=nhc(:,6); hy=nhc(:,5);
%hdn=datenum([nhc(:,1),nhc(:,2),nhc(:,3),nhc(:,4),repmat(0,length(hx),2)]);
%Rsize=nhc(:,end-1);           % the hurricane radius (km)

% figure output name:
png1name=[odir,Hname,'_Tsect_track1'];
png2name=[odir,Hname,'_Tsect_track2'];
png3name=[odir,Hname,'_Tsect_track3'];
png4name=[odir,Hname,'_Tprofile4_fig'];

%--------------- employ interpolation ---------------
%- build 3-D work space for depth and density fields
hxi=interp(hx,9);
hyi=interp(hy,9);

tri=delaunay(hlon,hlat);
Kindx=dsearch(hlon,hlat,tri,hxi,hyi);

% work-space
Z3d=repmat(nan,[length(dn),nlayers,length(Kindx)]);
D3d=repmat(nan,[length(dn),nlayers,length(Kindx)]);

disp(' ')
for nd=1:length(dn)
    
    gfile=[ddir,gfiles{nd}];
    
    disp(sprintf('   ... Working on %g/%g',nd,length(dn)))
    disp(['                data: ',gfile])
    
    %--- layer depths
    ztmp=getgrib(gfile,'LAYTH',[1 -1 -1],[nlayers -1 -1]);
    zdat=ztmp.data;                     % [481 x 361 x layers]
%     zdat=permute(zdat,[3 2 1]);         % [layers x 361 x 481]
    zout=[];
    for k=1:nlayers
        zz=squeeze(zdat(:,:,k));
        zz=zz';                     % [361 x 481]
        zs=zz(:);
        zout=[zout zs];             % [173641 x nlayers]
        clear zz zs
    end
    Zs=cumsum(zout,2);            % actual depths by adding thickness each layer
    ztmp=Zs(Kindx,:)';
    ztmp(ztmp>1e+10)=nan;
    Z3d(nd,:,:)=ztmp;
        clear ztmp zout Zs
        
    %--- density
    ttmp=getgrib(gfile,'WTMPC',[2 -1 -1],[nlayers+1 -1 -1]);  % temporarily, pot_temp is being used.
%     tdat=ttmp.data;
%     stmp=getgrib(gfile,'SALIN',[2 -1 -1],[nlayers -1 -1]);
%     sdat=stmp.data;
%     zdat=zdat';
%     dtmp=sw_temp(sdat(:),tdat(:),zdat(:),2000);
%     clear ttmp stmp
    dtmp=ttmp.data;
    
    ddat=dtmp;                     % [481 x 361 x layers]
    Ds=[];
    for k=1:nlayers
        dd=squeeze(ddat(:,:,k));
        dd=dd';                     % [361 x 481]
        ds=dd(:);
        Ds=[Ds ds];             % [173641 x nlayers]
        clear dd ds
    end
    clear dtmp
    
    dtmp=Ds(Kindx,:)';
    dtmp(dtmp>1e+10)=nan;
    D3d(nd,:,:)=dtmp;
        clear dtmp ddat Ds
        clear gfile
end     
    
T3d=D3d;
% save temp_sect_track.mat T3d Z3d

disp(' ')
%--------------------------------------------------------------------------
%   Diagnostic Part
%-------------------

% T-sections on a track each day: (3x2) figure
% individual location
pd=0.14;
pys=0.78+(-pd)*[0:5];
axs=[repmat(0.09,6,1),pys(:),repmat(0.83,6,1),repmat(pd,6,1)];        % each figure location

xs=fnddist(hxi(2:end),hyi(2:end),hxi(1:end-1),hyi(1:end-1));
xs=[0 xs(:)'];
xs=cumsum(xs);
Xs=repmat(xs,nlayers,1);

q=ismember(hdn,dn);
q=find(q==1);
ihx=hx(q); ihy=hy(q);
iRsiz=Rsize(q);

%===================================== distance of the storm center
%===========================
Rcindx=[];      % index for the storm center
Rindx=[];       % index for the rear side of the storm center
Reye=[];        % distance for the storm center
Rr=[];          % size
for k=1:min(length(hdn),length(dn))
    q=find(hdn==dn(k));
    i=fnddist(hxi,hyi,hx(q),hy(q));
    [junk,K]=min(i);
    Rs=xs(K);   clear junk 

    Reye=[Reye Rs];     % distance for the storm center
    
    Rr=[Rr Rsize(q)];   % maximum size
    
    Rcindx=[Rcindx K];  % index for the storm center in time
    
    j=find(i<Rsize(q));
    M=min(j);
    Rindx=[Rindx M];            % index for the rear side of the storm center in time   
end

%===================================== plotting ===========================
% ancilary for plotting

% color limits and range
crange=[15:1:34];
njet=20;

% division for track plots
dr=fnddist(hx(2:end),hy(2:end),hx(1:end-1),hy(1:end-1));
R=cumsum(dr);
clear dr;

Rdiv=ceil(max(R)/3/100)*100;

%--- FIGURE 1: first 36 hrs
figure('position',[220  49  770 866]);
axes('position',[0.09 0.96 0.83 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([runID,': Temp-section (^oC) for ',Hname,'(',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');

for k=1:6
    axes('position',axs(k,:));
    xlimits=[0 1.5*Rdiv];
    
    q=find(hdn==dn(k));
    i=fnddist(hxi,hyi,hx(q),hy(q));
    [junk,K]=min(i);
    Rs=xs(K);   clear junk 

    temp=squeeze(D3d(k,:,:));       % temperature 
    dept=-squeeze(Z3d(k,:,:));      % depths
    
    pcolorhsk(Xs,dept,temp); shading flat; colormap(jet(njet)); caxis([crange(1) crange(end)]);
    set(gca,'xlim',xlimits,'xtick',[xlimits(1):100:xlimits(2)],...
    'ytick',[-300:100:0],'ylim',[-300 0],...
    'tickdir','out','fontsize',10); 
    grid; hold on; 
    contour(Xs,dept,temp,[26 26],'k');
    if k~=6
        set(gca,'xticklabel',[]);
    end
    plot(repmat(Rs,2,1),[-300;0],'-k','linewidth',1.8); % the hurricane center position
    plot(repmat(Rs-Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    plot(repmat(Rs+Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    % location for 6-hr before
    ylabel(datestr(dn(k),'mm/dd HHZ'),'fontsize',11,'fontweight','bold')
    xlabel('distance (km)')
    if k>=2;
        plot(repmat(Reye(k-1),2,1),[-300;0],'--k'); % the hurricane center position
        plot(repmat(Reye(k-1)-Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
        plot(repmat(Reye(k-1)+Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
    end
end
set(gcf,'paperpositionmode','auto');

if isave; 
    eval(['print -dpng ',png1name]);
end

%--- FIGURE 2: second 36 (=72) hrs
figure('position',[220  49  770 866]);
axes('position',[0.09 0.96 0.83 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([runID,': Temp-section (^oC) for ',Hname,'(',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');

% gether history of index for the storm center 
for k=6+1:12
    p=k-6;   
    axes('position',axs(p,:));
    xlimits=[0 1.5*Rdiv]+0.5*Rdiv;
    
    q=find(hdn==dn(k));
    i=fnddist(hxi,hyi,hx(q),hy(q));
    [junk,K]=min(i);
    Rs=xs(K);   clear junk 

    temp=squeeze(D3d(k,:,:));       % temperature 
    dept=-squeeze(Z3d(k,:,:));      % depths
    pcolorhsk(Xs,dept,temp); shading flat; colormap(jet(njet)); caxis([crange(1) crange(end)]);
    set(gca,'xlim',xlimits,'xtick',[xlimits(1):100:xlimits(2)],...
    'ytick',[-300:100:0],'ylim',[-300 0],...
    'tickdir','out','fontsize',10); grid
    hold on; 
    contour(Xs,dept,temp,[26 26],'k');
    if p~=6
        set(gca,'xticklabel',[]);
    end
    plot(repmat(Rs,2,1),[-300;0],'-k','linewidth',1.8); % the hurricane center position
    plot(repmat(Rs-Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    plot(repmat(Rs+Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    ylabel(datestr(dn(k),'mm/dd HHZ'),'fontsize',11,'fontweight','bold')
    xlabel('distance (km)')
        plot(repmat(Reye(k-1),2,1),[-300;0],'--k'); % the hurricane center position
        plot(repmat(Reye(k-1)-Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
        plot(repmat(Reye(k-1)+Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
end
set(gcf,'paperpositionmode','auto');

if isave; 
    eval(['print -dpng ',png2name]);
end

%--- FIGURE 3: third 36 (=108) hrs
figure('position',[220  49  770 866]);
axes('position',[0.09 0.96 0.83 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([runID,': Temp-section (^oC) for ',Hname,'(',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');

% gether history of index for the storm center 
for k=12+1:18
    p=k-12;   
    axes('position',axs(p,:));
    xlimits=[0 1.5*Rdiv]+1*Rdiv;

    q=find(hdn==dn(k));
    i=fnddist(hxi,hyi,hx(q),hy(q));
    [junk,K]=min(i);
    Rs=xs(K);   clear junk 
    
    temp=squeeze(D3d(k,:,:));       % temperature 
    dept=-squeeze(Z3d(k,:,:));      % depths
    pcolorhsk(Xs,dept,temp); shading flat; colormap(jet(njet)); caxis([crange(1) crange(end)]);
    set(gca,'xlim',xlimits,'xtick',[xlimits(1):100:xlimits(2)],...
    'ytick',[-300:100:0],'ylim',[-300 0],...
    'tickdir','out','fontsize',10); grid
    hold on; 
    contour(Xs,dept,temp,[26 26],'k');
    if p~=6
        set(gca,'xticklabel',[]);
    end
    plot(repmat(Rs,2,1),[-300;0],'-k','linewidth',1.8); % the hurricane center position
    plot(repmat(Rs-Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    plot(repmat(Rs+Rsize(q)/2,2,1),[-300;0],'-','color',repmat(0.8,1,3),'linewidth',1.8);
    ylabel(datestr(dn(k),'mm/dd HHZ'),'fontsize',11,'fontweight','bold')
    xlabel('distance (km)')
        plot(repmat(Reye(k-1),2,1),[-300;0],'--k'); % the hurricane center position
        plot(repmat(Reye(k-1)-Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
        plot(repmat(Reye(k-1)+Rr(k-1)/2,2,1),[-300;0],'--','color',repmat(0.8,1,3));
end
set(gcf,'paperpositionmode','auto');

if isave; 
    eval(['print -dpng ',png3name]);
end

%--------------------------------------------------------------------------

%-------------------------------------- T-profiles before, during and after
%   the passge of the storm
%---------------------------
%
%        after          during              before
%       (t2,indx1)      (t1,indx1)      (t0,indx1)
%       (t3,indx2)      (t2,indx2)      (t1,indx2)
%       (t4,indx3)      (t3,indx3)      (t2,indx3)
%           ...           ...               ...

for K=2:length(Rindx)-1
    
    % (T,Z) before the passage of the storm
    Tb=squeeze(D3d(K-1,:,Rindx(K)));     
    Zb=squeeze(Z3d(K-1,:,Rindx(K)));
    
    % (T,Z) during the passage of the storm
    Td=squeeze(D3d(K,:,Rindx(K)));     
    Zd=squeeze(Z3d(K,:,Rindx(K)));

    % (T,Z) after the passage of the storm
    Ta=squeeze(D3d(K+1,:,Rindx(K)));     
    Za=squeeze(Z3d(K+1,:,Rindx(K)));

    % text location for a hurricane position
    loc=[num2str(ihx(K),'%6.2f'),'^oW,',num2str(ihy(K),'%6.2f'),'^oN'];
          
    % plotting
    %---------
    figure('position',[17   420   360   505]);
    h1=plot(Td,-Zd,'-xk','linewidth',1.5); hold on
    h2=plot(Tb,-Zb,'-xb',Ta,-Za,'-xr'); grid
    set(gca,'xlim',[10 35],'ylim',[-500 0],'tickdir','out','fontsize',11); 
    ylabel('depth (m)');
    xlabel('Temperature (^oC)')
    ttl{2}=[runID];
    ttl{1}=['T profile for ',Hname,'(',yearmmddhh,')'];
    title(ttl,'fontsize',12,'fontweight','bold');
    text(0.07,0.92,[Hname,' @(',loc,')'],'color','m',...
        'fontweight','bold','fontsize',11,'units','normalized');
    legend([h1,h2(:)'],['during: ',datestr(dn(K),'yyyy/mm/dd HH:00')],'6-hr before','6-hr after',4);
    
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',png4name,'_',num2str(K)]);
    
end
  
clear all; close all;pack
end

    
