% c_RHsect.m
%		reads in RH from a grib file, and plots a vertical section on a diagnal.
%
%--------
% input
%--------
%		latlon*.grb
%
%--------
% output
%--------
%		*.png
%		*.mat
%
%--------
% history
%--------
% 	7/9/2010 Edited by Hyun-Sook Kim
%
%-----------------------------------------------------------------------

zs=[50:50:1000 1013 1022];      % vertical layers


%------------ User set up
sdate='2010-06-22_183600';

ddir1='Z:\h210\ceila03e\2010062218-cold';
ddir2='Z:\h210\ceila03e\2010062218-cycled';

gfile1=[ddir1,'\latlon-wrfout_d01_',sdate,'.grb'];
gfile2=[ddir2,'\latlon-wrfout_d01_',sdate,'.grb'];

gtmp=read_grib(gfile1,{'UFLX'});

% read in data:
gds=gtmp.gds;
xs=[min(gds.Lo1,gds.Lo2):gds.Di:max(gds.Lo1,gds.Lo2)]-360;
ys=[max(gds.La1,gds.La2):-gds.Di:min(gds.La1,gds.La2)];
clear gtmp gds; pack
[Xs,Ys]=meshgrid(xs,ys);
clear xs ys
dxs=diag(Xs);

clear Xs Ys

gtmp1=getgrib(gfile1,'RH');
RH1=[];
gtmp2=getgrib(gfile2,'RH');
RH2=[];
for K=1:length(zs)
	rtmp=squeeze(gtmp1.data(:,:,K));
	RH1(K,:)=diag(rtmp);
	clear rtmp;
    
	rtmp=squeeze(gtmp2.data(:,:,K));
	RH2(K,:)=diag(rtmp);
	clear rtmp;
end
clear gtmp;

figure('position',[20    25   852   770]);
sax(1,:)=[0.09  0.70   0.85  0.23];
sax(2,:)=[0.09  0.39   0.85  0.23];
sax(3,:)=[0.09  0.09   0.85  0.23];

axes('position',sax(1,:));
contourf(dxs,zs,RH1,[0:5:100]); caxis([0 100]); colormap(jet(20)); colorbar;
set(gca,'tickdir','out','ydir','reverse','xticklabel',[]); 
ylabel('pressure (mbar');
title([sdate,': RH (%) for COLD'],'fontsize',13,'fontweight','bold');

axes('position',sax(2,:));
contourf(dxs,zs,RH2,[0:5:100]); caxis([0 100]); colormap(jet(20)); colorbar;
set(gca,'tickdir','out','ydir','reverse','xticklabel',[]); 
ylabel('pressure (mbar');
title([sdate,': RH (%) for CYCLED'],'fontsize',13,'fontweight','bold');

axes('position',sax(3,:));
contourf(dxs,zs,RH2-RH1,[-25:5:25]); caxis([-25 25]); colormap(jet(24)); colorbar;
set(gca,'tickdir','out','ydir','reverse','xminortick','on'); 
ylabel('pressure (mbar');
title([sdate,': RH (%) for Cycled - Cold'],'fontsize',13,'fontweight','bold');
xlabel('Longitude (^oW)');

set(gcf,'paperpositionmode','auto')
eval(['print -dpng RHsect',sdate]);



