function [ohc,z26]=cal_ohc(T,Z);
%   function cal_ohc(T,Z);
%       computes the ocean heat content using the 26C depth as a reference
%       depth, and using a fixed water density.
%
%-------
% inputs
%-------
%   T,Z - Temperature and Depth
%
%-------
% output
%-------
%   ohc - heat content J/m^2
%
%---------
% history
%--------
%   1/25/2013. Edited by Hyun-Sook Kim
%--------------------------------------------------------------------------

Cp=4.1e3;
r0=1023;

otmp=0.;
z26=0;
for k=2:size(T,1)
    if (T(k) >= 26.0)
        dz=Z(k-1)-Z(k);
        tw=(T(k-1)+T(k))/2.;
        otmp=otmp+abs(dz)*(tw-26.0);
        z26=max(z26,Z(k-1)+dz/2);
    end
end
ohc=r0*Cp*otmp;


clear r0 Cp otmp
