% cf_R3track2N1.m
%       compare track and intensity for three simulations against a best
%       track:
%           * 2 simulations w/ HWRF-HYCOM
%           * 1 simulation w/ HWRF-POM
%
%--------------------------------------------------------------------------
clear all; close all;

for ncyc=0:6:132
    
ID='13e';
year='2014';
mm='08';
dd='22';
hr='00';
basin='ep';
sname='Marie';
TCname=[sname,year,mm,dd,hr];

% BT domain
bid='bep';

% run ID
runID1=[sname,ID,'R1'];  hadd1='H4Y2'; lg1='H4Y2';
runID2=[sname,ID,'R2'];  hadd2='H4Y2'; lg2='Alpha';

prunID1=[sname,ID]; padd1='H214';

%--- NCO track
if ncyc<=0
    f4trk='thirteen13e';      % prefix for the NCO-op track file
else
    f4trk=lower(prunID1);      % prefix for the NCO-op track file
end

ntxt=hadd1;

%-------------------------------------------------------- for users: ------
%  Number of cycle
%ncyc=132;

%------------------
% axis limit for plot:
%lonlat=([-90 -20 10 50]);  % domain for figure

%--- time information
dn0=datenum(str2num(year),str2num(mm),str2num(dd))+str2num(hr)/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
nds=datestr(dn0+ncyc/24,'ddHH');

cyc=['cyc',num2str(ncyc,'%03d'),'-',nds];      % e.g., cyc102-2918
dn1=dn0+ncyc/24;   %
       
%======== atcf ======================
%--- HyHWRF: RUN 1
tfile=['Z:\',hadd1,'\',runID1,'\atcf\',f4trk,'.',datestr(dn1,'yyyymmddHH'),'.trak.hwrf.atcfunix'];
%tfile=['Z:\',hadd1,'\',runID1,'\atcf\',ID,'l.trak.hwrf.atcfunix.',datestr(dn1,'yyyymmddHH')];
disp([' ',hadd1,':    ',tfile])

hskj=caseread(tfile);
knt=str2num(hskj(:,65:66));      % reference knot
ix=find(knt==34);
hskj=hskj(ix,:);
hxj=str2num(hskj(:,41:45))/10;
if (~isempty(findstr(ID,'l')) || ~isempty(findstr(ID,'e')));
    hxj=-1*hxj;
end
hyj=str2num(hskj(:,35:38))/10;
hmin=str2num(hskj(:,53:57));    % min Pressure (mbar)
hdnj=datenum(hskj(:,9:18),'yyyymmddHH')+str2num(hskj(:,31:33))/24;
vmaxj=str2num(hskj(:,49:51));
        Rads=str2num(hskj(:,74:95))*1.8;     % size: [nm] to [km]
        naomiR1=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            naomiR1(n)=mn;
            clear tmp mn
        end

naomi1=[hdnj hxj hyj hmin vmaxj];
clear knt ix hxj hyj hmin hhr hdnj vmaxj hskj

%--- NAOMIex track: RUN 2
tfile=['Z:\',hadd2,'\',runID2,'\atcf\',f4trk,'.',datestr(dn1,'yyyymmddHH'),'.trak.hwrf.atcfunix'];
disp([' ',hadd2,':    ',tfile])

hskj=caseread(tfile);
knt=str2num(hskj(:,65:66));      % reference knot
ix=find(knt==34);
hskj=hskj(ix,:);
hxj=str2num(hskj(:,41:45))/10;
if (~isempty(findstr(ID,'l')) || ~isempty(findstr(ID,'e')));
    hxj=-1*hxj;
end
hyj=str2num(hskj(:,35:38))/10;
hmin=str2num(hskj(:,53:57));    % min Pressure (mbar)
hdnj=datenum(hskj(:,9:18),'yyyymmddHH')+str2num(hskj(:,31:33))/24;
vmaxj=str2num(hskj(:,49:51));
        Rads=str2num(hskj(:,74:95))*1.8;     % size: [nm] to [km]
        naomiR2=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            naomiR2(n)=mn;
            clear tmp mn
        end

naomi2=[hdnj hxj hyj hmin vmaxj];
clear knt ix hxj hyj hmin hhr hdnj vmaxj hskj

%--- POM-HWRF Run 1:
tfile=['Z:\',padd1,'\',prunID1,'\atcf\',f4trk,'.',datestr(dn1,'yyyymmddHH'),'.',...
    'trak.hwrf.atcfunix'];
%disp([' H41A: ',tfile])
disp([' ',padd1,': ',tfile])

hskj=caseread(tfile);
knt=str2num(hskj(:,65:66));      % reference knot
ix=find(knt==34);
hskj=hskj(ix,:);
hxj=str2num(hskj(:,41:45))/10;
if (~isempty(findstr(ID,'l')) || ~isempty(findstr(ID,'e')));
    hxj=-1*hxj;
end
hyj=str2num(hskj(:,35:38))/10;
hmin=str2num(hskj(:,53:57));    % min Pressure (mbar)
hdnj=datenum(hskj(:,9:18),'yyyymmddHH')+str2num(hskj(:,31:33))/24;
vmaxj=str2num(hskj(:,49:51));
        Rads=str2num(hskj(:,74:95))*1.8;     % size: [nm] to [km]
        ncoR1=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            ncoR1(n)=mn;
            clear tmp mn
        end
nco1=[hdnj hxj hyj hmin vmaxj];
clear knt ix hxj hyj hmin hhr hdnj vmaxj hskj


%--- best HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',year,'\',bid,ID(1:end-1),year,'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhy=str2num(nhc(:,35:38))/10;
nhx=str2num(nhc(:,41:45))/10;
if (~isempty(findstr(ID,'l')) || ~isempty(findstr(ID,'e')));
    nhx=-1*nhx;
end
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');
        Rads=str2num(nhc(:,74:95))*1.8;     % size: [nm] to [km]
        bestR=[];
        for n=1:size(nhc,1)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            bestR(n)=mn;
            clear tmp mn
        end
best=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

%--- load track data from all models

%------------------------------------------------------------------- plot -
% plotting track and intensity
%------------------------------------------------------------------- plot -

%-------------------------------------------------------------- track
%figure('position',[59   142   690   430]);
figure('position',[20  55  1000  700]);
axes('position',[0.08 0.36 0.4 0.54]);
clear ttl;
hold on; 
if sign(naomi1(1,2))==-1
    draw_wrldcst180;
else
    draw_wrldcst360('k');
end
h1=plot(best(:,2),best(:,3),'-og','linewidth',2,'markersize',2);    % BEST
h2=plot(naomi1(:,2),naomi1(:,3),'-or','linewidth',2,'markersize',2);  % HyHWRF Run1
h3=plot(naomi2(:,2),naomi2(:,3),'-om','linewidth',2,'markersize',2);  % HyHWRF Run2
h5=plot(nco1(:,2),nco1(:,3),'-xb','linewidth',1.7,'markersize',4);    % POM-HWRF Run1
grid
set(gca,'tickdir','out','Xaxislocation','top');

mnxs=mean(naomi1(:,2));
mnys=mean(naomi1(:,3));
lonlat=([mnxs-25 mnxs+25 mnys-22.5 mnys+22.5]);  % domain for figure

axis(lonlat);
legend([h1(1),h2(1),h3(1),h5(1)],'Best',lg1,lg2,padd1,1);       % j60 vs o60
ttl{1}=[TCname];
ttl{2}=[cyc(1:6),':',datestr(dn1,'yyyymmddHH'),'  -  TRACK'];
title(ttl,'fontsize',12,'fontweight','bold')
ylabel('Latitude (^oN)'); %xlabel('Longitude (^oW)');

clear h1 h2 h3 ttl

%----------------------------------- intensity
axes('position',[0.55 0.55 0.4 0.38]);
%figure;
%for K=1:length(mI)
%    eval(['tmp=data',num2str(K,'%02g'),';']);
%    h3=plot(tmp(:,1),tmp(:,end),'-x','markersize',4,'color',[0.3 1 1]); hold on
%end
hold on;
h1=plot(best(:,1),best(:,end),'-og','linewidth',2,'markersize',2);      % BEST
h2=plot(naomi1(:,1),naomi1(:,end),'-or','linewidth',2,'markersize',2);    % HyHWRF Run1
h3=plot(naomi2(:,1),naomi2(:,end),'-om','linewidth',2,'markersize',2);    % HyHWRF Run2
h5=plot(nco1(:,1),nco1(:,end),'-xb','linewidth',1.7,'markersize',4);  % POM-HWRF Run1
grid
set(gca,'xlim',[naomi1(1,1)-6/24 naomi1(end,1)],'tickdir','out',...
    'xtick',[naomi1(1,1):12/24:naomi1(end,1)],'ylim',[0 180],'ytick',[0:20:180]);
datetickhsk('x','mm/dd HH','keeplimits','keepticks')
ylabel('Max. Wind Speed (kt)')
ttl=[cyc(1:6),':',datestr(dn1,'yyyymmddHH'),'  -  INTENSITY'];
title(ttl,'fontsize',12,'fontweight','bold')

%-------------------------------------------------------------- translation speed (m/sec)
% distance (m);
dB=fnddist(best(2:end,2),best(2:end,3),best(1:end-1,2),best(1:end-1,3))*1000./diff(best(:,1))/24/3600;
dX1=fnddist(naomi1(2:end,2),naomi1(2:end,3),naomi1(1:end-1,2),naomi1(1:end-1,3))*1000./diff(naomi1(:,1))/24/3600;
dX2=fnddist(naomi2(2:end,2),naomi2(2:end,3),naomi2(1:end-1,2),naomi2(1:end-1,3))*1000./diff(naomi2(:,1))/24/3600;
dN1=fnddist(nco1(2:end,2),nco1(2:end,3),nco1(1:end-1,2),nco1(1:end-1,3))*1000./diff(nco1(:,1))/24/3600;

dnB=best(1:end-1,1)+diff(best(:,1))/2;
dnX1=naomi1(1:end-1,1)+diff(naomi1(:,1))/2;
dnX2=naomi2(1:end-1,1)+diff(naomi2(:,1))/2;
dnN1=nco1(1:end-1,1)+diff(nco1(:,1))/2;

axes('position',[0.55 0.15 0.4 0.30]);
%figure('position',[300   282   620   420]);
plot(dnB,dB,'-xg','linewidth',1.6); hold on;            % actual
plot(dnX1,dX1,'-xr','linewidth',1.6);                     % HyHWRF Run1
plot(dnX2,dX2,'-xm','linewidth',1.6);                     % HyHWRF Run2
plot(dnN1,dN1,'-xb','linewidth',1.6);                     % POM-HWRF Run1
set(gca,'xlim',[naomi1(1,1)-6/24 naomi1(end,1)],'tickdir','out',...
    'xtick',[naomi1(1,1):12/24:naomi1(end,1)],'ylim',[0 20]);
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
grid
ylabel('U_t (m/s)');
ttl=[cyc(1:6),':',datestr(dn1,'yyyymmddHH'),'  -  U_t'];
title(ttl,'fontweight','bold','fontsize',12);
text(0.02,-0.15,pwd,'fontsize',9,'color','r','units','normalized');

%------------------------------------------------- mean size(km) of a storm
axes('position',[0.1 0.08 0.38 0.215]);
%figure('position',[300   282   620   520]);
h1=plot(best(:,1),bestR,'-xg','linewidth',1.7,'markersize',3);
hold on
h2=plot(naomi1(:,1),naomiR1,'-rx','markersize',3,'linewidth',1.7);
h3=plot(naomi2(:,1),naomiR2,'-mx','markersize',3,'linewidth',1.7);
h5=plot(nco1(:,1),ncoR1,'-xb','markersize',3,'linewidth',1.);
set(gca,'xlim',[naomi1(1,1)-6/24 naomi1(end,1)],'tickdir','out',...
    'xtick',[naomi1(1,1):12/24:naomi1(end,1)],'ylim',[0 700]);
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
grid
ylabel('\eta (km)');
ttl=[cyc(1:6),':',datestr(dn1,'yyyymmddHH'),'  -  Storm-size'];
title(ttl,'fontweight','bold','fontsize',12);

set(gcf,'paperpositionmode','auto');
eval(['print -dpng cf_track3N1_',hadd1,'_',hadd2,'_',TCname,cyc]);

pause(0.5)

eval(['save cf_R3track2N1_cyc',num2str(ncyc,'%03g'),...
    ' naomi1 naomi2 nco1 best dB dnB dB dnX1 dX1 dnX2 dX2 dnN1 dN1']);

pause
%clear all
clear all; close all;pack

end
