% cf_rsssst.m
%       compares daily  SST (RSS) from TMI and AMSRE Microwave Obs.
%       to daily mean HYCOM sst.m
%
%---------
% history:
%---------
%   3/13/2013. Edited by Hyun-Sook Kim.
%--------------------------------------------------------------------------

clear all; close all; pack
%--------------------------------------------------------------------------

PDY0=datenum([2012 8 26]);     % for a reference date ==> TMI-AMSRE OI SST (accuracy = 0.15C)
pdyc=datestr(PDY0,'yyyymmddHH');  % a cycle of interest

cnv=0.0;    % conversion from pot. temp to in-situ temp.
scnv=num2str(abs(cnv)*10,'%02g');

for H=1:5
    PDY=datestr(PDY0+(H-1),'yyyymmdd');
    
    if mod(str2num(PDY(1:4)),4)==0;     yflg=1;
    else;     yflg=0;end
    yrday=yearday(str2num(PDY(5:6)),str2num(PDY(7:8)),yflg);

nday=datenum(PDY,'yyyymmdd')-datenum(pdyc,'yyyymmddhh');

HRS=((0:6:18)+0)+24*nday;   % --- Four 6-hrly data
datestr((datenum(pdyc,'yyyymmddHH')+HRS/24));

pdy0='2012082112';  % the 1st cycle
domain='hat11';
storm='Isaac';
id='09l';
Expt='H2Y2_offlux1';

ncyc=(datenum(pdyc,'yyyymmddHH')-datenum(pdy0,'yyyymmddHH'))*24;
sncyc=['cyc',num2str(ncyc,'%03g'),'-',pdyc(end-3:end)];

% model data:
ddir=['Z:\',Expt,'\',lower(storm),id,'\',pdy0,'\',sncyc,'\ocean\'];   
prefix=['hwrf_',upper(storm),'.',id,'.rtofs_',domain,'.t',pdyc(end-1:end),'z.'];

% Four 6-hourly data:
files{1}=[ddir,prefix,'F',num2str(HRS(1),'%03g'),'.3d.grb'];
files{2}=[ddir,prefix,'F',num2str(HRS(2),'%03g'),'.3d.grb'];
files{3}=[ddir,prefix,'F',num2str(HRS(3),'%03g'),'.3d.grb'];
files{4}=[ddir,prefix,'F',num2str(HRS(4),'%03g'),'.3d.grb'];
% display
disp(['simulation data: from ',files{1}])
disp(['   to ',files{4}])

all=zeros(351,563);
for K=1:4
    if exist(files{K})==0
        M=load([ddir,'temp_hwrf_rtofs_hat11.t00z.',pdyc,'_n00.mat']);
        gtmp=squeeze(M.varout(:,:,1));
        clear M;
    else
        htmp=getgrib(files{K},'WTMPC');
        gtmp=squeeze(htmp.data(:,:,2));
        clear htmp
    end
   all=all+gtmp;
end
all=all/4+cnv;

affix='tmi_amsre';
file=['Z:\MWRadar\TMInAMSRE\Data\',affix,'.fusion.',PDY(1:4),'.',num2str(yrday,'%03g'),'.rt'];
[xs,ys,Oi]=mwsst2hycom(file,domain);

Oi(Oi>250)=nan;
[lns,lts]=domain4hyhwrfv2(domain);
[rx,ry]=meshgrid(xs,ys);
Zi=griddata(lns,lts,all,rx,ry);
aa=find(isnan(Zi));
Oi(aa)=nan;     % E.Pacific for hat11.
clear aa;
% correct cool Temp
Oi=Oi;
aa=find(isnan(Oi));
Zi(aa)=nan;

% Taylor Diagram
statm=allstats(Oi(:),Zi(:))
statm=statm';
[hp ht axl] = taylordiag(statm(:,2),statm(:,3),statm(:,4));

set(ht(1),'string',upper(strrep(affix,'_','-')))
set(ht(2),'string','HYCOM')
title(['Valid ',datestr(datenum(PDY,'yyyymmdd'),'mmmm dd, yyyy')],'fontsize',12)
eval(['print -dpng TaylorDiagram_valid_',affix,'_sst',scnv,'_',PDY,'_',domain,'_',sncyc]);

% Histogram
figure
hh=hist([Zi(:) Oi(:)],[24:0.3:34]);
g=bar([24:0.3:34],hh);
set(g(1),'facecolor','m');
set(g(2),'facecolor','c');
set(gca,'xminortick','on')
set(gca,'tickdir','out','fontsize',11)
grid; set(gca,'xlim',[25 34]);
Sr=skewness(Oi(:));
Sh=skewness(Zi(:));
legend('HYCOM',upper(strrep(affix,'_','-')),1);
tt2=[strrep(affix,'_','-'),': (',num2str(statm(1,1),'%5.1f,'),num2str(Sr,'%6.2f)')];
tt1=['hycom: (',num2str(statm(2,1),'%5.1f,'),num2str(Sh,'%6.2f)')];
text(0.6,0.75,{tt1;tt2},'units','normalized','fontsize',12,'fontweight','bold');
title(['Valid ',datestr(datenum(PDY,'yyyymmdd'),'mmmm dd, yyyy')],'fontsize',12)
eval(['print -dpng Hist_valid_',affix,'_sst',scnv,'_',PDY,'_',domain,'_',sncyc]);

switch domain
    case 'hat11'
        fpos=[47   247   657   802];
        ax1=[0.10 0.72 0.84 0.25];
        ax2=[0.10 0.40 0.84 0.25];
        ax3=[0.10 0.08 0.84 0.25];
    case 'hat14'
end
figure('position',fpos);
axes('position',ax1);
pcolorhsk(xs,ys,Oi); sflat; 
caxis([25 31]); colormap(jet(13)); freezeColors; h1=colorbar; 
hold on; draw_wrldcst360('k');
title([upper(strrep(affix,'_','-')),' valid ',PDY],'fontsize',12);
set(gca,'tickdir','out');
clear Cdata

axes('position',ax2);
pcolorhsk(xs,ys,Zi); sflat; 
caxis([25 31]); colormap(jet(13)); freezeColors;  h2=colorbar;
hold on; draw_wrldcst360('k');
title(['HYCOM: ',sncyc,': ',num2str(HRS(1),'%03g')],'fontsize',12);
set(gca,'tickdir','out');
clear Cdata

axes('position',ax3);
contourf(xs,ys,Zi-Oi,[-3:0.5:3]); 
caxis([-3 3]); colormap(jet(12)); h3=colorbar;
hold on; draw_wrldcst360('k');
contour(xs,ys,Zi-Oi,[0 0],'-w','linewidth',1);
title(['HYCOM-TMIAMSRE: ',sncyc,': ',num2str(HRS(1),'%03g')],'fontsize',12);
set(gca,'tickdir','out');

set(gcf,'paperpositionmode','auto');
eval(['print -dpng 2DValid_',affix,'_sst',scnv,'_',PDY,'_',sncyc]);

%---- save matlab binary
eval(['save cf_',affix,'_sst',scnv,'_',PDY,sncyc,' xs ys  Zi Oi']);

close all
clear PDY xs ys Zi Oi
end

