% hyhwrf_TUVsrf.m
%		reads in a set of grib files of 
%	  a stand-alone hurricane west simulations, and 
%		plots a set of surface velocity fields, superimposed on temperature fields. 
%
%-------
% input
%-------
%					*.grb - every 6-hour simulations 
%
%--------
% output
%--------
%				*.png
%
%--------
% history
%--------
%   3/9/2012 Modified "ihops_TUVsrf.m". -hsk
%   4/16/2008 Modified 'diagnos_hwest_uvsrf.m. -hsk
%      1/2/2008 Edited by Hyun-Sook Kim
%
%-----------------------------------------------------------
clear all; close all;
for ncyc=36:6:36
%-----------------------------------------------------------
% hurricane name & date
hwrfmodel='H3Y2';
Hname='Erick05e';        % run
year=2013;
mm=07;
dd=04;
hr=12;
ID='bep05';
domain='hep23';      % subdomain for hurricane

hname=lower(Hname);

if ncyc<0
    f4trk='five05e';
else
    f4trk=hname;
end

% parameters related to figure
psave=1;                        % flag for saving plot

%-------------------------------------------------------- for users: ------
%  Number of cycle
%ncyc=00;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
dnc=dn0+ncyc/24;
nds=datestr(dn0+ncyc/24,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

ddir=['Z:\',hwrfmodel,'\',Hname,'\',yearmmddhh,'\',runID,'\ocean\'];       % run output directory
adir=['Z:\',hwrfmodel,'\',Hname,'\atcf\'];       % atcf

ofhead=[hname,'_TUVsrf_cyc',num2str(ncyc,'%03g')];       % figure suffix
odir=['Z:\',hwrfmodel,'\',Hname,'\',yearmmddhh,'\',runID,'\movie'];
%--- information for input data and folder: 
SD=dir([ddir,'*.F*.3d.grb']);
fnum=length(SD);

% a folder for files being saved
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ''MOVIE''',odir,' directory'])
    end
else
    disp(['             a ''MOVIE'' directory exists already!'])
end

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
switch lower(frc)
    case {'hwrf'}
        dlook=dir([adir,'\',f4trk,'.',datestr(dnc,'yyyymmddHH.'),'trak.hwrf.atcfunix']);
        hsk=caseread([adir,'\',dlook.name]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        knt=str2num(hsk(:,65:66));      % reference knot
        % find index for reference wind speed=34kt
        ix=find(knt==34);
        hsk=hsk(ix,:);
        hx=str2num(hsk(:,41:45))/10;
        if (ID(2)=='e' || ID(2)=='a')
            hx=(-1)*hx+360;
        end
        hy=str2num(hsk(:,35:38))/10; 
        hhr=hhr(ix);
        hdn=datenum(hsk(:,9:18),'yyyymmddHH')+hhr/24;
        vmax=str2num(hsk(:,49:51));       % max. wind speed (kts)
        Rads=str2num(hsk(:,74:95))*1.8;     % size: [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk
end

%--- best HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',num2str(year),'\',ID,num2str(year),'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhx=str2num(nhc(:,41:45))/10;
        if (ID(2)=='e' || ID(2)=='a')
            nhx=(-1)*nhx+360;
        end
nhy=str2num(nhc(:,35:38))/10;
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');

best=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

%---- Aux data
% load hurricane west domain properties:
[wlon,wlat]=domain4hyhwrfv2(domain);
switch domain
    case 'hwp33'
        fpos=[54 463 975 545];
        lonlat=[floor(min(wlon(:))) ceil(max(wlon(:))) ...
            floor(min(wlat(:))) ceil(max(wlat(:)))];
    case 'hwp32'
        fpos=[54 463 975 545];
        lonlat=[floor(min(wlon(:))) ceil(max(wlon(:))) ...
            floor(min(wlat(:))) ceil(max(wlat(:)))];
    case 'hwp31'
        fpos=[54 463 975 545];
        lonlat=[floor(min(wlon(:))) ceil(max(wlon(:))) ...
            floor(min(wlat(:))) ceil(max(wlat(:)))];
    case 'hep23'
        fpos=[ 54   341   831   767];
        lonlat=[floor(min(wlon(:))) ceil(max(wlon(:))) ...
        floor(min(wlat(:))) ceil(max(wlat(:)))];
end

% subsample for plotting vectors
six=1:4:size(wlon,1);
siy=1:4:size(wlon,2);

sln=wlon(six,siy); slt=wlat(six,siy);   % subsample grids for vector plot

refmax=3;               % reference velocity: 3 m/s
refx=sqrt(refmax);
refy=-refx;
ir=length(six); jr=1;       % reference location

pos1=[24   323   616   586]; % for set(gca,'xlim',[-100 -75],'ylim',[15 40])

%-----------------------------------------------------
% main 
%------

%------------------------------------------------- loading data
% Ue=repmat(nan,[length(dn),size(wlon)]);
% Vn=Ue;
% Ts=Ue;
disp(' ')
disp(' read in data file')
mnts=[];
dn=[];
for K=1:fnum
    
    indx=K;
    
        gfile=[ddir,SD(indx).name];        % a grib file
    
    % datenum for the current file
    aa=findstr(gfile,'.3d.grb');
    nhr=str2num(gfile(aa-3:aa-1)); clear aa
    
    dnt=dnc+nhr/24;
    dn=[dn; dnt];
    
    disp(['         data file: ',SD(K).name])
    
    % get surface (U,V) velocity component
    gtmp1=getgrib(gfile,'UOGRD',[1 -1 -1],[1 -1 -1]);
    gtmp2=getgrib(gfile,'VOGRD',[1 -1 -1],[1 -1 -1]);

        %--- velocity
    utmp=getgrib(gfile,'UOGRD',[1 -1 -1],[1 -1 -1]);  
    uc=utmp.data; 
    vtmp=getgrib(gfile,'VOGRD',[1 -1 -1],[1 -1 -1]);  
    vc=vtmp.data; 
    clear utmp vtmp
    
    utmp=getgrib(gfile,'UBARO');
    ub=utmp.data;
    vtmp=getgrib(gfile,'VBARO');
    vb=vtmp.data;
    clear utmp vtmp;

    %[te,tn]=uv2uevn(wlon',wlat',ub+uc,vb+vc);
  
    te=ub+uc;     % east component in the earth coordinates
    tn=vb+vc;     % north component in the earth coordinates
    
    clear ub uc vb vc
    
% convert potential to in-situ temperature    
    gtmp3=getgrib(gfile,'WTMPC',[2 -1 -1],[2 -1 -1]);
    
    ts=gtmp3.data;   
    sst=ts;
    
%     dumm=strrep(gfile,'.','_');
%     dumm=strrep(dumm,'grb','');

    sindx=findstr(gfile,'.F');
    dumm=gfile(1:sindx+4);
    dumm=strrep(dumm,'.','_');
    
    eval(['save ',dumm,'.mat sst']);
    clear dumm sst
    
    clear gtmp* 
    
%-------------------------------------------------------------
% diagnostic plotting
%---------------------
% for K=1:length(dn)
    
    t1s=te(six,siy);   t2s=tn(six,siy);
    t1s(ir,jr)=refx;
    t2s(ir,jr)=refy;

    % find index for current time
    hdni=interp1(hdn,hdn,dnt,'linear');
    
    hxi=interp1(hdn,hx,dnt,'linear');
    hyi=interp1(hdn,hy,dnt,'linear');

    nhxi=interp1(best(:,1),best(:,2),dnt,'linear');
    nhyi=interp1(best(:,1),best(:,3),dnt,'linear');
    
    % find index on a footprint of 150-km storm size
    dr=fnddist(wlon,wlat,hxi,hyi);
    ks=find(dr<150);        
    vel=abs(te+i*tn);
    mxvel=nanmax(vel(ks));      % maximum surface velocity on a footprint
    clear vel
    
    mnsst=nanmean(ts(ks));      % mean SST on a footprint
    clear ks
    
    %-------------------------------------------------------- plotting ----
    % figure('position',[110   178   615   640]);
    bc=[0.5 0.2 0.8];     % color for best track data
    obc=[1 0.5 0.0];      % part of track over the same simulation period
    
    figure('position',fpos);
    axes('position',[0.07 0.29 0.84 0.635]);     % SST-color and Velocity fields
    pcolorhsk(wlon,wlat,ts); caxis([20 32]); colormap(jet(24)); grid
    hc=colorbar; hp=get(hc,'position'); hp(1)=0.91+0.002; hp(3)=0.02;
    set(hc,'position',hp); clear hp;
    hold on; shading flat;
%--- coastline
    draw_wrldcst180;
%--- velocity plot
    quiver(sln,slt,t1s,t2s,5,'k');
    set(gca,'tickdir','out','fontsize',11); 
    axis(lonlat);
    xlabel('Longitude (^oW)'); ylabel('Latitude (^oN)');
%--- BEST track
    plot(best(:,2),best(:,3),'-x','linewidth',1.5,'color',obc);
    aa=find(best(:,1)>=min(hdn(:)) & best(:,1)<=max(hdn(:))); 
    plot(best(aa,2),best(aa,3),'-*','linewidth',1.5,'color',bc);
    clear aa
    plot(nhxi,nhyi,'oy','linewidth',1.8,'markersize',7);
%--- a current hurricane location on its track
    plot(hx,hy,'-xm','linewidth',1.8);
    plot(hxi,hyi,'ow','linewidth',1.8,'markersize',7);
%--- a reference vector
    ttl{1}=[upper(hname),': IC=',datestr(dnc,'yyyy/mm/dd HH')];
    ttl{2}='Ocean Surface Velocity and Temperature';
    title(ttl,'fontsize',15,'fontweight','bold');
    text(0.02,0.95,datestr(dnt,'yyyy/mm/dd HH'),...
        'fontsize',15,'color','r','units','normalized','fontweight','bold');
    text(0.02,0.84,['V_{max}=',num2str(mxvel,'%5.2f'),' m/s (R=150-km)'],...
        'fontweight','bold','color','m','units','normalized');   
    text(0.02,0.79,['T_{av}=',num2str(mnsst,'%5.1f'),' ^oC (R=150-km)'],...
        'fontweight','bold','color','m','units','normalized');   
    text(sln(ir,jr),slt(ir,jr),[num2str(refmax),' m/s'],'color','b','fontsize',15,'fontweight','bold');   
    text(0.62,-0.09,ddir,'fontsize',8,'color','r','units','normalized');
    text(0.03,0.03,hname,'fontsize',8,'color','k','units','normalized');        % legend for weight

%     axes('position',[0.10 0.06 0.77 0.15]);     % SST-color and Velocity fields
    axes('position',[0.10 0.06 0.85 0.15]);     % SST-color and Velocity fields
    x1=plot(hdn,vmax,'-xm','linewidth',2); hold on       % IHOPS Pmin
    plot(repmat(hdni,1,2),[0 160],'r','linewidth',1.4);
    x2=plot(best(:,1),best(:,end),'-x','linewidth',2,'color',bc);              % NHC Pmin
    set(gca,'xlim',[floor(hdn(1)) ceil(hdn(end))],'tickdir','out','ylim',[0 160]);
    ylabel('kts'); grid;
%     legend([x1(1),x2(1)],'ihops','nhc','location','eastoutside');
    datetickhsk('x',44,'keeplimits','keepticks');
    text(0.03,1.07,'Intensity','units','normalized','color','m',...
        'fontweight','bold','fontsize',15)
    legend([x1(1),x2(1)],hwrfmodel,'best',...
        'orientation','vertical','location','eastoutside');
    
    if psave;
        set(gcf,'paperpositionmode','auto');
        eval(['print -dpng ',odir,'\',ofhead,'_',num2str(K,'%02g')]);
    end

     clear tn te ts t1s t2s
     close
end

%    clear all; close all; pack
end

    
