% read_binmld.m
%
%
%-----------------------------------------------------------------------------------------------
% 1      2        3           4               5                  6    7          8
% sst, ssdensity, model-MLD,  MLD w/ dT=0.25, MLD w/ dSigma=0.1, Z26, Sigma @26. OHC*heat*rho
%-----------------------------------------------------------------------------------------------
%
%   write (21) sst,cs,d_in,bd,cd,bz,c_at_bz,ohc

Cp=3850;        % specific heat capacity for sea water

vars{1}='SST';
vars{2}='\sigma @z=0';
vars{3}='model MLD';
vars{4}='MLD \delta T=0.25';
vars{5}='MLD \delta\sigma=0.1';
vars{6}='Z_{26}';
vars{7}='\sigma_{Z26}';
vars{8}='OHC [kJ/cm^2]';

% cycle and domain information:
storm='isaac09l';
id=storm(end-2:end);
domain='hat11';

PDY='2012082112';
dn0=datenum(PDY,'yyyymmddHH');

% data directory
ncyc=60
cdn=dn0+60/24;
bdir=['Z:\H2Y2\',storm,'\',PDY,'\cyc',num2str(ncyc,'%03d'),'-',datestr(cdn,'ddHH'),'\ocean\'];

% grid data for a given domain:
switch domain
    case 'hat11'
        grdfile=['hwrf_rtofs_hat11_west_grid.mat'];
    case 'hat12'
        grdfile=['hwrf_rtofs_hat12_mid_grid.mat'];
    case 'hat13'
        grdfile=['hwrf_rtofs_hat13_east_grid.mat'];
    case 'hat14'
        grdfile=['hwrf_rtofs_hat14_north_grid.mat'];
    case 'hat10'
        grdfile=['hwrf_rtofs_hat10_basin_grid.mat'];
    case 'hep21'
        grdfile=['hwrf_rtofs_hep21_west_grid'];
    case 'hep22'
        grdfile='hwrf_rtofs_hep22_mid_grid';
    case 'hep23'
        grdfile='hwrf_rtofs_hep23_east_grid';
    case 'hwp31'
        grdfile='hwrf_rtofs_hwp31_west_grid';
    case 'hwp32'
        grdfile='hwrf_rtofs_hwp32_east_grid';
    case 'hwp33'
        grdfile='hwrf_rtofs_hwp33_north_grid';
end
M=load(grdfile);
ln=M.plon; lt=M.plat;
idm=size(ln,1); 
jdm=size(ln,2);
ijdm=idm*jdm;

% input files:
prefix=['hwrf_mld',id,'.',datestr(cdn,'yyyymmddHH'),'_F'];
for K=1:20
    infile=[bdir,prefix,num2str(K*6,'%03g'),'.bin'];

    % --- read a set of binary mld/ohc files
    fid=fopen(infile,'r','b');
    hsk=fread(fid,'float');
    fclose(fid);

    out=hsk(2:end-1); 
    out(out>1e+10)=nan;

% extract individual vars:
v1sst=[]; v2sg0=[];
v3mld1=[]; v4mld2=[]; v5mld3=[];
v6z26=[];  v7s26=[];  v8ohc=[];
for K=1:length(out)/ijdm
  R=ijdm*(K-1)+1:ijdm*K;
  eval(['tmp',num2str(K),'=reshape(out(R),jdm,idm);']);
end

v1sst=tmp1'; v2sg0=tmp2';
v3mld1=tmp3'; v4mld2=tmp4'; v5mld3=tmp5';
v6z26=tmp6';  v7s26=tmp7';  v8ohc=tmp8';

Rho=(v2sg0+v7s26)/2;
Rho(Rho<200)=nan;

OHC=Cp*v8ohc.*Rho/1E+7;        % [kJ/cm^2]

  figure;
  pcolorhsk(ln,lt,OHC); shading flat; colorbar;
  title(vars{8});
clear tmp*
