% read_nestarch_sst.m
%
% Note: Nest Archv Structure is different from RTOFS_GLOBAL.
%
%%% A matlab script to read hycom archv files.

%--------------------------------------------------------------------------
domain='hat11.west';
prop='MLD';
year='2011';
yday='347';
shr='01';

sdir='nosst_347';       % sub-directory

% MLD conversion from Pressure to [m]
conv=1./9806;  % 1000*9.8;  "onem=g/thref=9806" in HYCOM

%----- Input file directory
gdir='Z:\DAhycom\test\';       % dir for regional grid
adir=[gdir,'\',sdir,'\'];      % dir for archive

afiles=dir([adir,'\*arch*.a']);
af1=afiles(1).name;
bname=strrep(af1,'.a','.b');

bfid=fopen([adir,bname],'r');
for LL=1:8
    line=fgetl(bfid);
end
IDM=sscanf(line,'%f',1);
line=fgetl(bfid);
JDM=sscanf(line,'%f',1);
fclose(bfid);

IJDM=IDM*JDM;
KDM=32;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% field indices in the archv file%%%%%%%%%%
 
SSH_INDEX=2;
MLD_INDEX=7;
TMIX_INDEX=8;
SMIX_INDEX=9;
UMIX_INDEX=11;
VMIX_INDEX=12;
UBARO_INDEX=13;
VBARO_INDEX=14;
UVEL_INDEX=15;
VVEL_INDEX=16;
TEMP_INDEX=18;
SALT_INDEX=19;

NUM3DF=5;         % set = 0 if you want to read only the 2d fields

varindx=MLD_INDEX;

%--------------------------------------------------------------------------
% read plon and plat from regional grid file
%  & parameters for figure
%--------------------------
switch domain
    case 'hat11.west'
        M=load('hwrf_rtofs_hat11_west_grid.mat');
        fpos=[53   202   693   420];
        dpos=[0.08 0.1 0.85 0.82];
        cv=[0 200];
        ci=10;
        cvi=[cv(1):ci:cv(2)];
        ncmap=length(cvi)-1;
    case 'hat12.mid'
        M=load('hwrf_rtofs_hat12_mid_grid.mat');
    case 'hat13.east'
        M=load('hwrf_rtofs_hat13_east_grid.mat');
    case 'hat14.north'
        M=load('hwrf_rtofs_hat14_north_grid.mat');
    case 'hep21.west'
        M=load('hwrf_rtofs_hep21_west_grid.mat');
    case 'hep22.mid'
        M=load('hwrf_rtofs_hep22_mid_grid.mat');
    case 'hep23.east'
        M=load('hwrf_rtofs_hep23_east_grid.mat');
    case 'hwp31.west'
        M=load('hwrf_rtofs_hwp31_west_grid.mat');
    case 'hwp32.east'
        M=load('hwrf_rtofs_hwp32_east_grid.mat');
    case 'hwp33.north'
        M=load('hwrf_rtofs_hwp33_north_grid.mat');
end
plon=M.plon; plat=M.plat;

%--------------------------------------------------------------------------
% file names etc - edit file name to change files 

npad=4096-mod(IJDM,4096);

%----------  READ 3D fields  ----------------------------------------------
% MLD=[];
stats=[];
for N=1:length(afiles)

    % archv_fid=fopen([E,'_archv.*.a'],'r');
    ftmp=afiles(N).name;
    
    sday=str2num(ftmp(12:14));
    shr=str2num(ftmp(16:17));
    
    aname=[adir,afiles(N).name];
    archv_fid=fopen(aname,'r');
    
    if (NUM3DF>0)
    %---------- 
    % read temp 
        for k=0:0;      % SST
        fseek(archv_fid,(k*NUM3DF+(varindx-1))*4*(npad+IJDM),-1);
        [atmp,count]=fread(archv_fid,IJDM,'float32','ieee-be');
        atmp(find(atmp>1e10))=NaN;
        atmp=reshape(atmp,IDM,JDM)';
        atmp=atmp.*conv;
%         MLD(N,:,:)=atmp;
%         frewind(archv_fid);
        clear count
        end

    end % endif
    fclose(archv_fid);
    
    %-------------------------------------------
    % Diagnostic Plot
    %----------------
    stmp=[nanmin(atmp(:)) nanmax(atmp(:)) nanmean(atmp(:)) nanstd(atmp(:))];
    
    figure('position',fpos);
    axes('position',dpos);
    contourf(plon,plat,atmp,cvi); caxis(cv); colormap(jet(ncmap));
    hc=colorbar; ht=get(hc,'position'); 
    ht(1)=dpos(1)+dpos(3)+0.005; ht(3)=0.02; set(hc,'position',ht); clear hc ht
    grid; 
    set(gca,'tickdir','out');
    txt{1}=['CI=',num2str(ci,'%5.1f'),'m'];
    txt{2}=['(min,max,mean,std)=(',num2str(stmp(1),'%5.2f,'),...
        num2str(stmp(2),'%5.2f,'),num2str(stmp(3),'%5.2f,'),...
        num2str(stmp(4),'%5.3f)')];
    text(0.04,0.075,txt,'color','m','units','normalized');    
    title([sdir,': ',aname],'fontsize',12);
    
    oname=afiles(N).name;
    pname=strrep(oname,'.a','');
    
    set(gcf,'paperpositionmode','auto')
    eval(['print -dpng ',adir,'\MLD\',pname,'-',prop,'.png']);
    
    stmp=[sday shr stmp];
    stats=[stats; stmp];
    clear stmp atmp shr sday ftmp
    close all

end
%----------------------------------
% save output
%------------
%eval(['save ',adir,pname,'-',prop,'.mat MLD stats afiles']);
eval(['save ',adir,pname,'-',prop,'.mat  stats afiles']);

