% trackLHT150km.m
%		read in hourly latent heat flux
%       and
%       produce a set of the LHT on the storm footprint (size=150 km). 
%
%-------
%	input
%-------
%			*.grb   - 
%           
%-------
% output
%-------
%       1. a set of 4 figures:
%               png1name=[fcst,'_',Hname,'_LHT_Htrack'];
%               png2name=[fcst,'_',Hname,'_LHT_Htrack_matrix'];
%               png3name=[fcst,'_',Hname,'_mnLHT_Htrack'];
%               png4name=[fcst,'_',Hname,'_mnLHT_Htrack_matrix'];
%				png5name=[fcst,'_',Hname,'_diffLHT6hr_Htrack_matrix'];
%
%       2. ascii output for an LHT matrix as function of date (x) and distance (y).
%
%--------
% history
%--------
%   5/21/2009 Modified 'trackSST.m' to work with Latent Heat Flux. -hsk
%       1/29/3008 Modified 'diagnos_rtofs_trackSST.m' 
%               for Coupled/Stand-alone simulations. -hsk
%		11/19/2007 Edited by Hyun-Sook Kim
%
%------------------------------------------------------------------------
clear all; close all; 

%ncyc=24;

for ncyc=12:12:144
    
   Ro=300;      % the footprint size 
iplot=1;        % a flag for plotting
isave=1;
tsample=6;                  % sampling

%-------------------------------------------  Run information -------------
fcst='HH09p5';               % model system ID
domain='west';              % hurricane domain
year=2005;                  % year for interest of hurricane
mm=09;
dd=18;
hr=12;
Hname='dRita05';             % Hurricane name

%-------------------------------------------------------- for users: ------
%  Number of cycle
% ncyc=108;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
nds=datestr(dn0+ncyc/24,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['Z:\HH09p5\',Hname,'\',yearmmddhh,'\',runID,'\ocean\'];       % run output directory

%--- output directory
% a folder for figure deposit 
odir=['Z:\HH09p5\',Hname,'\',yearmmddhh,'\',runID,'\trackLHT\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

% output data filename
ofname=[fcst,'-',Hname,'-trackLHT','.dat'];      % ASCII data filename for MLD

%--- setup date for data extraction
%  6-hour data - 
Dr=dir([ddir,'*.grb']);
dn=[];
if length(Dr)==0
    disp([' ... No Data in ',ddir,'...'])
else
  dn=[];
  gfiles=[];
  N=0;
  for K=1:length(Dr)
      ftmp=Dr(K).name;
      shr=ftmp(end-5:end-4);
      if mod(str2num(shr),tsample)==0; 
          N=N+1;
          syd=ftmp(end-9:end-7);
          gfiles{N}=Dr(K).name;
          gd=greg2((str2num(syd)-1)+str2num(shr)/24,year);
          dn(N)=datenum(gd);
          clear gd syd
      end
      clear ftmp shr
  end
end

%------------------------------------------------------------------
% Ancillary
%-----------
% hurricane domain: grid information
switch lower(domain)
    case {'west'}
        M=load(['ncep12_01_hur_west_grid.mat']);
        hlon=M.hlon; hlat=M.hlat;
        lonlat=[-100 -60 10 35];
    case {'mid'}
        M=load(['ncep12_02_hur_mid_grid.mat']);
        hlon=M.mlon; hlat=M.mlat;
        lonlat=[-90 -35 10 45];
    case {'east'}
        M=load(['ncep12_03_hur_east_grid.mat']);
        hlon=M.elon; hlat=M.elat;
        lonlat=[-90 -40 5 50];
end
clear M

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
switch lower(frc)
    case {'hwrf'}
        dlook=dir([ddir,'\trak.hwrf.atcfunix.*']);
        tfile=dlook.name;
        hsk=caseread([ddir,'\',tfile]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        knt=str2num(hsk(:,65:66));      % reference knot
        % find index for reference wind speed=34kt
        ix=find(knt==34);
        hsk=hsk(ix,:);
        hx=-1*str2num(hsk(:,42:45))/10;
        hy=str2num(hsk(:,36:38))/10; 
        hhr=hhr(ix);
        hdn=datenum(hsk(:,9:18),'yyyymmddHH')+hhr/24;
        Rads=str2num(hsk(:,74:95)) *1.8;     % size [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk
    case {'gfs'}
        nhc=load('G:\PROJECT07\OFS\GFStrack\Rita.best.track.gfs.txt');
        hx=nhc(:,3); hy=nhc(:,2);
        ymdh=num2str(nhc(:,1));
        hdn=datenum(ymdh,'yyyymmddHH');
end

% %nhc=load('G:/NHC/nhc_Rita05.dat');           % NHC hurricane information
% %
% %   1    2   3  4  5   6   7       8         9        10   
% %  ----------------------------------------------------------
% %   year mon dy hh lat lon Prs(mb) wind(m/s) size(km) Prs_env
% %
% nhc=load(['G:/NHC/nhc_',Hname,'.dat']);           % NHC hurricane information
% hx=nhc(:,6); hy=nhc(:,5);
% hdn=datenum([nhc(:,1),nhc(:,2),nhc(:,3),nhc(:,4),repmat(0,length(hx),2)]);
% Rsize=nhc(:,end-1);           % the hurricane radius (km)
% 
%--------------------------------------------------------------------
% main section
%    1.Find a set of indicies along the hurricane track
%------------------------------------------------------

%--- figure output name:
png1name=[fcst,'_',Hname,'_LHT_Htrack_150km'];
png2name=[fcst,'_',Hname,'_LHT_Htrack_matrix1_150km'];
png3name=[fcst,'_',Hname,'_LHT_Htrack_matrix2_150km'];
png4name=[fcst,'_',Hname,'_LHT_timeseries_150km'];
png5name=[fcst,'_',Hname,'_diffLHT6hr_Htrack_matrix_150km'];

%====================================================== Assembling data ===
%--- assembling data
Cs=load('ClomClam.mat');     % coastline

% work-space
Im=repmat(nan,150,length(dn));       % collection of indicies each time step
mnVAR=repmat(nan,length(dn),1);        % mean LHT on a hurricane footprint                            
VARall=repmat(nan,[length(dn),size(hlon)]); % LHT for all 
disp(' ')
cindx=[];
for K=1:length(dn)

    % find indices at the hurricane eye
    q=find(hdn==dn(K));
    if ~isempty(q)
        
    cindx=[cindx; q];
    
    gfile=[ddir,gfiles{K}];
    
    disp(sprintf('      %g ... Working with %s',K,gfile))

    gtmp=getgrib(gfile,'LHTFL');   % latent heat flux
    Ds=squeeze(gtmp.data(:,:,2)');
    VARall(K,:,:)=Ds;
    
    % find indices at the hurricane eye
    dr=fnddist(hlon,hlat,hx(q),hy(q));
    ks=find(dr <= Ro);
       
    Im(1:length(ks),K)=ks(:);
    
    mnVAR(K)=nanmean(Ds(ks));
    
    clear ks q dr Ds
    end
end
hdn=hdn(cindx);
Rsize=Rsize(cindx);
hx=hx(cindx); 
hy=hy(cindx);

Im(Im==0)=nan;

mnVARtrack=repmat(nan,length(cindx),length(cindx));   % a matrix of mean LHTs 
                                % on a Hurricane footprint for the whole time period
for k=1:size(VARall,1)
    ssm=squeeze(VARall(k,:,:));       % a fixed day
    for p=1:length(cindx);         % x-direction
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        mnVARtrack(k,p)=nanmean(ssm(indx));     % mean LHT for pre and post storm passage
    end
end

%--------------------------------------------------------------------------
%   Diagnostic Part
%-------------------
knt=min(length(dn),length(hdn));

[hdn1,ij,jj]=intersect(hdn(:),dn(:));
hx1=hx(ij); hy1=hy(ij);

% color range
crange=[0:100:2600];
njet=length(crange)-1;

if iplot
%--- FIGURE 1: LHT on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.10 0.88 0.81]);
plot(Cs.Clom,Cs.Clam,'k'); grid; hold on;
% LHT on the storm footprint
for h=1:knt;
    ssm=repmat(nan,size(hlon));
    hsk=squeeze(VARall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;
    ssm(indx)=hsk(indx);
    
    if mod((dn(h)-dn(1)),1)==0
        pcolorhsk(hlon,hlat,(ssm)); shading flat; colorbar
        caxis([crange(1) crange(end)]); 
        %plot(hx1(h),hy1(h),'or','markersize',6)    
        avg=nanmean(ssm(indx));
        xx=hx1(h)+Rsize(h)/sqrt(2)/100;
        yy=hy1(h)+Rsize(h)/sqrt(2)/100;
        text(xx,yy,[num2str(round(avg),'%4d'),'W/m^2'],'fontsize',11,'color','k','fontweight','bold');
        
        clear xx yy avg
        
    end
end

% track
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
axis(lonlat);
set(gca,'tickdir','out','fontsize',11);
colormap(jet(njet)); 
hc=colorbar; set(hc,'tickdir','out');
xlabel('Longitude (^oW)');
ylabel('Latitude (^oN)');
% title(['Progressive Changes of ',fcst,' LHT on the ',Hname,' Footprint (',runID,')'],...
%     'fontsize',12,'fontweight','bold');
title([fcst,': ',runID,'  24-hourly LHT flux for ',Hname,' (IC=',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');
txt{1}='from';
txt{2}=datestr(dn(1),'yyyy/mm/dd HH:MMZ');
txt{3}=' to ';
txt{4}=datestr(dn(end),'yyyy/mm/dd HH:MMZ');
text(0.05,0.9,txt,'fontsize',13,'color','m','units','normalized','fontweight','bold');

if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png1name]); 
end

%--- FIGURE2: Hurricane's LHT foot-print: Stamp (6x6) Plot
%
% A) indiviual subplot locations for a 10x10 figure
np=10;
pd=0.084;
pys=0.085+pd*[0:np-1];
pxs=0.085+pd*[0:np-1];
[Px,Py]=meshgrid(pxs,pys);
Px=flipud(Px);
Py=flipud(Py);
axs=[Px(:),Py(:),repmat(pd,np*np,2)];        % each figure location

rscale=2;       % box size (1*rscale x 1*rscale)

% plotting
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': ',runID,' LHT for ',Hname,' (IC=',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');

for k=1:np;      % y-direction
    hsk=squeeze(VARall(k,:,:));       % a fixed day
    for p=1:np;         % x-direction
        r=(k-1)*np+p;
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   
        indx=Im(a,p); clear a;
        
        b=find(hdn==dn(p));                     % concurrent time
        if isempty(find(~isnan(hsk(indx))))
            plot(hx(b),hy(b),'.'); 
        else
            sss=nan(size(hsk));
            sss(indx)=hsk(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),(sss(ia,ja))); shading flat;
            clear ia ja sss 
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
         text(-0.15,0.8*rscale,[num2str(round(mnVARtrack(k,p)),'%4d')],'fontsize',9,'fontweight','bold');
        if k==1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,'fontweight','bold');
        end
        clear ia ja 
    end
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png2name]); 
end

% Stamp figure - 2
% Figure 2:
% B) indiviual subplot locations for a 10x10 figure
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': ',runID,' LHT for ',Hname,' (IC=',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');
for k=1+np:min(2*np,knt);      % y-direction
    hsk=squeeze(VARall(k,:,:));       % a fixed day
    for p=np+1:min(2*np,knt);         % x-direction

        b=find(hdn==dn(p));                     % concurrent time
        
        r=(k-1-np)*np+(p-np);
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        
        if isempty(find(~isnan(hsk(indx))))
            plot(hx(b),hy(b),'.'); 
        else
            ssm=nan(size(hlon));
            ssm(indx)=hsk(indx);
            [ia,ja]=find(~isnan(ssm)); 
            ia=unique(ia); ja=unique(ja);
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),ssm(ia,ja)); shading flat;
            clear ssm ia ja 
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        axis([-1 1 -1 1]*rscale);
        set(gca,'tickdir','out','ticklength',[0.05 0.025],'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        text(-0.15,0.8*rscale,[num2str(round(mnVARtrack(k,p)),'%4d')],'fontsize',9,'fontweight','bold');
        if k==np+1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
        clear indx a b r
    end
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
    clear ia ja 
end


if isave;
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png3name]); 
end

end;    % iplot

%--- FIGURE 4: Time series of mean LHT before, during and after storm
mnVAR=mnVAR(1:knt);
mnVARtrack=mnVARtrack(1:knt,1:knt);
C=mnVARtrack';
mnVARb=diag(C,-1);  % 6-hr before storm
mnVARa=diag(C,+1);  % 6-hr after storm

figure;
axes('position',[0.13 0.15 0.77 0.75]);
plot(hdn1(2:end),mnVARb,'-ok','markerfacecolor','b'); hold on; grid
plot(hdn1,mnVAR,'-ok','markerfacecolor','r'); 
plot(hdn1(1:end-1),mnVARa,'-ok','markerfacecolor','c');
legend('6-hr before','during','6-hr after','location','north','orientation','horizontal');
set(gca,'xtick',[hdn1(1:2:end)],'xlim',[hdn1(1) hdn1(end)],...
    'tickdir','out','ylim',[0 2500]); 
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
ylabel('Mean LHT (W/m^2)');
ttl{1}=[fcst,': ',runID,' Mean LHT'];
ttl{2}=['for ',Hname,' (IC=',yearmmddhh,')'];
title(ttl,'fontsize',12,'fontweight','bold');
xlabel(['Year ',num2str(year)],'fontsize',12)

if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png4name]); 
end


%--- FIGURE 5: Hurricane's delta LHT foot-print: Stamp (6x6) Plot
% figure 5:
% A) indiviual subplot locations for a 10x10 figure

% color range
crange=[-800:100:800]; njet=length(crange)-1;

%------------------------------------------------------ plotting 2 figures
%    of LHT difference for the past 6 hour and 12 hour
% build a matrix for subplot positions
np=10;
ixs=[0.0850+0.084*[0:np-1]]';
iys=[0.53 0.2];
Px=[ixs,repmat(iys(:,1),length(ixs),1),repmat([0.085 0.173],length(ixs),1)];
Py=[ixs,repmat(iys(:,2),length(ixs),1),repmat([0.085 0.173],length(ixs),1)];
Pxy=[Px;Py]; 
clear ixs iys Px Py

%--- 6 hour difference
%--- difference in LHT over the past 6 hour 
dVARall=repmat(nan,size(VARall));
tmp=diff(VARall); 
dVARall(2:end,:,:)=tmp;       % [W/m^2/hr]
clear tmp

figure('position',[190   441   811   430]);
axes('position',[0.085 0.80 0.84 0.02]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': ',runID,'  \deltaLHT_{6hr} (W/m^2) for ',Hname,' (IC=',yearmmddhh,')'],...
    'fontsize',12,'fontweight','bold');

for k=1:min(2*np,min(length(dn),length(hdn)));     % y-direction
    ssm=squeeze(dVARall(k,:,:));       % a fixed day
    %subplot(6,6,r)
    axes('position',Pxy(k,:));
    a=find(~isnan(Im(:,k)));
    indx=Im(a,k); clear a;

    b=find(hdn==dn(k));                     % concurrent time
    sss=nan(size(ssm));
    if isempty(indx) | isempty(find(~isnan(ssm(indx))))
        pcolorhsk(hlon-hx(b),hlat-hy(b),ssm); shading flat;
    else
        sss(indx)=ssm(indx);
        [ia,ja]=find(~isnan(sss)); 
        ia=unique(ia); ja=unique(ja);   
        pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
    end
    caxis([crange(1) crange(end)]); colormap(jet(njet)); 
    axis([-1 1 -1 1]*rscale);
    set(gca,'tickdir','out','ticklength',[0.05 0.025])
    set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
    text(-0.15,0.8*rscale,[num2str(round(nanmean(ssm(indx))),'%4g')],...
         'fontsize',9,'fontweight','bold');
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png5name]); 
end


% save output
eval(['save mnLHT',num2str(ncyc,'%03g'),'.mat C dn']);

% % end of the whole cycle

%keyboard

clear all; close all; pack

end
