% trackSST_R300.m
%		read in layer and water temperature data 
%       from a set of Stand-alone/Coupled HYCOM simulation grib files,
%       and
%       produce a set of the T footprints (size of eta-km) along a hurricane track. 
%
%-------
%	input
%-------
%			*.3d.grb   - layer-thickness for each layer (1-15)
%           nhc_Rita05.dat        - NHC disseminated hurricane information
%-------
% output
%-------
%       1. a set of 4 figures:
%               png1name=[fcst,'_',Hname,'_SST_HtrackR'];
%               png2name=[fcst,'_',Hname,'_SST_HtrackR_matrix'];
%               png3name=[fcst,'_',Hname,'_mnSST_HtrackR'];
%               png4name=[fcst,'_',Hname,'_mnSST_HtrackR_matrix'];
%								png5name=[fcst,'_',Hname,'_diffSST6hr_HtrackR_matrix'];
%								png6name=[fcst,'_',Hname,'_diffSST12hr_HtrackR_matrix'];
%
%       2. ascii output for an SST matrix as function of date (x) and distance (y).
%
%--------
% history
%--------
%   3/18/2009 Modified 'trackSST.m' by hsk.
%       1/29/3008 Modified 'diagnos_rtofs_trackSST.m' 
%               for Coupled/Stand-alone simulations. -hsk
%		11/19/2007 Edited by Hyun-Sook Kim
%
%------------------------------------------------------------------------
clear all; close all; 

%ncyc=24;

for ncyc=90:6:90
    
isave=1;

tsample=6;                  % sampling

%-------------------------------------------  Run information -------------
fcst='H4Y2'
domain='hep23';              % hurricane domain
year=2014;                  % year for interest of hurricane
mm=09;
dd=16;
hr=06;
Hname='Polo17e';             % Hurricane name

ID=Hname(end-2:end-1);

eta=300;

%-------------------------------------------------------- for users: ------
%  Number of cycle
% ncyc=108;

%------
dn0=datenum(year,mm,dd)+hr/24;
yearmmddhh=datestr(dn0,'yyyymmddHH');
dnc=dn0+ncyc/24;
nds=datestr(dnc,'ddHH');

runID=['cyc',num2str(ncyc,'%03d'),'-',nds];      % cycle ID: e.g., cyc102-2918

disp(' ..... ')
disp(['         Working on Cycle ',runID])
disp(' ')

%--- Data directory
ddir=['Z:\',fcst,'\',Hname,'\',yearmmddhh,'\',runID,'\ocean\'];       % run output directory
adir=['Z:\',fcst,'\',Hname,'\atcf\'];       % atcf directory

%--- output directory
% a folder for figure deposit 
odir=['Z:\',fcst,'\',Hname,'\',yearmmddhh,'\',runID,'\trackSST',num2str(eta),'km\'];     % directory for figures
disp(' ')
mdir=dir([odir]);
if length(mdir)==0
    [o1,o2,o3]=mkdir(odir);
    if o1==1
        disp(['     succesful to create ',odir,' directory'])
    end
else
    disp(['             the ',odir,' directory exists already!'])
end
clear mdir

%--- best track
%--- best HWRF hurricane file
nhc=caseread(['Z:\TPCtrack\y',num2str(year),'\b',domain(2:3),ID,num2str(year),'.dat']);
indx=strmatch('  34,',nhc(:,63:67),'exact');        % wind speed threshold (kt)
nhc=nhc(indx,:);    clear indx
nhy=str2num(nhc(:,35:38))/10;
nhx=(-1)*str2num(nhc(:,41:45))/10;
        if ~isempty(findstr(domain,'hwp'))
            nhx=nhx*(-1);
        end
npmin=str2num(nhc(:,53:57));
nvmax=str2num(nhc(:,48:51));
ndn=datenum(nhc(:,8:18),'yyyymmddHH');
        Rads=str2num(nhc(:,74:95))*1.8;     % size: [nm] to [km]
        bestR=[];
        for n=1:size(nhc,1)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            bestR(n)=mn;
            clear tmp mn
        end
best=[ndn nhx nhy npmin nvmax];
clear nhc nhx nhy npmin nvmax ndn

% output data filename
ofname=[fcst,'-',Hname,'-trackSST','.dat'];      % ASCII data filename for MLD

%--- setup date for data extraction
%  6-hour data - 
Dr=dir([ddir,'*.F*.3d.grb']);
dn=[];
if length(Dr)==0
    disp([' ... No Data in ',ddir,'...'])
else
  dn=dnc+[0:6:120]/24;
end

if ncyc<=6
    f4trk='seven07w';
else
    f4trk=lower(Hname);
end

%------------------------------------------------------------------
% Ancillary
%-----------
% hurricane domain: grid information
[hlon,hlat]=domain4hyhwrfv2(domain);
if isempty(findstr(domain,'hwp'))
    hlon=hlon-360;
end
lonlat=[min(hlon(:)) max(hlon(:)) min(hlat(:)) max(hlat(:))];

%----- Track:
% HWRF or GFS storm track file
frc='HWRF';
        dlook=dir([adir,'\',f4trk,'.',datestr(dnc,'yyyymmddHH'),'.trak.hwrf.atcfunix']);
        tfile=dlook.name;
        hsk=caseread([adir,'\',tfile]);            clear dlook tfile
        hhr=str2num(hsk(:,31:33));
        knt=str2num(hsk(:,65:66));      % reference knot
        % find index for reference wind speed=34kt
        ix=find(knt==34);
        hsk=hsk(ix,:);
        hx=-1*str2num(hsk(:,42:45))/10;
        if ~isempty(findstr(domain,'hwp'))
            hx=hx*(-1);
        end
        hy=str2num(hsk(:,36:38))/10; 
        hhr=hhr(ix);
        hdn=datenum(hsk(:,9:18),'yyyymmddHH')+hhr/24;
        Rads=str2num(hsk(:,74:95)) *1.8;     % size [nm] to [km]
        Rsize=[];
        for n=1:length(ix)
            tmp=Rads(n,:);
            mn=mean(tmp(tmp~=0));
            Rsize(n)=mn;
            clear tmp mn
        end
        clear Rads hhr B ix jx hsk

% %nhc=load('G:/NHC/nhc_Rita05.dat');           % NHC hurricane information
% %
% %   1    2   3  4  5   6   7       8         9        10   
% %  ----------------------------------------------------------
% %   year mon dy hh lat lon Prs(mb) wind(m/s) size(km) Prs_env
% %
% nhc=load(['G:/NHC/nhc_',Hname,'.dat']);           % NHC hurricane information
% hx=nhc(:,6); hy=nhc(:,5);
% hdn=datenum([nhc(:,1),nhc(:,2),nhc(:,3),nhc(:,4),repmat(0,length(hx),2)]);
% Rsize=nhc(:,end-1);           % the hurricane radius (km)
% 
%--------------------------------------------------------------------
% main section
%    1.Find a set of indicies along the hurricane track
%------------------------------------------------------

%--- figure output name:
png1name=[fcst,'_',Hname,'_SST_HtrackR'];
png2name=[fcst,'_',Hname,'_SST_HtrackR_matrix1'];
png3name=[fcst,'_',Hname,'_SST_HtrackR_matrix2'];
png4name=[fcst,'_',Hname,'_SST_timeseriesR'];
png5name=[fcst,'_',Hname,'_diffSST6hr_HtrackR_matrix'];
png6name=[fcst,'_',Hname,'_diffSST12hr_HtrackR_matrix'];
png7name=[fcst,'_',Hname,'_Cooling6hr_HtrackR_matrix'];

%====================================================== Assembling data ===
%--- assembling data
% work-space
Im=repmat(nan,eta,length(dn));       % collection of indicies each time step
mnSST=repmat(nan,length(dn),1);        % mean SST on a hurricane footprint                            
SSTall=repmat(nan,[length(dn),size(hlon)]); % SST for all 
disp(' ')
cindx=[];
for K=1:length(dn);

    % find indices at the hurricane eye
    q=find(hdn==dn(K));
    if ~isempty(q)
        
    cindx=[cindx; q];
    
    gfile=[ddir,Dr(K).name];
    
    %disp(sprintf('      %g ... Working with %s',K,gfile))

    gtmp1=getgrib(gfile,'WTMPC',[2,-1,-1],[2,-1,-1]);   % pot_temperature
    Ds=gtmp1.data;
    Ds(Ds>1e+10)=nan;
    SSTall(K,:,:)=Ds;

    % find indices at the hurricane eye
    dr=fnddist(hlon,hlat,hx(q),hy(q));
    %ks=find(dr <= Rsize(q));
    ks=find(dr <= eta);
    
    Im(1:length(ks),K)=ks(:);
    
    mnSST(K)=nanmean(Ds(ks));
    
    clear ks q dr Ds
    end
end
hdn=hdn(cindx);
Rsize=Rsize(cindx);
hx=hx(cindx); 
hy=hy(cindx);

Im(Im==0)=nan;

mnSSTtrack=repmat(nan,length(cindx),length(cindx));   % a matrix of mean SSTs 
                                % on a Hurricane footprint for the whole time period
stdSSTtrack=repmat(nan,length(cindx),length(cindx));   % a matrix of Standard deviation of SSTs 
                                % on a Hurricane footprint for the whole time period
for k=1:size(SSTall,1)
    ssm=squeeze(SSTall(k,:,:));       % a fixed day
    for p=1:length(cindx);         % x-direction
        a=find(~isnan(Im(:,p)));
        indx=Im(a,p); clear a;
        mnSSTtrack(k,p)=nanmean(ssm(indx));     % mean SST for pre and post storm passage
        stdSSTtrack(k,p)=nanstd(ssm(indx));
    end
end

%--------------------------------------------------------------------------
%   Diagnostic Part
%-------------------
knt=min(length(dn),length(hdn));

[hdn1,ij,jj]=intersect(hdn(:),dn(:));
hx1=hx(ij); hy1=hy(ij);

% color range
crange=[22:0.5:32];
njet=length(crange)-1;

%--- FIGURE 1: SST on a track map
figure('position',[300   400   833   515]);
axes('position',[0.09 0.11 0.88 0.81]);
%plot(Clom,Clam,'k'); grid; hold on;
% SST on the storm footprint
if isempty(findstr(domain,'hwp'))
    draw_wrldcst180('k'); 
else
    draw_wrldcst360('k'); 
end
hold on; grid
for h=1:14;
    ssm=squeeze(SSTall(h,:,:));
    a=find(~isnan(Im(:,h)));
    indx=Im(a,h); clear a;

    if mod((dn(h)-dn(1)),0.5)==0
        scatter(hlon(indx),hlat(indx),20,ssm(indx),'filled');
        caxis([crange(1) crange(end)]); 
        plot(hx1(h),hy1(h),'or','markersize',6)    
        avg=nanmean(ssm(indx));
        xx=hx1(h)+eta/sqrt(2)/eta;
        yy=hy1(h)+1.5*sqrt(2);
        text(xx,yy,[num2str(avg,'%3.1f'),'^oC'],'fontsize',11,'color','k','fontweight','bold');
        
        clear xx yy avg
        
    end
end
% track
plot(hx,hy,'-xk','markersize',5,'linewidth',1.5);
plot(best(:,2),best(:,3),'-x','color',repmat(0.5,1,3));
axis([floor(min(hlon(:))) ceil(max(hlon(:))) floor(min(hlat(:))) ceil(max(hlat(:)))]);
set(gca,'tickdir','out','fontsize',12);
colormap(jet(njet)); 
hc=colorbar; set(hc,'tickdir','out','fontsize',12);
xlabel('Longitude (^oE)','fontsize',13);
ylabel('Latitude (^oN)','fontsize',13); box on;
% title(['Progressive Changes of ',fcst,' SST on the ',Hname,' Footprint (',runID,')'],...
%     'fontsize',12,'fontweight','bold');
% title([fcst,': ',runID,'  24-hourly SST for ',Hname,' (IC=',dnc,')'],...
%     'fontsize',12,'fontweight','bold');
% txt{1}='from';
% txt{2}=datestr(dn(1),'yyyy/mm/dd HH:MMZ');
% txt{3}=' to ';
% txt{4}=datestr(dn(end),'yyyy/mm/dd HH:MMZ');
% text(0.05,0.9,txt,'fontsize',13,'color','m','units','normalized','fontweight','bold');

if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png1name]); 
end

%--- FIGURE2: Hurricane's SST foot-print: Stamp (6x6) Plot
%
% A) indiviual subplot locations for a 10x10 figure
np=10;
pd=0.084;
pys=0.085+pd*[0:np-1];
pxs=0.085+pd*[0:np-1];
[Px,Py]=meshgrid(pxs,pys);
Px=flipud(Px);
Py=flipud(Py);
axs=[Px(:),Py(:),repmat(pd,np*np,2)];        % each figure location

rscale=4;       % box size (1*rscale x 1*rscale)
sscale=20;      % size of mark for scatter

% plotting
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': SST for ',[Hname(1:end-2),' ',upper(Hname(end-2:end))],' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');

for k=1:np;      % y-direction
    ssm=squeeze(SSTall(k,:,:));       % a fixed day
    for p=1:np;         % x-direction
        r=(k-1)*np+p;
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   
        indx=Im(a,p); clear a;
        
            sss=nan(size(ssm));
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
        
        b=find(hdn==dn(p));                     % concurrent time
        if isempty(indx) | isempty(ia) | length(ia)==1
            plot(hx(b),hy(b),'.'); 
        else
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),(sss(ia,ja))); shading flat;
            clear ia ja sss 
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        set(gca,'xlim',[-1 1]*rscale,'ylim',[-1 1]*rscale,'tickdir','out',...
            'ticklength',[0.05 0.025])
        set(gca,'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
         text(-0.15,0.8*rscale,[num2str(mnSSTtrack(k,p),'%4.1f'),'^oC'],...
             'fontsize',9,'fontweight','bold');
         box on
        if k==1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
    end
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png2name]); 
end
% Stamp figure - 2
% Figure 2:
% B) indiviual subplot locations for a 10x10 figure
figure('position',[190   141   811   793]);
axes('position',[0.085 0.96 0.84 0.01]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,':  SST for ',[Hname(1:end-2),' ',upper(Hname(end-2:end))],' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');

for k=1+np:min(2*np,knt);      % y-direction
    ssm=squeeze(SSTall(k,:,:));       % a fixed day
    for p=np+1:min(2*np,knt);         % x-direction
        r=(k-1-np)*np+(p-np);
        %subplot(6,6,r)
        axes('position',axs(r,:));
        if ismember(r,[1:np+1:np*np]); 
            plot([-1 1]*rscale,[1 -1]*rscale,'k'); hold on; 
        end
        a=find(~isnan(Im(:,p)));   
        indx=Im(a,p); clear a;

            sss=nan(size(ssm));
            sss(indx)=ssm(indx);
            [ia,ja]=find(~isnan(sss)); 
            ia=unique(ia); ja=unique(ja);
        
        b=find(hdn==dn(p));                     % concurrent time
        if isempty(indx) | isempty(ia) | length(ia)==1
            plot(hx(b),hy(b),'.'); 
        else
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),(sss(ia,ja))); shading flat;
            clear ia ja sss 
        end
        caxis([crange(1) crange(end)]); colormap(jet(njet)); 
        set(gca,'xlim',[-1 1]*rscale,'ylim',[-1 1]*rscale,'tickdir','out',...
            'ticklength',[0.05 0.025])
        set(gca,'xticklabel',[],'yticklabel',[]);
        if mod(p,np)==0; 
            set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]); 
        end
        text(-0.15,0.8*rscale,[num2str(mnSSTtrack(k,p),'%4.1f'),'^oC'],...
             'fontsize',9,'fontweight','bold');
        box on
        if k==np+1;        % (lat,lon) at time
            ylabel(['(',num2str(-hx(b),'%4.1f'),',',...
                num2str(hy(b),'%4.1f'),')'],'rotation',90,'fontsize',9,...
                'fontweight','bold');
        end
    end
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png3name]); 
end
%--------------------- stamp figure: end ----------------------------------

%--- FIGURE 4: Time series of mean SST before, during and after storm
mnSST=mnSST(1:knt);
mnSSTtrack=mnSSTtrack(1:knt,1:knt);
C=mnSSTtrack';
mnSSTb=diag(C,-1);  % 6-hr before storm
mnSSTa=diag(C,+1);  % 6-hr after storm

S=stdSSTtrack';     % standard deviation
crange=[20:0.2:28];
figure;
axes('position',[0.13 0.15 0.77 0.75]);
plot(hdn1(2:end),mnSSTb,'-ok','markerfacecolor','b'); hold on; grid
plot(hdn1,mnSST,'-ok','markerfacecolor','r'); 
plot(hdn1(1:end-1),mnSSTa,'-ok','markerfacecolor','c');
legend('6-hr before','during','6-hr after','orientation','vertical',4);
set(gca,'xtick',[hdn1(1:2:end)],'xlim',[hdn1(1) hdn1(end)],...
    'tickdir','out','ylim',[crange(1) crange(2)]); 
%    'tickdir','out','ylim',[23 33]); 
datetickhsk('x','mm/dd HH','keeplimits','keepticks');
ylabel('Mean SST (^oC)');
ttl{1}=[fcst,': Mean SST'];
ttl{2}=['for ',[Hname(1:end-2),' ',upper(Hname(end-2:end))],' (IC=',datestr(dnc,'yyyymmddHH'),')'];
title(ttl,'fontsize',12,'fontweight','bold');
xlabel(['Year ',num2str(year)],'fontsize',12)

if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png4name]); 
end


%--- FIGURE 5: Hurricane's delta SST foot-print: Stamp (6x6) Plot
% figure 5:
% A) indiviual subplot locations for a 10x10 figure

% color range
crange=[-5:0.5:3]; njet=length(crange)-1;

%------------------------------------------------------ plotting 2 figures
%                         of SST difference for the past 6 hour and 12 hour
% build a matrix for subplot positions
ixs=[0.0850+0.084*[0:np-1]]';
iys=[0.53 0.2];
Px=[ixs,repmat(iys(:,1),length(ixs),1),repmat([0.085 0.173],length(ixs),1)];
Py=[ixs,repmat(iys(:,2),length(ixs),1),repmat([0.085 0.173],length(ixs),1)];
Pxy=[Px;Py]; 
clear ixs iys Px Py

%--- 6 hour difference
%--- difference in SST over the past 6 hour 
dSSTall=repmat(nan,size(SSTall));
tmp=diff(SSTall); 
dSSTall(2:end,:,:)=tmp; 
clear tmp

figure('position',[190   441   811   430]);
axes('position',[0.085 0.80 0.84 0.02]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': \deltaSST_{6hr} for ',[Hname(1:end-2),' ',upper(Hname(end-2:end))],' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');

for k=1:min(2*np,min(length(dn),length(hdn)));     % y-direction
    ssm=squeeze(dSSTall(k,:,:));       % a fixed day
    %subplot(6,6,r)
    axes('position',Pxy(k,:));
    a=find(~isnan(Im(:,k)));
    indx=Im(a,k); clear a;

    b=find(hdn==dn(k));                     % concurrent time
    sss=nan(size(ssm));
    sss(indx)=ssm(indx);
    [ia,ja]=find(~isnan(sss)); 
    ia=unique(ia); ja=unique(ja);   
    if isempty(indx) | isempty(ia) | length(ia)==1
        pcolorhsk(hlon-hx(b),hlat-hy(b),ssm); shading flat;
    else
        pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
    end
    caxis([crange(1) crange(end)]); colormap(jet(njet)); 
    set(gca,'xlim',[-1 1]*rscale,'ylim',[-1 1]*rscale,'tickdir','out',...
            'ticklength',[0.05 0.025])
    set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]);     
    text(-0.15,0.8*rscale,[num2str(nanmean(ssm(indx)),'%4.1f'),'^oC'],...
         'fontsize',9,'fontweight','bold');
    box on
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png5name]); 
end

% %--- 12 hour difference
% %--- difference in SST over the past 12-hour 
% d2SSTall=repmat(nan,size(SSTall));
% tmp=SSTall(3:end,:,:)-SSTall(1:end-2,:,:);
% d2SSTall(3:end,:,:)=tmp; 
% clear tmp
% 
% figure('position',[190   441   811   430]);
% axes('position',[0.085 0.80 0.84 0.02]);
% pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
% set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
% title([fcst,': ',runID,' \deltaSST_{12hr} for ',Hname,' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
%     'fontsize',12,'fontweight','bold');
% 
% for k=1:min(2*np,min(length(dn),length(hdn)));      % y-direction
%     
%     ssm=squeeze(d2SSTall(k,:,:));       % a fixed day
%     %subplot(6,6,r)
%     axes('position',Pxy(k,:));
%     a=find(~isnan(Im(:,k)));
%     indx=Im(a,k); clear a;
% 
%     b=find(hdn==dn(k));                     % concurrent time
%     sss=nan(size(ssm));
%         sss(indx)=ssm(indx);
%         [ia,ja]=find(~isnan(sss)); 
%         ia=unique(ia); ja=unique(ja);   
%     if isempty(indx) | isempty(ia) | length(ia)==1
%         pcolorhsk(hlon-hx(b),hlat-hy(b),ssm); shading flat;
%     else
%         pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
%     end
%     caxis([crange(1) crange(end)]); colormap(jet(njet)); 
%     set(gca,'xlim',[-1 1]*rscale,'ylim',[-1 1]*rscale,'tickdir','out',...
%             'ticklength',[0.05 0.025])
%     set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
%                 'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]);     
%     text(-0.15,0.8*rscale,[num2str(nanmean(ssm(indx)),'%4.1f'),'^oC'],...
%          'fontsize',9,'fontweight','bold');
%     box on
%     xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
% end
% if isave; 
%     set(gcf,'paperpositionmode','auto');
%     eval(['print -dpng ',odir,'\',png6name]); 
% end
% 
%--- 6 hour difference
%--- SST cooling 6 hr after the storm pass
dSSTall3=repmat(nan,size(SSTall));
dSSTall3(1,:,:)=SSTall(1,:,:);
for kk=2:size(SSTall,1);
    tmp=squeeze(SSTall(kk,:,:)-SSTall(1,:,:)); 
    dSSTall3(kk,:,:)=tmp; 
clear tmp
end

ixs=[0.0550+0.089*[0:np-1]]';
iys=[0.55 0.2];
Px=[ixs,repmat(iys(:,1),length(ixs),1),repmat([0.089 0.178],length(ixs),1)];
Py=[ixs,repmat(iys(:,2),length(ixs),1),repmat([0.089 0.178],length(ixs),1)];
Pxy=[Px;Py]; 
crange=[-8:0.5:1]; njet=length(crange)-1;

figure('position',[190   441   811   430]);
axes('position',[0.055 0.82 0.896 0.02]);
pcolor([crange;crange]); caxis([crange(1) crange(end)]); colormap(jet(njet));
set(gca,'yticklabel',[],'xtick',[1:length(crange)],'xticklabel',[crange]); 
title([fcst,': \deltaSST for ',[Hname(1:end-2),' ',upper(Hname(end-2:end))],' (IC=',datestr(dnc,'yyyymmddHH'),')'],...
    'fontsize',12,'fontweight','bold');
cooling=[];
for k=2:min(2*np,min(length(dn),length(hdn)));     % y-direction
    ssm=squeeze(dSSTall3(k,:,:));       % a fixed day
    %subplot(6,6,r)
    axes('position',Pxy(k,:));
    a=find(~isnan(Im(:,k)));
    indx=Im(a,k); clear a;

    b=find(hdn==dn(k));                     % concurrent time
    sss=nan(size(ssm));
    sss(indx)=ssm(indx);
    [ia,ja]=find(~isnan(sss)); 
    ia=unique(ia); ja=unique(ja);  
    if k>=21
        indx=[]; ia=[];
    else
        if isempty(indx) | isempty(ia) | length(ia)==1
            pcolorhsk(hlon-hx(b),hlat-hy(b),ssm); shading flat;
        else
            pcolorhsk(hlon(ia,ja)-hx(b),hlat(ia,ja)-hy(b),sss(ia,ja)); shading flat;
        end
    end
    caxis([crange(1) crange(end)]); colormap(jet(njet)); 
    set(gca,'xlim',[-1 1]*rscale,'ylim',[-1 1]*rscale,'tickdir','out',...
            'ticklength',[0.05 0.025])
    set(gca,'xtick',[-floor(rscale) 0 floor(rscale)],...
                'xticklabel',[-floor(rscale) 0 floor(rscale)],'yticklabel',[]);     
    text(-0.15,0.8*rscale,[num2str(nanmin(ssm(indx)),'%4.1f'),'^oC'],...
         'fontsize',9,'fontweight','bold');
     cooling=[cooling; nanmin(ssm(indx))];
    box on
    xlabel(datestr(hdn1(k),'mm/dd HH'),'fontsize',11,'fontweight','bold')
end
if isave; 
    set(gcf,'paperpositionmode','auto');
    eval(['print -dpng ',odir,'\',png7name]); 
end

% save output
eval(['save mnSST',num2str(eta),'R',num2str(ncyc,'%03g'),'.mat C  S dn cooling']);


keyboard


end
