function tsdiagram(S,T,P,sigma,color);
% TSDIAGRM  This function plots a temp vs. salinity diagram,
%            with selected density contours.
%
%            TSDIAGRM(S,T,P,Nlines,color) draws contours lines (range of sigma) of density anomaly
%            SIGMA (kg/m^3) at pressure P (dbars), given a range of
%            salinity (ppt) and temperature (deg C) in the 2-element vectors
%            S&T in color of 'color'.  The freezing point (if visible) will
%            be indicated.
%
%            TSDIAGRM(S,T,P) draws several randomly chosen contours.
%
%            Default:
%                   Nlines    = 10
%                   color     = blue


%Notes: RP (WHOI) 9/Dec/91
%                 7/Nov/92 Changed for Matlab 4.0
%                 14/Mar/94 Made P optional.

if (nargin<2),
   error('tsdiagram: Not enough calling parameters');
elseif (nargin==2),
   P=0;
   sigma=[20:0.2:40]; color='b';
elseif (nargin==3),
   sigma=[20:0.2:40]; color='b';
elseif (nargin==4)
    color='b';
end;

% Convert to columns to be on the safe side
%Nlines=Nlines(:);


% grid points ofr contouring
Smax=max(S(:))+1.5;
Smin=min(S(:))-1.5;
Tmax=max(T(:))+2;
Tmin=min(T(:))-2;

Sg=Smin+[0:40]/40*(Smax-Smin);
Tg=Tmin+[0:40]'/40*(Tmax-Tmin);


[SV,SG]=swstate(ones(size(Tg))*Sg,Tg*ones(size(Sg)),0);
%%[SV,SG]=swstate(ones(size(Tg))*Sg,Tg*ones(size(Sg)),P(1));
%[SV,SG]=swstate(repmat(Tg,1,length(Sg)),repmat(Sg,1,length(Tg)),P(1));

%cla;

[CS,H]=contour(Sg,Tg,SG,sigma,':');
hold on
plot(S,T,'*','markersize',4,'color',color);
%axis('square');
clabel(CS,H);

ax=get(gca,'xlim');
ay=get(gca,'ylim');

if ax(1)<Smin; Smin=ax(1); end
if ax(2)>Smax; Smax=ax(2); end
if ay(1)<Tmin; Tmin=ay(1); end
if ay(2)>Tmax; Tmax=ay(2); end
set(gca,'xlim',[Smin Smax],'ylim',[Tmin Tmax]);

xlabel('Salinity (ppt)');
ylabel('Temperature (^oC)');

%plot freezing temp.
freezeT=swfreezt(S,P(1));
line(S,freezeT,'LineStyle','--');


%if (max(size(sigma))==1), clabel(CS);
%else                      clabel(CS,sigma);
%end;

% Label with pressure, then return to other axes

text(Smin+0.05,Tmax-0.5, ...
[' Pressure = ' int2str(P(1)) ' dbars'],'horiz','left','Vert','top','color','r');