%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% GRiB Edition 1 Parameter Table, copped from WGRIB %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function Set_Parameter_Table(ParamTable)
global Parameter_Table 
global ScreenDiag

switch ParamTable
   
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %    NCEP OPERational parameter table                   %
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
   case 'NCEPOPER'
      Parameter_Table={...
      {'var0','undefined',''},...
      {'PRES','Pressure ','Pa'},...				       
      {'PRMSL','Pressure reduced to MSL ','Pa'},...		       
      {'PTEND','Pressure tendency ','Pa/s'},...		       
      {'PVORT','Pot. vorticity ','km^2/kg/s'},...		       
      {'ICAHT','ICAO Standard Atmosphere Reference Height ','M'},... 
      {'GP','Geopotential ','m^2/s^2'},...			       
      {'HGT','Geopotential height ','gpm'},...		       
      {'DIST','Geometric height ','m'},...			       
      {'HSTDV','Std dev of height ','m'},...  		       
      {'TOZNE','Total ozone ','Dobson'},...
      {'TMP','Temp. ','K'},...
      {'VTMP','Virtual temp. ','K'},...
      {'POT','Potential temp. ','K'},...
      {'EPOT','Pseudo-adiabatic pot. temp. ','K'},...
      {'TMAX','Max. temp. ','K'},...
      {'TMIN','Min. temp. ','K'},...
      {'DPT','Dew point temp. ','K'},...
      {'DEPR','Dew point depression ','K'},...
      {'LAPR','Lapse rate ','K/m'},...
      {'VIS','Visibility ','m'},...
      {'RDSP1','Radar spectra (1) ','non-dim'},...
      {'RDSP2','Radar spectra (2) ','non-dim'},...
      {'RDSP3','Radar spectra (3) ','non-dim'},...
      {'PLI','Parcel lifted index (to 500 hPa) ','K'},...
      {'TMPA','Temp. anomaly ','K'},...
      {'PRESA','Pressure anomaly ','Pa'},...
      {'GPA','Geopotential height anomaly ','gpm'},...
      {'WVSP1','Wave spectra (1) ','non-dim'},...
      {'WVSP2','Wave spectra (2) ','non-dim'},...
      {'WVSP3','Wave spectra (3) ','non-dim'},...
      {'WDIR','Wind direction ','deg'},...
      {'WIND','Wind speed ','m/s'},...
      {'UGRD','u wind ','m/s'},...
      {'VGRD','v wind ','m/s'},...
      {'STRM','Stream function ','m^2/s'},...
      {'VPOT','Velocity potential ','m^2/s'},...
      {'MNTSF','Montgomery stream function ','m^2/s^2'},...
      {'SGCVV','Sigma coord. vertical velocity ','/s'},...
      {'VVEL','Pressure vertical velocity ','Pa/s'},...
      {'DZDT','Geometric vertical velocity ','m/s'},...
      {'ABSV','Absolute vorticity ','/s'},...
      {'ABSD','Absolute divergence ','/s'},...
      {'RELV','Relative vorticity ','/s'},...
      {'RELD','Relative divergence ','/s'},...
      {'VUCSH','Vertical u shear ','/s'},...
      {'VVCSH','Vertical v shear ','/s'},...
      {'DIRC','Direction of current ','deg'},...
      {'SPC','Speed of current ','m/s'},...
      {'UOGRD','u of current ','m/s'},...
      {'VOGRD','v of current ','m/s'},...
      {'SPFH','Specific humidity ','kg/kg'},...
      {'RH','Relative humidity ','%'},...
      {'MIXR','Humidity mixing ratio ','kg/kg'},...
      {'PWAT','Precipitable water ','kg/m^2'},...
      {'VAPP','Vapor pressure ','Pa'},...
      {'SATD','Saturation deficit ','Pa'},...
      {'EVP','Evaporation ','kg/m^2'},...
      {'CICE','Cloud Ice ','kg/kg'},...
      {'PRATE','Precipitation rate ','kg/m^2/s'},...
      {'TSTM','Thunderstorm probability ','%'},...
      {'APCP','Total precipitation ','kg/m^2'},...
      {'NCPCP','Large scale precipitation ','kg/m^2'},...
      {'ACPCP','Convective precipitation ','kg/m^2'},...
      {'SRWEQ','Snowfall rate water equiv. ','kg/m^2/s'},...
      {'WEASD','Accum. snow ','kg/m^2'},...
      {'SNOD','Snow depth ','m'},...
      {'MIXHT','Mixed layer depth ','m'},...
      {'TTHDP','Transient thermocline depth ','m'},...
      {'MTHD','Main thermocline depth ','m'},...
      {'MTHA','Main thermocline anomaly ','m'},...
      {'TCDC','Total cloud cover ','%'},...
      {'CDCON','Convective cloud cover ','%'},...
      {'LCDC','Low level cloud cover ','%'},...
      {'MCDC','Mid level cloud cover ','%'},...
      {'HCDC','High level cloud cover ','%'},...
      {'CWAT','Cloud water ','kg/kg'},...
      {'BLI','Best lifted index (to 500 hPa) ','K'},...
      {'SNOC','Convective snow ','kg/m^2'},...
      {'SNOL','Large scale snow ','kg/m^2'},...
      {'WTMP','Water temp. ','K'},...
      {'LAND','Land cover (land=1;sea=0) ','fraction'},...
      {'DSLM','Deviation of sea level from mean ','m'},...
      {'SFCR','Surface roughness ','m'},...
      {'ALBDO','Albedo ','%'},...
      {'TSOIL','Soil temp. ','K'},...
      {'SOILM','Soil moisture content ','kg/m^2'},...
      {'VEG','Vegetation ','%'},...
      {'SALTY','Salinity ','kg/kg'},...
      {'DEN','Density ','kg/m^3'},...
      {'WATR','Water runoff ','kg/m^2'},...
      {'ICEC','Ice concentration (ice=1;no ice=0) ','fraction'},...
      {'ICETK','Ice thickness ','m'},...
      {'DICED','Direction of ice drift ','deg'},...
      {'SICED','Speed of ice drift ','m/s'},...
      {'UICE','u of ice drift ','m/s'},...
      {'VICE','v of ice drift ','m/s'},...
      {'ICEG','Ice growth rate ','m/s'},...
      {'ICED','Ice divergence ','/s'},...
      {'SNOM','Snow melt ','kg/m^2'},...
      {'HTSGW','Sig height of wind waves and swell ','m'},...
      {'WVDIR','Direction of wind waves ','deg'},...
      {'WVHGT','Sig height of wind waves ','m'},...
      {'WVPER','Mean period of wind waves ','s'},...
      {'SWDIR','Direction of swell waves ','deg'},...
      {'SWELL','Sig height of swell waves ','m'},...
      {'SWPER','Mean period of swell waves ','s'},...
      {'DIRPW','Primary wave direction ','deg'},...
      {'PERPW','Primary wave mean period ','s'},...
      {'DIRSW','Secondary wave direction ','deg'},...
      {'PERSW','Secondary wave mean period ','s'},...
      {'NSWRS','Net short wave (surface) ','W/m^2'},...
      {'NLWRS','Net long wave (surface) ','W/m^2'},...
      {'NSWRT','Net short wave (top) ','W/m^2'},...
      {'NLWRT','Net long wave (top) ','W/m^2'},...
      {'LWAVR','Long wave ','W/m^2'},...
      {'SWAVR','Short wave ','W/m^2'},...
      {'GRAD','Global radiation ','W/m^2'},...
      {'BRTMP','Brightness temperature ','K'},...
      {'LWRAD','Radiance with respect to wave no. ','W/m/sr'},...
      {'SWRAD','Radiance with respect ot wave len. ','W/m^3/sr'},...
      {'LHTFL','Latent heat flux ','W/m^2'},...
      {'SHTFL','Sensible heat flux ','W/m^2'},...
      {'BLYDP','Boundary layer dissipation ','W/m^2'},...
      {'UFLX','Zonal momentum flux ','N/m^2'},...
      {'VFLX','Meridional momentum flux ','N/m^2'},...
      {'WMIXE','Wind mixing energy ','J'},...
      {'IMGD','Image data ',''},...
      {'MSLSA','Mean sea level pressure (Std Atm) ','Pa'},...
      {'MSLMA','Mean sea level pressure (MAPS) ','Pa'},...
      {'MSLET','Mean sea level pressure (ETA model) ','Pa'},...
      {'LFTX','Surface lifted index ','K'},...
      {'4LFTX','Best (4-layer) lifted index ','K'},...
      {'KX','K index ','K'},...
      {'SX','Sweat index ','K'},...
      {'MCONV','Horizontal moisture divergence ','kg/kg/s'},...
      {'VWSH','Vertical speed shear ','1/s'},...
      {'TSLSA','3-hr pressure tendency (Std Atmos Red) ','Pa/s'},...
      {'BVF2','Brunt-Vaisala frequency^2 ','1/s^2'},...
      {'PVMW','Potential vorticity (mass-weighted) ','1/s/m'},...
      {'CRAIN','Categorical rain ','yes=1;no=0'},...
      {'CFRZR','Categorical freezing rain ','yes=1;no=0'},...
      {'CICEP','Categorical ice pellets ','yes=1;no=0'},...
      {'CSNOW','Categorical snow ','yes=1;no=0'},...
      {'SOILW','Volumetric soil moisture ','fraction'},...
      {'PEVPR','Potential evaporation rate ','W/m^2'},...
      {'CWORK','Cloud work function ','J/kg'},...
      {'U-GWD','Zonal gravity wave stress ','N/m^2'},...
      {'V-GWD','Meridional gravity wave stress ','N/m^2'},...
      {'PV','Potential vorticity ','m^2/s/kg'},...
      {'COVMZ','Covariance between u and v ','m^2/s^2'},...
      {'COVTZ','Covariance between u and T ','K*m/s'},...
      {'COVTM','Covariance between v and T ','K*m/s'},...
      {'CLWMR','Cloud water ','kg/kg'},...
      {'O3MR','Ozone mixing ratio ','kg/kg'},...
      {'GFLUX','Ground heat flux ','W/m^2'},...
      {'CIN','Convective inhibition ','J/kg'},...
      {'CAPE','Convective Avail. Pot. Energy ','J/kg'},...
      {'TKE','Turbulent kinetic energy ','J/kg'},...
      {'CONDP','Lifted parcel condensation pressure ','Pa'},...
      {'CSUSF','Clear sky upward solar flux ','W/m^2'},...
      {'CSDSF','Clear sky downward solar flux ','W/m^2'},...
      {'CSULF','Clear sky upward long wave flux ','W/m^2'},...
      {'CSDLF','Clear sky downward long wave flux ','W/m^2'},...
      {'CFNSF','Cloud forcing net solar flux ','W/m^2'},...
      {'CFNLF','Cloud forcing net long wave flux ','W/m^2'},...
      {'VBDSF','Visible beam downward solar flux ','W/m^2'},...
      {'VDDSF','Visible diffuse downward solar flux ','W/m^2'},...
      {'NBDSF','Near IR beam downward solar flux ','W/m^2'},...
      {'NDDSF','Near IR diffuse downward solar flux ','W/m^2'},...
      {'RWMR','Rain water mixing ratio ','kg/kg'},...
      {'SNMR','Snow mixing ratio ','kg/kg'},...
      {'MFLX','Momentum flux ','N/m^2'},...
      {'LMH','Mass point model surface ','non-dim'},...
      {'LMV','Velocity point model surface ','non-dim'},...
      {'MLYNO','Model layer number (from bottom up) ','non-dim'},...
      {'NLAT','Latitude (-90 to +90) ','deg'},...
      {'ELON','East longitude (0-360) ','deg'},...
      {'ICMR','Ice mixing ratio ','kg/kg'},...
      {'GRMR','Graupel mixing ratio ','kg/kg'},...
      {'GUST','Surface wind gust ','m/s'},...
      {'LPSX','x-gradient of log pressure ','1/m'},...
      {'LPSY','y-gradient of log pressure ','1/m'},...
      {'HGTX','x-gradient of height ','m/m'},...
      {'HGTY','y-gradient of height ','m/m'},...
      {'TURB','Turbulence SIGMET/AIRMET ','non-dim'},...
      {'ICNG','Icing SIGMET/AIRMET ','non-dim'},...
      {'LTNG','Lightning ','non-dim'},...
      {'DRIP','Rate of water dropping from canopy to gnd ','kg/m^2'},...
      {'VPTMP','Virtual pot. temp. ','K'},...
      {'HLCY','Storm relative helicity ','m^2/s^2'},...
      {'PROB','Prob. from ensemble ','non-dim'},...
      {'PROBN','Prob. from ensemble norm. to clim. expect. ','non-dim'},...
      {'POP','Prob. of precipitation ','%'},...
      {'CPOFP','Prob. of frozen precipitation ','%'},...
      {'CPOZP','Prob. of freezing precipitation ','%'},...
      {'USTM','u-component of storm motion ','m/s'},...
      {'VSTM','v-component of storm motion ','m/s'},...
      {'NCIP','No. concen. ice particles ',''},...
      {'EVBS','Direct evaporation from bare soil ','W/m^2'},...
      {'EVCW','Canopy water evaporation ','W/m^2'},...
      {'ICWAT','Ice-free water surface ','%'},...
      {'CWDI','Convective weather detection index ',''},...
      {'VAFTAD','VAFTAD?? ','??'},...
      {'DSWRF','Downward short wave flux ','W/m^2'},...
      {'DLWRF','Downward long wave flux ','W/m^2'},...
      {'UVI','Ultra violet index (1 hour centered at solar noon) ','J/m^2'},...
      {'MSTAV','Moisture availability ','%'},...
      {'SFEXC','Exchange coefficient ','(kg/m^3)(m/s)'},...
      {'MIXLY','No. of mixed layers next to surface ','integer'},...
      {'TRANS','Transpiration ','W/m^2'},...
      {'USWRF','Upward short wave flux ','W/m^2'},...
      {'ULWRF','Upward long wave flux ','W/m^2'},...
      {'CDLYR','Non-convective cloud ','%'},...
      {'CPRAT','Convective precip. rate ','kg/m^2/s'},...
      {'TTDIA','Temp. tendency by all physics ','K/s'},...
      {'TTRAD','Temp. tendency by all radiation ','K/s'},...
      {'TTPHY','Temp. tendency by non-radiation physics ','K/s'},...
      {'PREIX','Precip index (0.0-1.00) ','fraction'},...
      {'TSD1D','Std. dev. of IR T over 1x1 deg area ','K'},...
      {'NLGSP','Natural log of surface pressure ','ln(kPa)'},...
      {'HPBL','Planetary boundary layer height ','m'},...
      {'5WAVH','5-wave geopotential height ','gpm'},...
      {'CNWAT','Plant canopy surface water ','kg/m^2'},...
      {'SOTYP','Soil type (Zobler) ','0..9'},...
      {'VGTYP','Vegetation type (as in SiB) ','0..13'},...
      {'BMIXL','Blackadars mixing length scale ','m'},...
      {'AMIXL','Asymptotic mixing length scale ','m'},...
      {'PEVAP','Pot. evaporation ','kg/m^2'},...
      {'SNOHF','Snow phase-change heat flux ','W/m^2'},...
      {'5WAVA','5-wave geopot. height anomaly ','gpm'},...
      {'MFLUX','Convective cloud mass flux ','Pa/s'},...
      {'DTRF','Downward total radiation flux ','W/m^2'},...
      {'UTRF','Upward total radiation flux ','W/m^2'},...
      {'BGRUN','Baseflow-groundwater runoff ','kg/m^2'},...
      {'SSRUN','Storm surface runoff ','kg/m^2'},...
      {'SIPD','Supercooled large droplet (SLD) icing pot. diagn. ',''},...
      {'O3TOT','Total ozone ','kg/m^2'},...
      {'SNOWC','Snow cover ','%'},...
      {'SNOT','Snow temp. ','K'},...
      {'COVTW','Covariance T and w ','K*m/s'},...
      {'LRGHR','Large scale condensation heating ','K/s'},...
      {'CNVHR','Deep convective heating ','K/s'},...
      {'CNVMR','Deep convective moistening ','kg/kg/s'},...
      {'SHAHR','Shallow convective heating ','K/s'},...
      {'SHAMR','Shallow convective moistening ','kg/kg/s'},...
      {'VDFHR','Vertical diffusion heating ','K/s'},...
      {'VDFUA','Vertical diffusion zonal accel ','m/s^2'},...
      {'VDFVA','Vertical diffusion meridional accel ','m/s^2'},...
      {'VDFMR','Vertical diffusion moistening ','kg/kg/s'},...
      {'SWHR','Solar radiative heating ','K/s'},...
      {'LWHR','Longwave radiative heating ','K/s'},...
      {'CD','Drag coefficient ','non-dim'},...
      {'FRICV','Friction velocity ','m/s'},...
      {'RI','Richardson number ','non-dim'},...
      {'var255','undefined',''}};

   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %    NCEP REANalysis parameter table                    %
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

   case 'NCEPREAN'
      Parameter_Table={...
      {'var0',    'undefined',''},...
      {'PRES',    'Pressure','Pa'},...
      {'PRMSL',   'Pressure reduced to MSL','Pa'},...
      {'PTEND',   'Pressure tendency','Pa/s'},...
      {'var4',    'undefined',''},...
      {'var5',    'undefined',''},...
      {'GP',      'Geopotential','m^2/s^2'},...
      {'HGT',     'Geopotential height','gpm'},...
      {'DIST',    'Geometric height','m'},...
      {'HSTDV',   'Std dev of height','m'},...
      {'HVAR',   'Variance of height','m^2'},...
      {'TMP',    'Temp.','K'},...
      {'VTMP',   'Virtual temp.','K'},...
      {'POT',    'Potential temp.','K'},...
      {'EPOT',   'Pseudo-adiabatic pot. temp.','K'},...
      {'TMAX',   'Max. temp.','K'},...
      {'TMIN',   'Min. temp.','K'},...
      {'DPT',    'Dew point temp.','K'},...
      {'DEPR',   'Dew point depression','K'},...
      {'LAPR',   'Lapse rate','K/m'},...
      {'VISIB',  'Visibility','m'},...
      {'RDSP1',  'Radar spectra (1)','non-dim'},...
      {'RDSP2',  'Radar spectra (2)','non-dim'},...
      {'RDSP3',  'Radar spectra (3)','non-dim'},...
      {'var24',  'undefined',''},...
      {'TMPA',   'Temp. anomaly','K'},...
      {'PRESA',  'Pressure anomaly','Pa'},...
      {'GPA',    'Geopotential height anomaly','gpm'},...
      {'WVSP1',  'Wave spectra (1)','non-dim'},...
      {'WVSP2',  'Wave spectra (2)','non-dim'},...
      {'WVSP3',  'Wave spectra (3)','non-dim'},...
      {'WDIR',   'Wind direction','deg'},...
      {'WIND',   'Wind speed','m/s'},...
      {'UGRD',   'u wind','m/s'},...
      {'VGRD',   'v wind','m/s'},...
      {'STRM',   'Stream function','m^2/s'},...
      {'VPOT',   'Velocity potential','m^2/s'},...
      {'MNTSF',  'Montgomery stream function','m^2/s^2'},...
      {'SGCVV',  'Sigma coord. vertical velocity','/s'},...
      {'VVEL',   'Pressure vertical velocity','Pa/s'},...
      {'DZDT',   'Geometric vertical velocity','m/s'},...
      {'ABSV',   'Absolute vorticity','/s'},...
      {'ABSD',   'Absolute divergence','/s'},...
      {'RELV',   'Relative vorticity','/s'},...
      {'RELD',   'Relative divergence','/s'},...
      {'VUCSH',  'Vertical u shear','/s'},...
      {'VVCSH',  'Vertical v shear','/s'},...
      {'DIRC',   'Direction of current','deg'},...
      {'SPC',    'Speed of current','m/s'},...
      {'UOGRD',  'u of current','m/s'},...
      {'VOGRD',  'v of current','m/s'},...
      {'SPFH',   'Specific humidity','kg/kg'},...
      {'RH',     'Relative humidity','%'},...
      {'MIXR',   'Humidity mixing ratio','kg/kg'},...
      {'PWAT',   'Precipitable water','kg/m^2'},...
      {'VAPP',   'Vapor pressure','Pa'},...
      {'SATD',   'Saturation deficit','Pa'},...
      {'EVP',    'Evaporation','kg/m^2'},...
      {'CICE',   'Cloud Ice','kg/m^2'},...
      {'PRATE',  'Precipitation rate','kg/m^2/s'},...
      {'TSTM',   'Thunderstorm probability','%'},...
      {'APCP',   'Total precipitation','kg/m^2'},...
      {'NCPCP',  'Large scale precipitation','kg/m^2'},...
      {'ACPCP',  'Convective precipitation','kg/m^2'},...
      {'SRWEQ',  'Snowfall rate water equiv.','kg/m^2/s'},...
      {'WEASD',  'Accum. snow','kg/m^2'},...
      {'SNOD',   'Snow depth','m'},...
      {'MIXHT',  'Mixed layer depth','m'},...
      {'TTHDP',  'Transient thermocline depth','m'},...
      {'MTHD',   'Main thermocline depth','m'},...
      {'MTHA',   'Main thermocline anomaly','m'},...
      {'TCDC',   'Total cloud cover','%'},...
      {'CDCON',  'Convective cloud cover','%'},...
      {'LCDC',   'Low level cloud cover','%'},...
      {'MCDC',   'Mid level cloud cover','%'},...
      {'HCDC',   'High level cloud cover','%'},...
      {'CWAT',   'Cloud water','kg/m^2'},...
      {'var77',  'undefined',''},...
      {'SNOC',   'Convective snow','kg/m^2'},...
      {'SNOL',   'Large scale snow','kg/m^2'},...
      {'WTMP',   'Water temp.','K'},...
      {'LAND',   'Land-sea mask','1=l; 0=s'},...
      {'DSLM',   'Deviation of sea level from mean','m'},...
      {'SFCR',   'Surface roughness','m'},...
      {'ALBDO',  'Albedo','%'},...
      {'TSOIL',  'Soil temp.','K'},...
      {'SOILM',  'Soil moisture content','kg/m^2'},...
      {'VEG',    'Vegetation','%'},...
      {'SALTY',  'Salinity','kg/kg'},...
      {'DEN',    'Density','kg/m^3'},...
      {'RUNOF',  'Runoff','kg/m^2'},...
      {'ICEC',   'Ice concentration','ice=1;no ice=0'},...
      {'ICETK',  'Ice thickness','m'},...
      {'DICED',  'Direction of ice drift','deg'},...
      {'SICED',  'Speed of ice drift','m/s'},...
      {'UICE',   'u of ice drift','m/s'},...
      {'VICE',   'v of ice drift','m/s'},...
      {'ICEG',   'Ice growth rate','m/s'},...
      {'ICED',   'Ice divergence','/s'},...
      {'SNOM',   'Snow melt','kg/m^2'},...
      {'HTSGW',  'Sig height of wind waves and swell','m'},...
      {'WVDIR',  'Direction of wind waves','deg'},...
      {'WVHGT',  'Sig height of wind waves','m'},...
      {'WVPER',  'Mean period of wind waves','s'},...
      {'SWDIR',  'Direction of swell waves','deg'},...
      {'SWELL',  'Sig height of swell waves','m'},...
      {'SWPER',  'Mean period of swell waves','s'},...
      {'DIRPW',  'Primary wave direction','deg'},...
      {'PERPW',  'Primary wave mean period','s'},...
      {'DIRSW',  'Secondary wave direction','deg'},...
      {'PERSW',  'Secondary wave mean period','s'},...
      {'NSWRS',  'Net short wave (surface)','W/m^2'},...
      {'NLWRS',  'Net long wave (surface)','W/m^2'},...
      {'NSWRT',  'Net short wave (top)','W/m^2'},...
      {'NLWRT',  'Net long wave (top)','W/m^2'},...
      {'LWAVR',  'Long wave','W/m^2'},...
      {'SWAVR',  'Short wave','W/m^2'},...
      {'GRAD',   'Global radiation','W/m^2'},...
      {'var118', 'undefined',''},...
      {'var119', 'undefined',''},...
      {'var120', 'undefined',''},...
      {'LHTFL',  'Latent heat flux','W/m^2'},...
      {'SHTFL',  'Sensible heat flux','W/m^2'},...
      {'BLYDP',  'Boundary layer dissipation','W/m^2'},...
      {'UFLX',   'Zonal momentum flux','N/m^2'},...
      {'VFLX',   'Meridional momentum flux','N/m^2'},...
      {'WMIXE',  'Wind mixing energy','J'},...
      {'IMGD',   'Image data','integer'},...
      {'MSLSA',  'Mean sea level pressure (Std Atm)','Pa'},...
      {'MSLMA',  'Mean sea level pressure (MAPS)','Pa'},...
      {'MSLET',  'Mean sea level pressure (ETA model)','Pa'},...
      {'LFTX',   'Surface lifted index','K'},...
      {'4LFTX',  'Best (4-layer) lifted index','K'},...
      {'KX',     'K index','K'},...
      {'SX',     'Sweat index','K'},...
      {'MCONV',  'Horizontal moisture divergence','kg/kg/s'},...
      {'VSSH',   'Vertical speed shear','1/s'},...
      {'TSLSA',  '3-hr pressure tendency','Pa/s'},...
      {'BVF2',   'Brunt-Vaisala frequency^2','1/s^2'},...
      {'PVMW',   'Potential vorticity (mass-weighted)','1/s/m'},...
      {'CRAIN',  'Categorical rain','1|0'},...
      {'CFRZR',  'Categorical freezing rain','1|0'},...
      {'CICEP',  'Categorical ice pellets','1|0'},...
      {'CSNOW',  'Categorical snow','1|0'},...
      {'SOILW',  'Volumetric soil moisture','fraction'},...
      {'PEVPR',  'Potential evaporation rate','W/m^2'},...
      {'CWORK',  'Cloud work function','J/kg'},...
      {'U-GWD',  'Zonal gravity wave stress','N/m^2'},...
      {'V-GWD',  'Meridional gravity wave stress','N/m^2'},...
      {'PV___',  'Potential vorticity','m^2/s/kg'},...
      {'var150', 'undefined',''},...
      {'var151', 'undefined',''},...
      {'var152', 'undefined',''},...
      {'MFXDV',  'Moisture flux divergence','gr/gr*m/s/m'},...
      {'var154', 'undefined',''},...
      {'GFLUX',  'Ground heat flux','W/m^2'},...
      {'CIN',    'Convective inhibition','J/kg'},...
      {'CAPE',   'Convective Avail. Pot. Energy','J/kg'},...
      {'TKE',    'Turbulent kinetic energy','J/kg'},...
      {'CONDP',  'Lifted parcel condensation pressure','Pa'},...
      {'CSUSF',  'Clear sky upward solar flux','W/m^2'},...
      {'CSDSF',  'Clear sky downward solar flux','W/m^2'},...
      {'CSULF',  'Clear sky upward long wave flux','W/m^2'},...
      {'CSDLF',  'Clear sky downward long wave flux','W/m^2'},...
      {'CFNSF',  'Cloud forcing net solar flux','W/m^2'},...
      {'CFNLF',  'Cloud forcing net long wave flux','W/m^2'},...
      {'VBDSF',  'Visible beam downward solar flux','W/m^2'},...
      {'VDDSF',  'Visible diffuse downward solar flux','W/m^2'},...
      {'NBDSF',  'Near IR beam downward solar flux','W/m^2'},...
      {'NDDSF',  'Near IR diffuse downward solar flux','W/m^2'},...
      {'USTR',   'U wind stress','N/m^2'},...
      {'VSTR',   'V wind stress','N/m^2'},...
      {'MFLX',   'Momentum flux','N/m^2'},...
      {'LMH',    'Mass point model surface','integer'},...
      {'LMV',    'Velocity point model surface','integer'},...
      {'SGLYR',  'Nearby model level','integer'},...
      {'NLAT',   'Latitude','deg'},...
      {'NLON',   'Longitude','deg'},...
      {'UMAS',   'Mass weighted u','gm/m*K*s'},...
      {'VMAS',   'Mass weighted v','gm/m*K*s'},...
      {'XPRATE', 'corrected precip','kg/m^2/s'},...
      {'LPSX',   'x-gradient of log pressure','1/m'},...
      {'LPSY',   'y-gradient of log pressure','1/m'},...
      {'HGTX',   'x-gradient of height','m/m'},...
      {'HGTY',   'y-gradient of height','m/m'},...
      {'STDZ',   'Std dev of Geop. hgt.','m'},...
      {'STDU',   'Std dev of zonal wind','m/s'},...
      {'STDV',   'Std dev of meridional wind','m/s'},...
      {'STDQ',   'Std dev of spec. hum.','gm/gm'},...
      {'STDT',   'Std dev of temp.','K'},...
      {'CBUW',   'Covar. u and omega','m/s*Pa/s'},...
      {'CBVW',   'Covar. v and omega','m/s*Pa/s'},...
      {'CBUQ',   'Covar. u and specific hum','m/s*gm/gm'},...
      {'CBVQ',   'Covar. v and specific hum','m/s*gm/gm'},...
      {'CBTW',   'Covar. T and omega','K*Pa/s'},...
      {'CBQW',   'Covar. spec. hum and omega','gm/gm*Pa/s'},...
      {'CBMZW',  'Covar. v and u','m^2/s^2'},...
      {'CBTZW',  'Covar. u and T','K*m/s'},...
      {'CBTMW',  'Covar. v and T','K*m/s'},...
      {'STDRH',  'Std dev of Rel. Hum.','%'},...
      {'SDTZ',   'Std dev of time tend of geop. hgt','m'},...
      {'ICWAT',  'Ice-free water surface','%'},...
      {'SDTU',   'Std dev of time tend of zonal wind','m/s'},...
      {'SDTV',   'Std dev of time tend of merid wind','m/s'},...
      {'DSWRF',  'Downward solar radiation flux','W/m^2'},...
      {'DLWRF',  'Downward long wave flux','W/m^2'},...
      {'SDTQ',   'Std dev of time tend of spec. hum','gm/gm'},...
      {'MSTAV',  'Moisture availability','%'},...
      {'SFEXC',  'Exchange coefficient','kg*m/m^3/s'},...
      {'MIXLY',  'No. of mixed layers next to sfc','integer'},...
      {'SDTT',   'Std dev of time tend of temp.','K'},...
      {'USWRF',  'Upward solar radiation flux','W/m^2'},...
      {'ULWRF',  'Upward long wave flux','W/m^2'},...
      {'CDLYR',  'Non-convective cloud','%'},...
      {'CPRAT',  'Convective precip. rate','kg/m^2/s'},...
      {'TTDIA',  'Temp. tendency by all physics','K/s'},...
      {'TTRAD',  'Temp. tendency by all radiation','K/s'},...
      {'TTPHY',  'Temp. tendency by nonrad physics','K/s'},...
      {'PREIX',  'Precipitation index','fraction'},...
      {'TSD1D',  'Std dev of IR T over 1x1 deg area','K'},...
      {'NLSGP',  'Natural log of surface pressure','ln(kPa)'},...
      {'SDTRH',  'Std dev of time tend of rel hum','%'},...
      {'5WAVH',  '5-wave geopotential height','gpm'},...
      {'CNWAT',  'Plant canopy surface water','kg/m^2'},...
      {'PLTRS',  'Max. stomato plant resistance','s/m'},...
      {'RHCLD',  'RH-type cloud cover','%'},...
      {'BMIXL',  'Blackadar''s mixing length scale','m'},...
      {'AMIXL',  'Asymptotic mixing length scale','m'},...
      {'PEVAP',  'Pot. evaporation','kg/m^2'},...
      {'SNOHF',  'Snow melt heat flux','W/m^2'},...
      {'SNOEV',  'Snow sublimation heat flux','W/m^2'},...
      {'MFLUX',  'Convective cloud mass flux','Pa/s'},...
      {'DTRF',   'Downward total radiation flux','W/m^2'},...
      {'UTRF',   'Upward total radiation flux','W/m^2'},...
      {'BGRUN',  'Baseflow-groundwater runoff','kg/m^2'},...
      {'SSRUN',  'Storm surface runoff','kg/m^2'},...
      {'var236', 'undefined',''},...
      {'OZONE',  'Total column ozone','Dobson'},...
      {'SNOWC',  'Snow cover','%'},...
      {'SNOT',   'Snow temp.','K'},...
      {'GLCR',   'Permanent snow points','mask'},...
      {'LRGHR',  'Large scale condensation heating','K/s'},...
      {'CNVHR',  'Deep convective heating','K/s'},...
      {'CNVMR',  'Deep convective moistening','kg/kg/s'},...
      {'SHAHR',  'Shallow convective heating','K/s'},...
      {'SHAMR',  'Shallow convective moistening','kg/kg/s'},...
      {'VDFHR',  'Vertical diffusion heating','K/s'},...
      {'VDFUA',  'Vertical diffusion zonal accel','m/s^2'},...
      {'VDFVA',  'Vertical diffusion meridional accel','m/s^2'},...
      {'VDFMR',  'Vertical diffusion moistening','kg/kg/s'},...
      {'SWHR',   'Solar radiative heating','K/s'},...
      {'LWHR',   'Longwave radiative heating','K/s'},...
      {'CD',     'Drag coefficient','non-dim'},...
      {'FRICV',  'Friction velocity','m/s'},...
      {'RI',     'Richardson number','non-dim'},...
      {'var255', 'undefined',''}};


   case 'ECMWF128'

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %    ECMWF user-defined parameter table (#128)          %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

      Parameter_Table={...
      {'var0',    'undefined',''},...
      {'None',   'Stream Function ',   'm**2 s**-1'},...
      {'None',   'Velocity Potential',   ' m**2 s**-1'},...
      {'None',   'Potential Temperature ',   'K'},...
      {'None',   'Equivalent Potential Temperature',   ' K'},...
      {'None',   'Saturated Equivalent Potential Temperature',   ' K'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW.',   ' -'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'u-component of Divergent Wind ',   'm s**-1'},...
      {'None',   'v-component of Divergent Wind ',   'm s**-1'},...
      {'None',   'u-component of Rotational Wind ',   'm s**-1'},...
      {'None',   'v-component of Rotational Wind ',   'm s**-1'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'UCTP',   'Unbalanced component of temperature ',   'K'},...
      {'UCLN',   'Unbalanced component of lnsp ',   '-'},...
      {'UCDV',   'Unbalanced component of divergence',   ' s**-1'},...
      {'None',   'Reserved for future unbalanced components',   ' -'},...
      {'None',   'Reserved for future unbalanced components ',   '-'},...
      {'CL',   'Lake cover ',   '(0-1)'},...
      {'CVL',   'Low vegetation cover ',   '(0-1)'},...
      {'CVH',   'High vegetation cover ',   '(0-1)'},...
      {'TVL',   'Type of low vegetation ',   '-'},...
      {'TVH',   'Type of high vegetation ',   '-'},...
      {'CI',   'Sea ice cover ',   '(0-1)'},...
      {'ASN',   'Snow albedo ',   '(0-1)'},...
      {'RSN',   'Snow density ',   'kg**-3'},...
      {'SSTK',   'Sea surface temperature (absolute) ',   'K'},...
      {'ISTL1',   'Ice surface temperature layer 1 ',   'K'},...
      {'ISTL2',   'Ice surface temperature layer 2 ',   'K'},...
      {'ISTL3',   'Ice surface temperature layer 3 ',   'K'},...
      {'ISTL4',   'Ice surface temperature layer 4 ',   'K'},...
      {'SWVL1',   'Volumetric soil water layer 1 ',   'm**3 m**-3'},...
      {'SWVL2',   'Volumetric soil water layer 2 ',   'm**3 m**-3'},...
      {'SWVL3',   'Volumetric soil water layer 3 ',   'm**3 m**-3'},...
      {'SWVL4',   'Volumetric soil water layer 4 ',   'm**3 m**-3'},...
      {'SLT',   'Soil Type ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'AT',   'Atmospheric tide ',   '-'},...
      {'BV',   'Budget values ',   '-'},...
      {'Z',   'Geopotential (at the surface = orography) ',   'm**2 s**-2'},...
      {'T',   'Temperature ',   'K'},...
      {'U',   'U-velocity ',   'm s**-1'},...
      {'V',   'V-velocity ',   'm s**-1'},...
      {'Q',   'Specific humidity ',   'kg kg**-1'},...
      {'SP',   'Surface pressure ',   'Pa'},...
      {'W',   'Vertical velocity ',   'Pa s**-1'},...
      {'TWC',   'Total column water ',   'kg m**-2'},...
      {'PWC',   'Precipitable water content ',   'kg m**-2'},...
      {'VO',   'Vorticity (relative) ',   's**-1'},...
      {'ST',   'Surf.temp/soil temp lev 1 (from 930804) ',   'K'},...
      {'SSW',   'Surf soil wet/soil wet lev 1(from 930803) ',   'm (of water)'},...
      {'SD',   'Snow depth ',   'm (of water equivalent)'},...
      {'LSP',   'Large scale precipitation ',   'm'},...
      {'CP',   'Convective precipitation ',   'm'},...
      {'SF',   'Snow fall ',   'm(of water equivalent)'},...
      {'BLD',   'Boundary layer dissipation ',   'W m**-2 s'},...
      {'SSHF',   'Surface sensible heat flux ',   'W m**-2 s'},...
      {'SLHF',   'Surface latent heat flux ',   'W m**-2 s'},...
      {'SS/CHNK',   'Surface stress/Charnock (from 980519) ',   '-'},...
      {'SNR',   'Surface net radiation ',   '-'},...
      {'AIW',   'Top net radiation ',   '-'},...
      {'MSL',   'Mean sea level pressure ',   'Pa'},...
      {'LNSP',   'Log surface pressure ',   '-'},...
      {'SWHR',   'Short wave heating rate ',   'K'},...
      {'LWH',   'Long wave heating rate ',   'K'},...
      {'D',   'Divergence ',   's**-1'},...
      {'GH',   'Height (geopotential) ',   'm'},...
      {'R',   'Relative humidity ',   '%'},...
      {'TSP',   'Tendency of surface pressure ',   'Pa s**-1'},...
      {'BLH',   'Boundary layer height ',   'm'},...
      {'SDOR',   'Standard deviation of orography ',   '-'},...
      {'ISOR',   'Anisotropy of subgrid scale orography ',   '-'},...
      {'ANOR',   'Angle of subgrid scale orography ',   '-'},...
      {'SLOR',   'Slope of subgrid scale orography ',   '-'},...
      {'TCC',   'Total cloud cover ',   '(0 - 1)'},...
      {'10U',   '10 metre u wind component ',   'm s**-1'},...
      {'10V',   '10 metre v wind component ',   'm s**-1'},...
      {'2T',   '2 metre temperature ',   'K'},...
      {'2D',   '2 metre dewpoint temperature ',   'K'},...
      {'SSRD',   'Surface solar radiation downwards',   ' W m**-2 s'},...
      {'DST',   'Deep soil tmp/soil temp lev2(from 930804) ',   'K'},...
      {'DSW',   'Deep soil wet/soil wet lev2(from 930803) ',   'm (of water)'},...
      {'LSM',   'Land/sea mask ',   '(0-1)'},...
      {'SR',   'Surface roughness ',   'm'},...
      {'AL',   'Albedo ',   '-'},...
      {'STRD',   'Surface thermal radiation downwards',   ' W m**-2 s'},...
      {'SSR',   'Surface solar radiation ',   'W m**-2 s'},...
      {'STR',   'Surface thermal radiation',   ' W m**-2 s'},...
      {'TSR',   'Top solar radiation ',   'W m**-2 s'},...
      {'TTR',   'Top thermal radiation ',   'W m**-2 s'},...
      {'EWSS',   'East/West surface stress ',   'N m**-2 s'},...
      {'NSSS',   'North/South surface stress ',   'N m**-2 s'},...
      {'E',   'Evaporation ',   'm (of water)'},...
      {'CDST',   'Clim deep soil tmp/soil tmp lev3(930804) ',   'K'},...
      {'CDSW',   'Clim deep soil wet/soil wet lev3(930803) ',   'm (of water)'},...
      {'CCC',   'Convective cloud cover ',   '(0 - 1)'},...
      {'LCC',   'Low cloud cover ',   '(0 - 1)'},...
      {'MCC',   'Medium cloud cover ',   '(0 - 1)'},...
      {'HCC',   'High cloud cover ',   '(0 - 1)'},...
      {'-',   'Unused ',   '-'},...
      {'EWOV',   'EW component subgrid orographic variance ',   'm**2'},...
      {'NSOV',   'NS component subgrid orographic variance ',   'm**2'},...
      {'NWOV',   'NWSE component subgrid orographic variance ',   'm**2'},...
      {'NEOV',   'NESW component subgrid orographic variance ',   'm**2'},...
      {'BTMP',   'Brightness temperature ',   'K'},...
      {'LGWS',   'Lat. component of gravity wave stress ',   'N m**-2 s'},...
      {'MGWS',   'Meridional component gravity wave stress ',   'N m**-2 s'},...
      {'GWD',   'Gravity wave dissipation ',   'W m**-2 s'},...
      {'SRC',   'Skin reservoir content ',   'm (of water)'},...
      {'VEG',   'Percentage of vegetation ',   '%'},...
      {'VSO',   'Variance of sub-grid scale orography ',   'm**2'},...
      {'MX2T',   'Max 2m temp since previous post-processing',   ' K'},...
      {'MN2T',   'Min 2m temp since previous post-processing ',   'K'},...
      {'O3',   'Ozone mass mixing ratio ',   'kg kg**-1'},...
      {'PAW',   'Precip. analysis weights ',   '-'},...
      {'RO',   'Runoff* ',   'm'},...
      {'TCO3',   'Total column ozone Dobson ',   '(kg m**-2)'},...
      {'10SI',   '10m. Windspeed (irresp of dir.) ',   'm s**-1'},...
      {'TSRC',   'Top net solar radiation clear sky ',   'W m**-2'},...
      {'TTRC',   'Top upward thermal radiation clear sky ',   'W m**-2'},...
      {'SSRC',   'Surface net solar radiation clear sky ',   'W m**-2'},...
      {'STRC',   'Surface net thermal radiation clear sky ',   'W m**-2'},...
      {'SI',   'Solar insulation ',   'W m**-2'},...
      {'-',   'Unused ',   '-'},...
      {'DHR',   'Diabatic heating by radiation* ',   'K'},...
      {'DHVD',   'Diabatic heating by vertical diffusion ',   'K'},...
      {'DHCC',   'Diabatic heating by cumulus convection ',   'K'},...
      {'DHLC',   'Diabatic heating large-scale condensation ',   'K'},...
      {'VDZW',   'Vertical diffusion of zonal wind ',   'm s**-1'},...
      {'VDMW',   'Vertical diffusion of meridional wind ',   'm s**-1'},...
      {'EWGD',   'EW gravity wave drag ',   'm s**-1'},...
      {'NSGD',   'NS gravity wave drag ',   'm s**-1'},...
      {'CTZW',   'Convective tendency of zonal wind ',   'm s**-1'},...
      {'CTMW',   'Convective tendency of meridional wind ',   'm s**-1'},...
      {'VDH',   'Vertical diffusion of humidity ',   'kg kg**-1'},...
      {'HTCC',   'Humidity tendency by cumulus convection ',   'kg kg**-1'},...
      {'HTLC',   'Humidity tendency large-scale condensation ',   'kg kg**-1'},...
      {'CRNH',   'Change from removing negative humidity ',   'kg/kg s-1'},...
      {'TP',   'Total precipitation ',   'm'},...
      {'IEWS',   'Instantaneous X surface stress ',   'N m**-2'},...
      {'INSS',   'Instantaneous Y surface stress ',   'N m**-2'},...
      {'ISHF',   'Instantaneous surface Heat Flux ',   'W m**-2'},...
      {'IE',   'Instantaneous Moisture Flux (evaporation)',   ' kg m**-2 s'},...
      {'ASQ',   'Apparent Surface Humidity ',   'kg kg**-1'},...
      {'LSRH',   'Log of surface roughness length for heat ',   '-'},...
      {'SKT',   'Skin Temperature ',   'K'},...
      {'STL4',   'Soil temperature level 4 ',   'K'},...
      {'SWL4',   'Soil wetness level 4 ',   'm'},...
      {'TSN',   'Temperature of snow layer ',   'K'},...
      {'CSF',   'Convective snow-fall ',   'm (of water equivalent)'},...
      {'LSF',   'Large scale snow-fall ',   'm (of water equivalent)'},...
      {'ACF',   'Accumulated cloud fraction tendency ',   '(-1 to 1)'},...
      {'ALW',   'Accumulated liquid water tendency ',   '(-1 to 1)'},...
      {'FAL',   'Forecast albedo ',   '-'},...
      {'FSR',   'Forecast surface roughness ',   'm'},...
      {'FLSR',   'Forecast log of surface roughness for heat ',   '-'},...
      {'CLWC',   'Cloud liquid water content ',   'kg kg**-1'},...
      {'CIWC',   'Cloud ice water content ',   'kg kg**-1'},...
      {'CC',   'Cloud cover ',   '(0 - 1)'},...
      {'AIW',   'Accumulated ice water tendency ',   '(-1 to 1)'},...
      {'ICE',   'Ice Age ',   '(0 first-year 1 multi-year)'},...
      {'ATTE',   'Adiabatic tendency of temperature ',   'K'},...
      {'ATHE',   'Adiabatic tendency of humidity ',   'kg kg**-1'},...
      {'ATZE',   'Adiabatic tendency of zonal wind ',   'm s**-1'},...
      {'ATMW',   'Adiabatic tendency of meridional wind ',   'm s**-1'},...
      {'-',   'Indicates a missing value ',   '-'}};

  case 'ECMWF140'

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %    ECMWF user-defined parameter table (#140)          %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      Parameter_Table={...
      {'var0',   'undefined',   ' ',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'MAXSWH',   'Maximum of significant wave height',   'm',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'-',   'unused',   '-',},...
      {'UST',   'U-component stokes drift',   'm s**-1'},...
      {'VST',   'V-component stokes drift',   'm s**-1'},...
      {'TMAX',   'Period corresponding to maximum individual wave height',   's'},...
      {'HMAX',   'Maximum individual wave height',   'm'},...
      {'WMB',   'Model bathymetry',   'm'},...
      {'MP1',   'Mean wave period based on first moment',   's'},...
      {'MP2',   'Mean wave period based on second moment',   's'},...
      {'WDW',   'Wave spectral directional width',   '-'},...
      {'P1WW',   'Mean wave period based on first moment for wind waves',   's'},...
      {'P2WW',   'Mean wave period based on second moment for wind waves',   's'},...
      {'DWWW',   'Wave spectral directional width for wind waves',   '-'},...
      {'P1PS',   'Mean wave period based on first moment for swell',   's'},...
      {'P2PS',   'Mean wave period based on second moment for swell',   's'},...
      {'DWPS',   'Wave spectral directional width for swell',   '-'},...
      {'SWH',   'Significant wave height',   'm'},...
      {'MWD',   'Mean wave direction',   'degrees'},...
      {'PP1D',   'Peak period of 1D spectra',   's'},...
      {'MWP',   'Mean wave period',   's'},...
      {'CDWW',   'Coefficient of drag with waves',   '-'},...
      {'SHWW',   'Significant height of wind waves',   'm'},...
      {'MDWW',   'Mean direction of wind waves',   'degrees'},...
      {'MPWW',   'Mean period of wind waves',   's'},...
      {'SHTS',   'Significant height of total swell',   'm'},...
      {'MDTS',   'Mean direction of total swell',   'degrees'},...
      {'MPTS',   'Mean period of total swell',   's'},...
      {'SDHS',   'Standard deviation wave height',   'm'},...
      {'MU10',   'Mean of 10 metre wind speed',   'm s**-1'},...
      {'MDWI',   'Mean wind direction',   'degrees'},...
      {'SDU',   'Standard deviation of 10 metre wind speed',   'm s**-1'},...
      {'MSQS',   'Mean square slope of waves',   'dimensionless'},...
      {'WIND',   '10 metre wind speed',   'm s**-1'},...
      {'AWH',   'Altimeter wave height',   'm'},...
      {'ACWH',   'Altimeter corrected wave height',   'm'},...
      {'ARRC',   'Altimeter range relative correction',   '-'},...
      {'DWI',   '10 metre wind direction',   'degrees'},...
      {'2DSP',   '2D wave spectra (multiple)',   'm**2 s radian**-1'},...
      {'2DFD',   '2D wave spectra (single)',   'm**2 s radian**-1'},...
      {'WSK',   'Wave spectral kurtosis',   '-',},...
      {'BFI',   'Benjamin-Feir index',   '-'},...
      {'WSP',   'Wave spectral peakedness',   's**-1'},...
      {'-',   'Indicates a missing value',   '-'}};


  
   case 'ECMWF160'

      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %    ECMWF user-defined parameter table (#160)          %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      Parameter_Table={...
      {'var0',    'undefined',''},...
      {'None',   'Stream Function ',   'm**2 s**-1'},...
      {'None',   'Velocity Potential',   ' m**2 s**-1'},...
      {'None',   'Potential Temperature ',   'K'},...
      {'None',   'Equivalent Potential Temperature',   ' K'},...
      {'None',   'Saturated Equivalent Potential Temperature',   ' K'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW.',   ' -'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'u-component of Divergent Wind ',   'm s**-1'},...
      {'None',   'v-component of Divergent Wind ',   'm s**-1'},...
      {'None',   'u-component of Rotational Wind ',   'm s**-1'},...
      {'None',   'v-component of Rotational Wind ',   'm s**-1'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'None',   'RESERVED FOR METVIEW. ',   '-'},...
      {'UCTP',   'Unbalanced component of temperature ',   'K'},...
      {'UCLN',   'Unbalanced component of lnsp ',   '-'},...
      {'UCDV',   'Unbalanced component of divergence',   ' s**-1'},...
      {'None',   'Reserved for future unbalanced components',   ' -'},...
      {'None',   'Reserved for future unbalanced components ',   '-'},...
      {'CL',   'Lake cover ',   '(0-1)'},...
      {'CVL',   'Low vegetation cover ',   '(0-1)'},...
      {'CVH',   'High vegetation cover ',   '(0-1)'},...
      {'TVL',   'Type of low vegetation ',   '-'},...
      {'TVH',   'Type of high vegetation ',   '-'},...
      {'CI',   'Sea ice cover ',   '(0-1)'},...
      {'ASN',   'Snow albedo ',   '(0-1)'},...
      {'RSN',   'Snow density ',   'kg**-3'},...
      {'SSTK',   'Sea surface temperature (absolute) ',   'K'},...
      {'ISTL1',   'Ice surface temperature layer 1 ',   'K'},...
      {'ISTL2',   'Ice surface temperature layer 2 ',   'K'},...
      {'ISTL3',   'Ice surface temperature layer 3 ',   'K'},...
      {'ISTL4',   'Ice surface temperature layer 4 ',   'K'},...
      {'SWVL1',   'Volumetric soil water layer 1 ',   'm**3 m**-3'},...
      {'SWVL2',   'Volumetric soil water layer 2 ',   'm**3 m**-3'},...
      {'SWVL3',   'Volumetric soil water layer 3 ',   'm**3 m**-3'},...
      {'SWVL4',   'Volumetric soil water layer 4 ',   'm**3 m**-3'},...
      {'SLT',   'Soil Type ',   '-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'-','Unused ','-'},...
      {'AT',   'Atmospheric tide ',   '-'},...
      {'BV',   'Budget values ',   '-'},...
      {'Z',   'Geopotential (at the surface = orography) ',   'm**2 s**-2'},...
      {'T',   'Temperature ',   'K'},...
      {'U',   'U-velocity ',   'm s**-1'},...
      {'V',   'V-velocity ',   'm s**-1'},...
      {'Q',   'Specific humidity ',   'kg kg**-1'},...
      {'SP',   'Surface pressure ',   'Pa'},...
      {'W',   'Vertical velocity ',   'Pa s**-1'},...
      {'-',   'Unused ',   '-'},...
      {'PWC',   'Precipitable water content ',   'kg m**-2'},...
      {'VO',   'Vorticity (relative) ',   's**-1'},...
      {'STL1',   'Soil temperature level 1 ',   'K'},...
      {'SWL1',   'Soil wetness level 1 ',   'm'},...
      {'SD',   'Snow depth ',   'm (of water)'},...
      {'LSP',   'Large scale precipitation ',   'kg m**-2 s**-1'},...
      {'CP',   'Convective precipitation ',   'kg m**-2 s**-1'},...
      {'SF',   'Snow fall ',   'kg m**-2 s**-1'},...
      {'BLD',   'Boundary layer dissipation ',   'W m**-2 s'},...
      {'SSHF',   'Surface sensible heat flux ',   'W m**-2 s'},...
      {'SLHF',   'Surface latent heat flux ',   'W m**-2 s'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'MSL', 'Mean sea level pressure','Pa'},...
      {'LNSP','Ln surface pressure', ' -'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'D','Divergence s**-1'},...
      {'GH','Height (geopotential)','m'},...
      {'R','Relative humidity','(0 - 1)'},...
      {'TSP','Tendency of surface pressure ','Pa s**-1'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'TCC','Total cloud cover ','(0 - 1)'},...
      {'10U','10 metre u wind component',' m s**-1'},...
      {'10V','10 metre v wind component ','m s**-1'},...
      {'2T','2 metre temperature ','K'},...
      {'2D','2 metre dewpoint temperature',' K'},...
      {'-',   'Unused ',   '-'},...
      {'STL2','Soil temperature level 2 ','K'},...
      {'SWL2','Soil wetness level 2 ','m'},...
      {'LSM','Land/sea mask ','(0 - 1)'},...
      {'SR','Surface roughness ','m'},...
      {'AL','Albedo ','(0 - 1)'},...
      {'-',   'Unused ',   '-'},...
      {'SSR','Surface solar radiation ','W m**-2'},...
      {'STR','Surface thermal radiation ','W m**-2'},...
      {'TSR','Top solar radiation ','W m**-2'},...
      {'TTR','Top thermal radiation ','W m**-2'},...
      {'EWSS','East/west surface stress',' N m**-2 s**-1'},...
      {'NSSS','North/south surface stress ','N m**-2 s**-1'},...
      {'E','Evaporation ','kg m**-2 s**-1'},...
      {'STL3','Soil temperature level 3 ','K'},...
      {'SWL3','Soil wetness level 3 ','m'},...
      {'CCC','Convective cloud cover ','(0 - 1)'},...
      {'LCC','Low cloud cover ','(0 - 1)'},...
      {'MCC','Medium cloud cover ','(0 - 1)'},...
      {'HCC','High cloud cover ','(0 - 1)'},...
      {'-',   'Unused ',   '-'},...
      {'EWOV','EW component of sub-grid scale orographic variance',' m**2'},...
      {'NSOV','NS component of sub-grid scale orographic variance',' m**2'},...
      {'NWOV','NWSE component sub-grid scale orographic variance ','m**2'},...
      {'NEOV','NESW component sub-grid scale orographic variance',' m**2'},...
      {'-',   'Unused ',   '-'},...
      {'LGWS','Latitudinal component of gravity wave stress ','N m**-2 s'},...
      {'MGWS','Meridional component of gravity wave stress ','N m**-2 s'},...
      {'GWD','Gravity wave dissipation',' W m**-2 s'},...
      {'SRC','Skin reservoir content ','m (of water)'},...
      {'VEG','Percentage of vegetation ','%'},...
      {'VSO','Variance of sub-grid scale orography ','m**2'},...
      {'MX2T','Max temp.2m during averaging time ','K'},...
      {'MN2T','Min temp.2m during averaging time',' K'},...
      {'-',   'Unused ',   '-'},...
      {'PAW','Precip. analysis weights ','-'},...
      {'RO','Runoff ','kg m**-2 s**-1'},...
      {'ZZ','St.Dev. of Geopotential ','m**2 s**-2'},...
      {'TZ','Covar Temp & Geopotential',' K m**2 s**-2'},...
      {'TT','St.Dev. of Temperature',' K'},...
      {'QZ','Covar Sp.Hum. & Geopotential',' m**2 s**-2'},...
      {'QT','Covar Sp.Hum & Temp. ','K'},...
      {'QQ','St.Dev. of Specific humidity ','(0 - 1)'},...
      {'UZ','Covar U-comp. & Geopotential',' m**3 s**-3'},...
      {'UT','Covar U-comp. & Temp.',' K m s**-1'},...
      {'UQ','Covar U-comp. & Sp.Hum.',' m s**-1'},...
      {'UU','St.Dev. of U-velocity ','m s**-1'},...
      {'VZ','Covar V-comp. & ','Geopotential m**3 s**-3'},...
      {'VT','Covar V-comp. & Temp.',' K m s**-1'},...
      {'VQ','Covar V-comp. & Sp.Hum.',' m s**-1'},...
      {'VU','Covar V-comp. & U-comp ','m**2 s**-2'},...
      {'VV','St.Dev. of V-comp',' m s**-1'},...
      {'WZ','Covar W-comp. & Geopotential ','Pa m**2 s**-3'},...
      {'WT','Covar W-comp. & Temp.',' K Pa s**-1'},...
      {'WQ','Covar W-comp. & Sp.Hum.',' Pa s**-1'},...
      {'WU','Covar W-comp. & U-comp.',' Pa m s**-2'},...
      {'WV','Covar W-comp. & V-comp.',' Pa m s**-2'},...
      {'-',   'Unused ',   '-'},...
      {'WW','St.Dev. of Vertical velocity Pa s**-1'},...
      {'-',   'Unused ',   '-'},...
      {'TP','Total precipitation','m'},...
      {'IEWS','Instantaneous X surface stress','N m**-2'},...
      {'INSS','Instantaneous Y surface stress','N m**-2'},...
      {'ISHF','Instantaneous surface Heat Flux','W m**-2'},...
      {'IE','Instantaneous Moisture Flux (evaporation)','kg m**-2 s**-1'},...
      {'ASQ','Apparent Surface Humidity ','kg kg**-1'},...
      {'LSRH','Logarithm of surface roughness length for heat','-'},...
      {'SKT','Skin Temperature','K'},...
      {'STL4','Soil temperature level 4 ','K'},...
      {'SWL4','Soil wetness level 4 ','m'},...
      {'TSN','Temperature of snow layer ','K'},...
      {'CSF','Convective snow-fall ','kg m**-2 s**-1'},...
      {'LSF','Large scale snow-fall ','kg m**-2 s**-1'},...
      {'CLWC','Cloud liquid water content ','kg kg**-1'},...
      {'CC','Cloud cover (at given level) ','(0 - 1)'},...
      {'FAL','Forecast albedo ','-'},...
      {'FSR','Forecast surface roughness ','m'},...
      {'FLSR','Forecast logarithm of surface roughness for heat. ','-'},...
      {'10WS','10m. Windspeed (irresp of dir.) ','m s**-1'},...
      {'MOFL','Momentum flux (irresp of dir.) ','N m**-2'},...
      {'HSD','Heaviside ("beta") function','(0 - 1)'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'},...
      {'-',   'Unused ',   '-'}};
  
   otherwise,
      error('Invalid parameter table specification.')
end

if ScreenDiag, disp(sprintf('Parameter Table set to %s',ParamTable))   , end




    
    
    
    
    
    



